package org.jtiger.samples;

import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.Comparable.assertEqualComparesToZero;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Category;
import org.jtiger.framework.Test;
import org.jtiger.framework.ExpectException;
import org.jtiger.assertion.ObjectFactory;

@Fixture(value = "Integer", description = "Performs Unit Tests on java.lang.Integer")
@Category({"java.lang.Integer", "J2SE Core", "java.lang"})
public final class SampleTestFixture2
{
    public SampleTestFixture2()
    {

    }

    @Test(value = "Constant fields", description = "Test the constant fields of java.lang.Integer")
    public void constantFields()
    {
        assertEqual(2147483647, Integer.MAX_VALUE);
        assertEqual(-2147483648, Integer.MIN_VALUE);
        assertEqual(32, Integer.SIZE);
        assertSame(int.class, Integer.TYPE);
        assertSame(int.class, Integer.TYPE);
    }

    @Test(value = "Constructors (1)", description = "Test the constructors of java.lang.Integer")
    public void constructors1()
    {
        new Integer(7);
        new Integer("7");
        final Integer i1 = new Integer(7);
        assertEqual(7, i1.intValue());

        final Integer i2 = new Integer("8");
        assertEqual(8, i2.intValue());
    }

    @Test(value = "Constructors (2)", description = "Test the constructors of java.lang.Integer")
    @ExpectException(NumberFormatException.class)
    public void constructors2()
    {
        new Integer("xyz");
    }

    @Test(value = "Rotate", description = "Test the rotating method of java.lang.Integer")
    public void rotate()
    {
        final Integer i = 7;
        assertEqual(7340032, Integer.rotateRight(i, 12));
        assertEqual(28672, Integer.rotateLeft(i, 12));
    }

    @Test(value = "Serialization", description = "Test the serialization of java.lang.Integer")
    public void serialization()
    {
        final Integer i = 7;
        assertSerializes(i, "Integer does not serialize");
        assertSerializesEqual(i, "Integer does not serialize equal");
    }

    @Test(value = "Comparable", description = "Test the comparable implementation of java.lang.Integer")
    public void comparable()
    {
        final ObjectFactory<Integer> factory = new ObjectFactory<Integer>()
        {
            public Integer newInstanceX()
            {
                // WARNING!
                // Values between -128 and 127 will not work
                // here since they are boxed to the same
                // instance of Integer.
                // This violates the ObjectFactory contract.
                // This method must return unique instances on each invocation.
                return 777;
            }

            public Integer newInstanceY()
            {
                return 888;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualComparesToZero(factory, "equal Integers do not compare to zero");
    }

    @Test(value = "Equals/HashCode", description =
        "Test the equals and hashCode method contract implementations of java.lang.Integer")
    public void equalsHashCodeContracts()
    {
        final ObjectFactory<Integer> factory = new ObjectFactory<Integer>()
        {
            public Integer newInstanceX()
            {
                return 777;
            }

            public Integer newInstanceY()
            {
                return 888;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }
}