package org.jtiger.samples;

import org.jtiger.framework.Test;
import org.jtiger.framework.ExpectException;
import org.jtiger.assertion.ObjectFactory;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;

public final class SomeTestCases
{
    public SomeTestCases()
    {

    }

    @Test
    public void simpleTestCase1()
    {
        // Assert that two plus two equals four.
        assertEqual(4, 2 + 2);
    }

    @Test
    public void simpleTestCase2()
    {
        // Assert that an instance of the Integer
        // class serializes and deserializes.
        assertSerializes(new Integer(7));
    }

    @Test
    public void simpleTestCase3()
    {
        // Assert that an instance of the Integer
        // class serializes and deserializes to be equal.
        assertSerializesEqual(new Integer(7));
    }

    @Test
    public void simpleTestCase4()
    {
        // Assert that the Integer class meets the Object equals
        // and hashCode method contracts.
        // This test is only as good as the test data returned by
        // the ObjectFactory methods.
        final ObjectFactory<Integer> factory = new ObjectFactory<Integer>()
        {
            public Integer newInstanceX()
            {
                return new Integer(7);
            }

            public Integer newInstanceY()
            {
                return new Integer(8);
            }
        };

        // Assert that the test data is valid and meets
        // the ObjectFactory contract.
        assertObjectFactoryFillsContract(factory);
        // Assert that the Object equals method contract is met.
        assertEqualsMethodFillsContract(factory);
        // Assert that the Object hashCode method contract is met.
        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void simpleTestCase5()
    {
        // Expect a NullPointerException to occur.
        new String((StringBuffer)null);
    }
}