/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

/**
 * An element used in {@link JTigerTask the Ant task} to specify a regular expression which categories of test cases are
 * to be executed by the framework. Omitting this element from the build file causes test cases in any category to be
 * executed.
 *
 * @see JTigerTask
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class Category
{
    private String regex;

    /**
     * Create a default <tt>Category</tt>.
     */
    public Category()
    {

    }

    /**
     * Create a <tt>Category</tt> with the given regular expression.
     *
     * @param regex The regular expression of the <tt>Category</tt>.
     */
    public Category(final String regex)
    {
        setRegex(regex);
    }

    /**
     * Returns the regular expression for this category.
     *
     * @return The regular expression for this category.
     */
    public String getRegex()
    {
        return regex;
    }

    /**
     * Sets the regular expression for this category.
     *
     * @param regex The regular expression for this category.
     */
    public void setRegex(final String regex)
    {
        this.regex = regex;
    }
}
