/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

final class FileNameToClassNameFactory
{
    private FileNameToClassNameFactory()
    {

    }

    static FileNameToClassName newFileNameToClassName()
    {
        return new FileNameToClassNameImpl();
    }

    private static final class FileNameToClassNameImpl implements FileNameToClassName
    {
        private static final String JAVA = ".java";
        private static final String CLASS = ".class";

        FileNameToClassNameImpl()
        {

        }

        public String toClassName(String filename)
        {
            if(filename == null)
            {
                return null;
            }

            if(filename.endsWith(FileNameToClassNameImpl.JAVA))
            {
                filename = filename.substring(0, filename.length() - FileNameToClassNameImpl.JAVA.length());
            }
            else if(filename.endsWith(FileNameToClassNameImpl.CLASS))
            {
                filename = filename.substring(0, filename.length() - FileNameToClassNameImpl.CLASS.length());
            }
            else
            {
                return null;
            }

            if(filename.length() == 0)
            {
                return null;
            }

            return filename.replaceAll("[^A-Za-z0-9_$]", ".");
        }
    }
}
