/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.util.LinkedList;
import java.util.List;
import org.apache.tools.ant.DirectoryScanner;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.FileSet;

/**
 * An element used in {@link JTigerTask the Ant task} to specify zero or more {@link Fixture fixtures} and/or zero or
 * more <a href="http://ant.apache.org//manual/CoreTypes/fileset.html" target="_blank">file sets</a>. These subelements provide the
 * ability to specify which test fixture classes are to be executed during the test run.
 *
 * @see Fixture
 * @see JTigerTask
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class Fixtures
{
    private final List<Fixture> fixtures;
    private final List<FileSet> filesets;

    /**
     * Create a default <tt>Fixtures</tt>.
     */
    public Fixtures()
    {
        fixtures = new LinkedList<Fixture>();
        filesets = new LinkedList<FileSet>();
    }

    /**
     * {@link Fixture#Fixture() Creates a <tt>Fixture</tt>}, adds it to the list of instances, and returns the instance.
     *
     * @return A created {@link Fixture#Fixture() <tt>Fixture</tt>}.
     */
    public Fixture createFixture()
    {
        final Fixture f = new Fixture();
        fixtures.add(f);
        return f;
    }

    /**
     * Creates a <tt>FileSet</tt>, adds it to the list of instances, and returns the instance.
     *
     * @return A created <tt>FileSet</tt>.
     */
    public FileSet createFileSet()
    {
        final FileSet fs = new FileSet();
        filesets.add(fs);
        return fs;
    }

    List<Fixture> getFixtures()
    {
        return fixtures;
    }

    List<FileSet> getFileSets()
    {
        return filesets;
    }

    String[] toStringArray(final Project project)
    {
        final List<String> names = new LinkedList<String>();

        for(Fixture f : fixtures)
        {
            names.add(f.getClassname());
        }

        for(FileSet f : filesets)
        {
            final DirectoryScanner ds = f.getDirectoryScanner(project);

            final String[] files = ds.getIncludedFiles();

            for(String file : files)
            {
                final FileNameToClassName ftc = FileNameToClassNameFactory.newFileNameToClassName();
                final String className = ftc.toClassName(file);
                if(className != null)
                {
                    names.add(className);
                }
            }
        }

        return names.toArray(new String[names.size()]);
    }
}
