/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.util.List;
import java.util.LinkedList;

/**
 * An element used in {@link JTigerTask the Ant task} to specify how the test result is handled. The name attribute
 * must be a class name that implements the {@link org.jtiger.framework.FixtureResultsHandler} interface. There are
 * four (4) special, case-insensitive values for the name attribute, "~html", "~xml", "~text" and "~failure". These four
 * values are aliases for {@link org.jtiger.report.html.HtmlFixtureResultsHandler},
 * {@link org.jtiger.report.xml.XmlFixtureResultsHandler} and {@link org.jtiger.report.text.TextFixtureResultsHandler}
 * respectively. Each of these four special values require at least one {@link Param} be specified.
 *  
 * @see org.jtiger.framework.FixtureResultsHandler
 * @see JTigerTask
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class Result
{
    private String name;
    private final List<Param> params;

    /**
     * Create a default <tt>Result</tt>.
     */
    public Result()
    {
        params = new LinkedList<Param>();
    }

    /**
     * Returns the name for this result.
     *
     * @return The name for this result.
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the name for this result.
     *
     * @param name The name for this result.
     */
    public void setName(final String name)
    {
        this.name = name;
    }

    /**
     * Creates a param for this result..
     *
     * @return A param for this result.
     */
    public Param createParam()
    {
        final Param p = new Param();
        params.add(p);
        return p;
    }

    List<Param> getParams()
    {
        return params;
    }
}
