/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

/**
 * An exception that may be thrown to indicate that an assertion was not met.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class AssertionException extends RuntimeException
{
    private final String message;

    /**
     * Create a default <tt>AssertionException</tt>.
     */
    public AssertionException()
    {
        message = super.getMessage();
    }

    /**
     * Create a <tt>AssertionException</tt> with the given message.
     *
     * @param message The message of the <tt>AssertionException</tt>.
     */
    public AssertionException(final Object... message)
    {
        final StringBuilder sb = new StringBuilder();

        for(Object o : message)
        {
            sb.append(o);
        }

        this.message = sb.toString();
    }

    /**
     * Create a <tt>AssertionException</tt> with the given cause.
     *
     * @param cause The cause of the <tt>AssertionException</tt>.
     */
    public AssertionException(final Throwable cause)
    {
        super(cause);
        message = super.getMessage();
    }

    /**
     * Create a <tt>AssertionException</tt> with the given message and cause.
     *
     * @param cause The cause of the <tt>AssertionException</tt>.
     * @param message The message of the <tt>AssertionException</tt>.
     */
    public AssertionException(final Throwable cause, final Object... message)
    {
        super(cause);

        final StringBuilder sb = new StringBuilder();

        for(Object o : message)
        {
            sb.append(o);
        }

        this.message = sb.toString();
    }

    /**
     * Returns the message for this exception which may be concatenated by passing multiple arguments to constructors.
     *
     * @return The message for this exception which may be concatenated by passing multiple arguments to constructors.
     */
    public String getMessage()
    {
        return message;
    }
}
