/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import static org.jtiger.assertion.ComparableTesterFactory.newComparableTester;

/**
 * Makes assertions on instances of
 * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/Comparable.html">java.lang.Comparable</a>.
 * This requires the creation of an instance of {@link ObjectFactory} to return instances to use to test.
 * The given {@link ObjectFactory} must meet the its own general contract.
 *
 * @see ObjectFactory
 * @see ObjectFactoryContract
 * @see Comparable
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class Comparable
{
    private Comparable()
    {

    }

    /**
     * Asserts that two equal instances of <tt>java.lang.Comparable</tt> return zero (0) from the <tt>compareTo</tt>
     * method.
     *
     * @param factory The factory to use to return instances for making the assertion.
     * @param message The assertion message.
     * @throws AssertionException If the given <code>ObjectFactory</code> returns instances that are equal but do not
     * return zero (0) from the <tt>compareTo</tt> method, or the compareTo method cannot be invoked through reflection.
     */
    public static void assertEqualComparesToZero(final ObjectFactory<? extends java.lang.Comparable<?>> factory, final Object... message) throws AssertionException
    {
        final ComparableTester tester = newComparableTester(factory);

        if(!tester.equalComparesToZero())
        {
            throw new AssertionException(message);
        }
    }

    /**
     * Asserts that two unequal instances of <tt>java.lang.Comparable</tt> return non-zero from the <tt>compareTo</tt>
     * method.
     *
     * @param factory The factory to use to return instances for making the assertion.
     * @param message The assertion message.
     * @throws AssertionException If the given <code>ObjectFactory</code> returns instances that are unequal and
     * return zero (0) from the <tt>compareTo</tt> method, or the compareTo method cannot be invoked through reflection.
     */
    public static void assertNotEqualNotComparesToZero(final ObjectFactory<? extends java.lang.Comparable<?>> factory, final Object... message) throws AssertionException
    {
        final ComparableTester tester = newComparableTester(factory);

        if(!tester.notEqualNotComparesToZero())
        {
            throw new AssertionException(message);
        }
    }
}
