/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Method;
import java.lang.reflect.InvocationTargetException;

final class ComparableTesterFactory
{
    private static final String COMPARE_TO = "compareTo";

    private ComparableTesterFactory()
    {

    }

    public static ComparableTester newComparableTester(final ObjectFactory<? extends java.lang.Comparable> factory) throws NullPointerException
    {
        if(factory == null)
        {
            throw new NullPointerException();
        }

        return new ComparableTesterImpl(factory);
    }

    private static final class ComparableTesterImpl implements ComparableTester
    {
        private static Method compareTo;

        static
        {
            try
            {
                compareTo = java.lang.Comparable.class.getMethod(ComparableTesterFactory.COMPARE_TO, Object.class);

                if(!compareTo.isAccessible())
                {
                    compareTo.setAccessible(true);
                }
            }
            catch(NoSuchMethodException e)
            {
                throw new AssertionException(e.getMessage(), e);
            }
        }

        private final ObjectFactory<? extends java.lang.Comparable> factory;

        ComparableTesterImpl(final ObjectFactory<? extends java.lang.Comparable> factory)
        {
            this.factory = factory;
        }

        public boolean equalComparesToZero() throws AssertionException
        {
            final java.lang.Comparable<?> x = factory.newInstanceX();
            final java.lang.Comparable<?> y = factory.newInstanceY();

            try
            {
                return ((Integer)compareTo.invoke(x, x)) == 0 && ((Integer)compareTo.invoke(y, y)) == 0;
            }
            catch(IllegalAccessException e)
            {
                throw new AssertionException(e.getMessage(), e);
            }
            catch(InvocationTargetException e)
            {
                throw new AssertionException(e.getMessage(), e);
            }
        }

        public boolean notEqualNotComparesToZero() throws AssertionException
        {
            final java.lang.Comparable<?> x = factory.newInstanceX();
            final java.lang.Comparable<?> y = factory.newInstanceY();

            try
            {
                return ((Integer)compareTo.invoke(x, y)) != 0 && ((Integer)compareTo.invoke(y, x)) != 0;
            }
            catch(IllegalAccessException e)
            {
                throw new AssertionException(e.getMessage(), e);
            }
            catch(InvocationTargetException e)
            {
                throw new AssertionException(e.getMessage(), e);
            }
        }
    }
}
