/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

final class EqualsMethodContractTesterFactory
{
    private EqualsMethodContractTesterFactory()
    {

    }

    static EqualsMethodContractTester newEqualsMethodContractTester(final ObjectFactory<?> factory) throws NullPointerException
    {
        if(factory == null)
        {
            throw new NullPointerException();
        }

        return new EqualsMethodContractTesterImpl(factory);
    }

    private static final class EqualsMethodContractTesterImpl implements EqualsMethodContractTester
    {
        private final ObjectFactory<?> factory;

        EqualsMethodContractTesterImpl(final ObjectFactory<?> factory)
        {
            this.factory = factory;
        }

        public boolean isUnequalToNull()
        {
            final Object x = factory.newInstanceX();
            final Object y = factory.newInstanceY();

            return x != null && !x.equals(null) && y != null && !y.equals(null);
        }

        public boolean isConsistentAcrossInvocations()
        {
            for (int i = 0; i < 20; ++i)
            {
                if(!isUnequalToNull())
                {
                    return false;
                }

                if(!isReflexive())
                {
                    return false;
                }

                if(!isSymmetric())
                {
                    return false;
                }

                if(!isTransitive())
                {
                    return false;
                }

                if(!isUnequalToUnequalInstance())
                {
                    return false;
                }
            }

            return true;
        }

        public boolean isReflexive()
        {
            final Object x = factory.newInstanceX();
            final Object y = factory.newInstanceY();

            return x.equals(x) && y.equals(y);
        }

        public boolean isSymmetric()
        {
            final Object x1 = factory.newInstanceX();
            final Object x2 = factory.newInstanceX();
            final Object y1 = factory.newInstanceY();
            final Object y2 = factory.newInstanceY();

            return x1.equals(x2) && x2.equals(x1) && y1.equals(y2) && y2.equals(y1);
        }

        public boolean isTransitive()
        {
            final Object x1 = factory.newInstanceX();
            final Object x2 = factory.newInstanceX();
            final Object x3 = factory.newInstanceX();
            final Object y1 = factory.newInstanceY();
            final Object y2 = factory.newInstanceY();
            final Object y3 = factory.newInstanceY();

            return x1.equals(x2) && x2.equals(x3) && x1.equals(x3) &&
                   y1.equals(y2) && y2.equals(y3) && y1.equals(y3);
        }

        public boolean isUnequalToUnequalInstance()
        {
            final Object x = factory.newInstanceX();
            final Object y = factory.newInstanceY();

            return !x.equals(y) && !y.equals(x);
        }

        public boolean isUnequalToArbitraryType()
        {
            final Object x = factory.newInstanceX();
            final Object y = factory.newInstanceY();

            final class ArbitraryType
            {
                private ArbitraryType()
                {

                }
            }

            return !x.equals(new ArbitraryType()) && !y.equals(new ArbitraryType());
        }

        public boolean fillsContract()
        {
            return (isUnequalToNull()
                    && isConsistentAcrossInvocations()
                    && isReflexive()
                    && isSymmetric()
                    && isTransitive()
                    && isUnequalToArbitraryType()
                    && isUnequalToUnequalInstance());
        }
    }
}
