/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

final class HashCodeMethodContractTesterFactory
{
    private HashCodeMethodContractTesterFactory()
    {

    }

    static HashCodeMethodContractTester newHashCodeMethodContractTester(final ObjectFactory<?> factory) throws NullPointerException
    {
        if(factory == null)
        {
            throw new NullPointerException();
        }

        return new HashCodeMethodContractTesterImpl(factory);
    }

    private static final class HashCodeMethodContractTesterImpl implements HashCodeMethodContractTester
    {
        private final ObjectFactory<?> factory;

        HashCodeMethodContractTesterImpl(final ObjectFactory<?> factory)
        {
            this.factory = factory;
        }

        public boolean isConsistentResult()
        {
            for(int i = 0; i < 20; i++)
            {
                final Object x = factory.newInstanceX();
                final Object y = factory.newInstanceY();

                if(!(x.hashCode() == x.hashCode() && y.hashCode() == y.hashCode()))
                {
                    return false;
                }
            }

            return true;
        }

        public boolean isEqualOnEqualInstance()
        {
            final Object x1 = factory.newInstanceX();
            final Object x2 = factory.newInstanceX();
            final Object y1 = factory.newInstanceY();
            final Object y2 = factory.newInstanceY();

            return x1.hashCode() == x2.hashCode() && y1.hashCode() == y2.hashCode();
        }

        public boolean fillsContract()
        {
            return isConsistentResult() && isEqualOnEqualInstance();
        }
    }
}
