/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

final class ModifierTesterFactory
{
    private ModifierTesterFactory()
    {

    }

    static ModifierTester newModifierTester()
    {
        return new ModifierTesterImpl();
    }

    private static final class ModifierTesterImpl implements ModifierTester
    {
        ModifierTesterImpl()
        {

        }

        public boolean isAbstract(final Method m)
        {
            return Modifier.isAbstract(m.getModifiers());
        }

        public boolean isAbstract(final Class<?> c)
        {
            return Modifier.isAbstract(c.getModifiers());
        }

        public boolean isFinal(final Method m)
        {
            return Modifier.isFinal(m.getModifiers());
        }

        public boolean isFinal(final Class<?> c)
        {
            return Modifier.isFinal(c.getModifiers());
        }

        public boolean isFinal(final Field f)
        {
            return Modifier.isFinal(f.getModifiers());
        }

        public boolean isNative(final Method m)
        {
            return Modifier.isNative(m.getModifiers());
        }

        public boolean isPrivate(final Method m)
        {
            return Modifier.isPrivate(m.getModifiers());
        }

        public boolean isPrivate(final Constructor<?> c)
        {
            return Modifier.isPrivate(c.getModifiers());
        }

        public boolean isPrivate(final Class<?> c)
        {
            return Modifier.isPrivate(c.getModifiers());
        }

        public boolean isPrivate(final Field f)
        {
            return Modifier.isPrivate(f.getModifiers());
        }

        public boolean isProtected(final Method m)
        {
            return Modifier.isProtected(m.getModifiers());
        }

        public boolean isProtected(final Constructor<?> c)
        {
            return Modifier.isProtected(c.getModifiers());
        }

        public boolean isProtected(final Class<?> c)
        {
            return Modifier.isProtected(c.getModifiers());
        }

        public boolean isProtected(final Field f)
        {
            return Modifier.isProtected(f.getModifiers());
        }

        public boolean isPublic(final Method m)
        {
            return Modifier.isPublic(m.getModifiers());
        }

        public boolean isPublic(final Constructor<?> c)
        {
            return Modifier.isPublic(c.getModifiers());
        }

        public boolean isPublic(final Class<?> c)
        {
            return Modifier.isPublic(c.getModifiers());
        }

        public boolean isPublic(final Field f)
        {
            return Modifier.isPublic(f.getModifiers());
        }

        public boolean isDefaultAccess(final Method m)
        {
            return !Modifier.isPrivate(m.getModifiers()) &&
                    !Modifier.isProtected(m.getModifiers()) &&
                    !Modifier.isPublic(m.getModifiers());
        }

        public boolean isDefaultAccess(final Constructor<?> c)
        {
            return !Modifier.isPrivate(c.getModifiers()) &&
                    !Modifier.isProtected(c.getModifiers()) &&
                    !Modifier.isPublic(c.getModifiers());
        }

        public boolean isDefaultAccess(final Class<?> c)
        {
            return !Modifier.isPrivate(c.getModifiers()) &&
                    !Modifier.isProtected(c.getModifiers()) &&
                    !Modifier.isPublic(c.getModifiers());
        }

        public boolean isDefaultAccess(final Field f)
        {
            return !Modifier.isPrivate(f.getModifiers()) &&
                    !Modifier.isProtected(f.getModifiers()) &&
                    !Modifier.isPublic(f.getModifiers());
        }

        public boolean isStatic(final Method m)
        {
            return Modifier.isStatic(m.getModifiers());
        }

        public boolean isStatic(final Class<?> c)
        {
            return Modifier.isStatic(c.getModifiers());
        }

        public boolean isStatic(final Field f)
        {
            return Modifier.isStatic(f.getModifiers());
        }

        public boolean isStrictfp(final Class<?> c)
        {
            return Modifier.isStrict(c.getModifiers());
        }

        public boolean isSynchronized(final Method m)
        {
            return Modifier.isSynchronized(m.getModifiers());
        }

        public boolean isTransient(final Field f)
        {
            return Modifier.isTransient(f.getModifiers());
        }

        public boolean isVolatile(final Field f)
        {
            return Modifier.isVolatile(f.getModifiers());
        }
    }
}
