/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.util.HashSet;
import java.util.Set;

final class ObjectFactoryContractTesterFactory
{
    private ObjectFactoryContractTesterFactory()
    {

    }

    static ObjectFactoryContractTester newObjectFactoryContractTester(final ObjectFactory<?> factory) throws NullPointerException
    {
        if(factory == null)
        {
            throw new NullPointerException();
        }

        return new ObjectFactoryContractTesterImpl(factory);
    }

    private static final class ObjectFactoryContractTesterImpl implements ObjectFactoryContractTester
    {
        private final ObjectFactory<?> factory;

        ObjectFactoryContractTesterImpl(final ObjectFactory<?> factory)
        {
            this.factory = factory;
        }

        public boolean isXConsistentlyNewInstance()
        {
            final Object x1 = factory.newInstanceX();

            if(x1 == null)
            {
                return false;
            }

            for(int i = 0; i < 20; i++)
            {
                final Object x2 = factory.newInstanceX();

                if(x1 == x2)
                {
                    return false;
                }
            }

            return true;
        }

        public boolean isYConsistentlyNewInstance()
        {
            final Object y1 = factory.newInstanceY();

            if(y1 == null)
            {
                return false;
            }

            for(int i = 0; i < 20; i++)
            {
                final Object y2 = factory.newInstanceY();

                if(y1 == y2)
                {
                    return false;
                }
            }

            return true;
        }

        public boolean isXConsistentlyEqual()
        {
            Object x1 = factory.newInstanceX();

            if(x1 == null)
            {
                return false;
            }

            for(int i = 0; i < 20; i++)
            {
                final Object x2 = factory.newInstanceX();

                if(!x1.equals(x2))
                {
                    return false;
                }

                x1 = x2;
            }

            return true;
        }

        public boolean isYConsistentlyEqual()
        {
            Object y1 = factory.newInstanceY();

            if(y1 == null)
            {
                return false;
            }

            for(int i = 0; i < 20; i++)
            {
                final Object y2 = factory.newInstanceY();

                if(!y1.equals(y2))
                {
                    return false;
                }

                y1 = y2;
            }

            return true;
        }

        public boolean isXYConsistentlyUnequal()
        {
            final Set<Object> xs = new HashSet<Object>();
            final Set<Object> ys = new HashSet<Object>();

            for(int i = 0; i < 20; i++)
            {
                final Object x = factory.newInstanceX();
                final Object y = factory.newInstanceY();

                if(x == null || y == null)
                {
                    return false;
                }

                xs.add(x);
                ys.add(y);

                if(xs.contains(y) || ys.contains(x))
                {
                    return false;
                }
            }

            return true;
        }

        public boolean fillsContract()
        {
            return isXConsistentlyNewInstance() &&
                    isYConsistentlyNewInstance() &&
                    isXConsistentlyEqual() &&
                    isYConsistentlyEqual() &&
                    isXYConsistentlyUnequal();
        }
    }
}
