/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

final class SerializationTesterFactory
{
    private SerializationTesterFactory()
    {

    }

    static SerializationTester newSerializationTester(final Serializable s) throws NullPointerException
    {
        if(s == null)
        {
            throw new NullPointerException();
        }

        return new SerializationTesterImpl(s);
    }

    private static final class SerializationTesterImpl implements SerializationTester
    {
        private final Serializable s;

        SerializationTesterImpl(final Serializable s)
        {
            this.s = s;
        }

        public boolean serializes()
        {
            try
            {
                serializeDeserialize(s);

                return true;
            }
            catch(IOException ioe)
            {
                return false;
            }
            catch(ClassNotFoundException cnfe)
            {
                return false;
            }
        }

        public boolean serializesSame()
        {
            try
            {
                final Object o = serializeDeserialize(s);

                return o == s;
            }
            catch(IOException ioe)
            {
                return false;
            }
            catch(ClassNotFoundException cnfe)
            {
                return false;
            }
        }

        public boolean serializesEqual()
        {
            try
            {
                final Object o = serializeDeserialize(s);

                return o.equals(s);
            }
            catch(IOException ioe)
            {
                return false;
            }
            catch(ClassNotFoundException cnfe)
            {
                return false;
            }
        }

        private Object serializeDeserialize(final Serializable serializable) throws IOException, ClassNotFoundException
        {
            final ByteArrayOutputStream baout = new ByteArrayOutputStream();

            final ObjectOutputStream out = new ObjectOutputStream(baout);

            out.writeObject(serializable);

            final ByteArrayInputStream bain = new ByteArrayInputStream(baout.toByteArray());

            final ObjectInputStream in = new ObjectInputStream(bain);

            return in.readObject();
        }
    }
}
