/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

final class ArgsFactory
{
    private ArgsFactory()
    {

    }

    static Args newArgs(final FixturesRunnerConfig fixturesRunnerConfig, final Class<? extends FixtureResultsHandler> resultHandlerClass, final ReadOnlyArray<String> resultHandlerParameters) throws NullPointerException
    {
        return new ArgsImpl(fixturesRunnerConfig, resultHandlerClass, resultHandlerParameters);
    }

    private static final class ArgsImpl implements Args
    {
        private final FixturesRunnerConfig fixturesRunnerConfig;
        private final Class<? extends FixtureResultsHandler> resultHandlerClass;
        private final  ReadOnlyArray<String> resultHandlerParameters;

        ArgsImpl(final FixturesRunnerConfig fixturesRunnerConfig, final Class<? extends FixtureResultsHandler> resultHandlerClass,  final ReadOnlyArray<String> resultHandlerParameters)
        {
            this.fixturesRunnerConfig = fixturesRunnerConfig;
            this.resultHandlerClass = resultHandlerClass;
            this.resultHandlerParameters = resultHandlerParameters;
        }

        public FixturesRunnerConfig getFixturesRunnerConfig()
        {
            return fixturesRunnerConfig;
        }

        public Class<? extends FixtureResultsHandler> getResultHandlerClass()
        {
            return resultHandlerClass;
        }

        public  ReadOnlyArray<String> getResultHandlerParameters()
        {
            return resultHandlerParameters;
        }

        @Override
        public String toString()
        {
            final StringBuilder sb = new StringBuilder();

            sb.append('[');
            sb.append(fixturesRunnerConfig);
            sb.append("][");
            sb.append(resultHandlerClass);
            sb.append("][");
            sb.append(resultHandlerParameters);
            sb.append(']');

            return sb.toString();
        }

        @Override
        public boolean equals(final Object o)
        {
            if(this == o)
            {
                return true;
            }

            if(o == null || o.getClass() != ArgsImpl.class)
            {
                return false;
            }

            final ArgsImpl a = (ArgsImpl)o;

            return (fixturesRunnerConfig == null ? a.fixturesRunnerConfig == null : fixturesRunnerConfig.equals(a.fixturesRunnerConfig)) &&
                    (resultHandlerClass == null ? a.resultHandlerClass == null : resultHandlerClass == a.resultHandlerClass) &&
                    (resultHandlerParameters == null ? a.resultHandlerParameters == null : resultHandlerParameters == a.resultHandlerParameters);
        }

        @Override
        public int hashCode()
        {
            final int oddPrime = 461;
            int result = 73;

            if(fixturesRunnerConfig != null)
            {
                result = result * oddPrime + fixturesRunnerConfig.hashCode();
            }

            if(resultHandlerClass != null)
            {
                result = result * oddPrime + resultHandlerClass.hashCode();
            }

            if(resultHandlerParameters != null)
            {
                result = result * oddPrime + resultHandlerParameters.hashCode();
            }

            return result;
        }
    }
}
