/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Used to annotate {@link Test test case methods} or test fixture classes by specifying which category(ies) it is in.
 * A test case is in all categories that form the union of the annotations present on the test case method and on the
 * enclosing test fixture class. A test case has no requirement to be in a category, in which case, this annotation
 * should not be present on the test case method or its enclosing test fixture class.
 * <br/>
 * Example:<br/>
<pre>
    &#64Fixture("Demonstration")
    &#64Category({"Category1", "Category2"})
    class MyTestFixture
    {
        &#64Test
        &#64Category("Category3")
        public void myTestCase()
        {

        }
    }
</pre>

 * The test case represented by the method, <code>MyTestFixture.myTestCase</code> is in 3 categories,
 * <code>Category1</code>, <code>Category2</code>, and <code>Category3</code>.
 *
 * @see Test
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
@Documented
@Target({ElementType.TYPE, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface Category
{
    /**
     * Returns the categories that the test case is in.
     *
     * @return The categories that the test case is in.
     */
    String[] value();
}
