/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * Provides a mapping between user-friendly alias names for class names that are used by the framework.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface ClassAliasMapping
{
    /**
     * Returns the class name for the given alias. May return <code>null</code> if there is no class name mapping for
     * the given alias.
     *
     * @param alias The alias to obtain the class name for.
     * @return The class name for the given alias. May return <code>null</code> if there is no class name mapping for
     * the given alias.
     * @throws NullPointerException If <code>alias</code> is <code>null</code>.
     */
    String getMappedClassName(String alias) throws NullPointerException;

    /**
     * Returns all the aliases that are mapped to a class name.
     *
     * @return All the aliases that are mapped to a class name.
     */
    ReadOnlyArray<String> getAliases();
}
