/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

final class ClassConstructionFactory
{
    private ClassConstructionFactory()
    {

    }

    static <T> ClassConstruction newClassConstruction()
    {
        return new ClassConstructionImpl<T>();
    }

    private static final class ClassConstructionImpl<T> implements ClassConstruction
    {
        ClassConstructionImpl()
        {

        }

        public <T> T construct(final Class<? extends T> c)
                throws InstantiationException, IllegalAccessException, InvocationTargetException
        {
            if(c == null)
            {
                return null;
            }

            try
            {
                final Constructor<? extends T> strCtor = c.getDeclaredConstructor(String.class);

                if(!strCtor.isAccessible())
                {
                    strCtor.setAccessible(true);
                }

                return strCtor.newInstance(c.getCanonicalName());
            }
            catch(NoSuchMethodException e1)
            {
                try
                {
                    final Constructor<? extends T> noArgsCtor = c.getDeclaredConstructor();

                    if(!noArgsCtor.isAccessible())
                    {
                        noArgsCtor.setAccessible(true);
                    }

                    return noArgsCtor.newInstance();
                }
                catch(NoSuchMethodException e2)
                {
                    return null;
                }
            }
        }
    }
}
