/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestFailureFactory.newTestFailure;
import static org.jtiger.framework.TestIgnoredFactory.newTestIgnored;

/**
 * The default implementation to handle fixture results sends output to
 * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/System.html#out">the standard output stream</a> with a summary of the result.
 * The summary contains the number of test case results of success, failure and ignored.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class DefaultFixtureResultsHandlerFactory
{
    private DefaultFixtureResultsHandlerFactory()
    {

    }

    /**
     * Returns a new instance of the default implementation to handle fixture results.
     *
     * @return A new instance of the default implementation to handle fixture results.
     */
    public static FixtureResultsHandler newDefaultFixtureResultsHandler()
    {
        return new DefaultFixtureResultsHandlerImpl();
    }

    private static final class DefaultFixtureResultsHandlerImpl implements FixtureResultsHandler
    {
        DefaultFixtureResultsHandlerImpl()
        {

        }

        public void handleResult(final FixtureResults results, final ReadOnlyArray<String> params)
        {
            int failures = 0;
            int successes = 0;
            int ignored = 0;

            for(FixtureResult result : results)
            {
                for(TestResult tr : result)
                {
                    if(tr.getTestResultType() == SUCCESS)
                    {
                        successes++;
                    }
                    else if(newTestFailure().isFailure(tr.getTestResultType()))
                    {
                        failures++;
                    }
                    else if(newTestIgnored().isIgnored(tr.getTestResultType()))
                    {
                        ignored++;
                    }
                }
            }

            System.out.println(DefaultFixtureResultsHandlerMessage.message(successes, failures, ignored));
        }
    }
}
