/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Method;

/**
 * Provides a default implementation of defining a unit test case method.
 * This implementation determines a test case method as having the {@link Test} annotation present.
 *
 * @see TestDefinition
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class DefaultTestDefinitionFactory
{
    private DefaultTestDefinitionFactory()
    {

    }

    /**
     * Returns a new instance of the definition of a unit test case method.
     *
     * @return A new instance of the definition of a unit test case method.
     */
    public static TestDefinition newDefaultTestDefinition()
    {
        return new DefaultTestDefinitionImpl();
    }

    private static final class DefaultTestDefinitionImpl implements TestDefinition
    {
        DefaultTestDefinitionImpl()
        {

        }

        public boolean isTest(final Method m)
        {
            if(m == null)
            {
                return false;
            }

            return m.isAnnotationPresent(Test.class);            
        }
    }
}
