/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.Serializable;
import java.util.ListIterator;

/**
 * Represents the result of the execution of all the test case methods in a test fixture class.
 * i.e. zero or many sequentially ordered instances of {@link TestResult}.
 *
 * @see TestResult
 * @see FixtureResults
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface FixtureResult extends Iterable<TestResult>, Serializable
{
    /**
     * Returns the test case method result at the given index.
     *
     * @param index The index of the test case method result to return.
     * @return The test case method result at the given index.
     * @throws IndexOutOfBoundsException If there isn't a test case method result at the given index.
     */
    TestResult get(int index) throws IndexOutOfBoundsException;

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the test case
     * method results.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the test case
     * method results.
     */
    ListIterator<TestResult> listIterator();

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the test case
     * method results from the given index.
     *
     * @param index The index from which to obtain a List iterator for.
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the test case
     * method results from the given index.
     * @throws IndexOutOfBoundsException If there isn't a test case method result to start iterating from at the given
     * index.
     */
    ListIterator<TestResult> listIterator(int index) throws IndexOutOfBoundsException;

    /**
     * Returns the number of test case method results that the fixture result contains.
     *
     * @return The number of test case method results that the fixture result contains.
     */
    int size();

    /**
     * Returns the test case method results as an array.
     * Modification to the array does not affect the underlying fixture result.
     *
     * @return The test case method results as an array.
     */
    TestResult[] toArray();
}
