/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;
import static org.jtiger.framework.UnmodifiableListIteratorFactory.unmodifiableListIterator;
import static org.jtiger.framework.UnmodifiableIteratorFactory.unmodifiableIterator;

final class FixtureResultFactory
{
    private FixtureResultFactory()
    {

    }

    public static FixtureResult newFixtureResult(final List<TestResult> results) throws NullPointerException
    {
        if(results == null)
        {
            throw new NullPointerException();
        }

        return new FixtureResultImpl(results);
    }

    private static final class FixtureResultImpl implements FixtureResult
    {
        private static final long serialVersionUID = 2L;

        private final List<TestResult> results;

        FixtureResultImpl(final List<TestResult> results)
        {
            this.results = results;
        }

        public TestResult get(final int index)
        {
            return results.get(index);
        }

        public ListIterator<TestResult> listIterator()
        {
            return unmodifiableListIterator(results.listIterator());
        }

        public ListIterator<TestResult> listIterator(final int index)
        {
            return unmodifiableListIterator(results.listIterator(index));
        }

        public int size()
        {
            return results.size();
        }

        public TestResult[] toArray()
        {
            return results.toArray(new TestResult[results.size()]);
        }

        public Iterator<TestResult> iterator()
        {
            return unmodifiableIterator(results.iterator());
        }

        @Override
        public String toString()
        {
            return results.toString();
        }

        @Override
        public boolean equals(final Object o)
        {
            if(this == o)
            {
                return true;
            }

            if(o == null || o.getClass() != FixtureResultImpl.class)
            {
                return false;
            }

            final FixtureResultImpl f = (FixtureResultImpl)o;

            return results.equals(f.results);
        }

        @Override
        public int hashCode()
        {
            final int oddPrime = 461;
            int result = 73;

            result = result * oddPrime + results.hashCode();

            return result;
        }
    }
}
