/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.Serializable;
import java.util.ListIterator;

/**
 * Represents the fixture results of the execution of all the test case methods in a test fixture class.
 * i.e. zero or many sequentially ordered instances of {@link FixtureResult}.
 *
 * @see FixtureResult
 * @see FixturesRunner
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface FixtureResults extends Iterable<FixtureResult>, Serializable
{
    /**
     * Returns the fixture result at the given index.
     *
     * @param index The index of the fixture result to return.
     * @return The fixture result at the given index.
     * @throws IndexOutOfBoundsException If there isn't a fixture result at the given index.
     */
    FixtureResult get(int index) throws IndexOutOfBoundsException;

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the fixture
     * results.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the fixture
     * results.
     */
    ListIterator<FixtureResult> listIterator();

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the fixture
     * results from the given index.
     *
     * @param index The index from which to obtain a List iterator for.
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/util/ListIterator.html">List iterator</a> to iterate over the fixture
     * results from the given index.
     * @throws IndexOutOfBoundsException If there isn't a fixture result to start iterating from at the given index.
     */
    ListIterator<FixtureResult> listIterator(int index) throws IndexOutOfBoundsException;

    /**
     * Returns the number of fixture results that the fixture result contains.
     *
     * @return The number of fixture results that the fixture result contains.
     */
    int size();

    /**
     * Returns the fixture results as an array.
     * Modification to the array does not affect the underlying fixtures result.
     *
     * @return The fixture results as an array.
     */
    FixtureResult[] toArray();
}
