/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * Handle the result of a test run. Typical implementations might present the result to an end user using a graphical
 * interface.
 * <br/>
 * Custom implementations can be passed on {@link FixturesRunnerMain the command} line using
 * {@link FixturesRunnerMain#ARG_RESULT the appropriate argument} and
 * {@link FixturesRunnerMain#ARG_RESULT_PARAMETERS the argument for the parameters}.
 *
 * @see DefaultFixtureResultsHandlerFactory
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface FixtureResultsHandler
{
    /**
     * Handle the result of a test run. Typical implementations might present the result to the user in some kind of
     * interface.
     *
     * @param results The test results to handle.
     * @param params Parameters passed from an external source.
     * @throws FixtureResultsHandlerException If an error occurs while handling the test result.
     */
    void handleResult(FixtureResults results,  ReadOnlyArray<String> params) throws FixtureResultsHandlerException;
}
