/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * Executes a test configuration and returns the result of the test run.
 * This type is to be considered the entry point into the underlying test framework. i.e. this type provides the highest
 * level of abstraction from the details of a test execution.
 *
 * @see FixturesRunnerFactory
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface FixturesRunner
{
    /**
     * Executes a test configuration and returns the result of the test run.
     *
     * @param config The test configuration to execute with.
     * @return The result of the test run.
     * @throws RunnerException If an error occurs during creation of the test fixture classes.
     * @throws RunnerException If an error occurs during execution of the test fixture classes.
     * @throws NullPointerException If <code>config</code> is <code>null</code>.
     */
    FixtureResults run(FixturesRunnerConfig config)
        throws RunnerException, RunnerException, NullPointerException;
}
