/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.Serializable;

/**
 * Represents the configuration for a test execution.
 *
 * @see FixturesRunnerConfigFactory
 * @see FixturesRunner#run(FixturesRunnerConfig)
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface FixturesRunnerConfig extends Serializable
{
    /**
     * Returns the test fixture classes to run during test execution.
     * The fixture classes should have either; a no argument constructor, or a constructor that takes a single
     * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> argument.
     *
     * @return The test fixture classes to run during test execution.
     */
    ReadOnlyArray<Class<?>> getFixtureClasses();

    /**
     * Returns the type that defines a test. This method may return <code>null</code>.
     * This class should have either; a no argument constructor, or a constructor that takes a single
     * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> argument.
     *
     * @return The type that defines a test. This method may return <code>null</code>.
     */
    Class<? extends TestDefinition> getDefinitionClass();

    /**
     * Returns the type that executes test case set up and tear down. This method may return <code>null</code>.
     * This class should have either; a no argument constructor, or a constructor that takes a single
     * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> argument.
     *
     * @return The type that executes test case set up and tear down. This method may return <code>null</code>.
     */
    Class<? extends SetUpTearDown> getSutdClass();

    /**
     * Returns <code>true</code> if the test run is to halt execution when a test case gives a result of
     * {@link TestResultType#FAILURE}, {@link TestResultType#FAILURE_SETUP}, or {@link TestResultType#FAILURE_TEARDOWN},
     * <code>false</code> otherwise.
     *
     * @return <code>true</code> if the test run is to halt execution when a test case gives a result of
     * {@link TestResultType#FAILURE}, {@link TestResultType#FAILURE_SETUP}, or {@link TestResultType#FAILURE_TEARDOWN},
     * <code>false</code> otherwise.
     */
    boolean isHaltOnFailure();

    /**
     * Returns regular expressions representing the categories to execute during the test run.
     * An empty array represents that all categories should be executed.
     *
     * @return Regular expressions representing the categories to execute during the test run.
     */
    ReadOnlyArray<String> getCategories();
}
