/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import static org.jtiger.framework.FixtureRunnerFactory.newFixtureRunner;
import static org.jtiger.framework.FixtureResultsFactory.newFixtureResults;

/**
 * Returns instances of {@link FixturesRunner}.
 *
 * @see FixturesRunner
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class FixturesRunnerFactory
{
    private FixturesRunnerFactory()
    {

    }

    /**
     * Returns a new instance of {@link FixturesRunner}.
     *
     * @return A new instance of {@link FixturesRunner}.
     */
    public static FixturesRunner newFixturesRunner()
    {
        return new FixturesRunnerImpl();
    }

    private static final class FixturesRunnerImpl implements FixturesRunner
    {
        FixturesRunnerImpl()
        {

        }

        public FixtureResults run(final FixturesRunnerConfig config)
                throws RunnerException, NullPointerException
        {
            if(config == null)
            {
                throw new NullPointerException();
            }

            final ReadOnlyArray<Class<?>> fixtureClasses = config.getFixtureClasses();
            final Class<? extends TestDefinition> definitionClass = config.getDefinitionClass();
            final Class<? extends SetUpTearDown> sutdClass = config.getSutdClass();
            final boolean haltOnFailure = config.isHaltOnFailure();
            final ReadOnlyArray<String> categories = config.getCategories();

            if(fixtureClasses == null)
            {
                return newFixtureResults(new ArrayList<FixtureResult>(0));
            }

            final List<FixtureResult> results = new LinkedList<FixtureResult>();

            final FixtureRunner runner = newFixtureRunner();

            for(final Class<?> fixtureClass : fixtureClasses)
            {
                final FixtureResult result = runner.run(fixtureClass, definitionClass, sutdClass, haltOnFailure, categories);
                results.add(result);
            }

            return newFixtureResults(results);
        }
    }
}

