/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Used to annotate a test fixture class or {@link Test test case method} to indicate that it should be ignored during
 * test execution. An annotated test case method or as a member of an annotated test fixture class will have a test case
 * result of {@link TestResultType#IGNORED_ANNOTATED}.
 *
 * @see Test
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
@Documented
@Target({ElementType.TYPE, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface Ignore
{
    /**
     * Returns a reason for ignoring the test fixture or test method.
     *
     * @return A reason for ignoring the test fixture or test method.
     */
    String value() default "";
}
