/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Method;
import java.util.regex.Pattern;

final class MethodCategoryFactory
{
    private MethodCategoryFactory()
    {

    }

    static MethodCategory newMethodCategory()
    {
        return new MethodCategoryImpl();
    }

    private static final class MethodCategoryImpl implements MethodCategory
    {
        MethodCategoryImpl()
        {

        }

        public boolean isInAnyCategories(final Method m, final ReadOnlyArray<String> categories) throws NullPointerException
        {
            if(m == null)
            {
                throw new NullPointerException();
            }

            if(categories == null || categories.length() == 0)
            {
                return true;
            }

            for(String category : categories)
            {
                if(isInAnyCategory(m, category))
                {
                    return true;
                }
            }

            return false;
        }

        private boolean isInAnyCategory(final Method m, final String category)
        {
            Category c = m.getAnnotation(Category.class);
            final Pattern p = Pattern.compile(category);

            if(c != null)
            {
                for(String s : c.value())
                {
                    if(p.matcher(s).matches())
                    {
                        return true;
                    }
                }
            }

            c = m.getDeclaringClass().getAnnotation(Category.class);

            if(c != null)
            {
                for(String s : c.value())
                {
                    if(p.matcher(s).matches())
                    {
                        return true;
                    }
                }
            }

            return false;
        }
    }
}
