/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * An exception that is thrown when a structure's position is specified that is outside of the permissible bounds for
 * that structure.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218</i>
 */
public final class PositionOutOfBoundsException extends RuntimeException implements Positionable
{
    private int position;

    /**
     * Construct a <tt>PositionOutOfBoundsException</tt> with the given position.
     *
     * @param position The position that is outside of the permissible bounds.
     */
    public PositionOutOfBoundsException(final int position)
    {
        this.position = position;
    }

    /**
     * Construct a <tt>PositionOutOfBoundsException</tt> with the given position and message.
     *
     * @param position The position that is outside of the permissible bounds.
     * @param message The exception message.
     */
    public PositionOutOfBoundsException(final int position, final String message)
    {
        super(message);

        this.position = position;
    }

    /**
     * Construct a <tt>PositionOutOfBoundsException</tt> with the given position and cause.
     *
     * @param position The position that is outside of the permissible bounds.
     * @param cause The cause of this exception.
     */
    public PositionOutOfBoundsException(final int position, final Throwable cause)
    {
        super(cause);

        this.position = position;
    }


    /**
     * Construct a <tt>PositionOutOfBoundsException</tt> with the given position, message and cause.
     *
     * @param position The position that is outside of the permissible bounds.
     * @param message The exception message.
     * @param cause The cause of this exception.
     */
    public PositionOutOfBoundsException(final int position, final String message, final Throwable cause)
    {
        super(message, cause);

        this.position = position;
    }

    /**
     * Returns the position that is outside of the permissible bounds for this structure.
     *
     * @return The position that is outside of the permissible bounds for this structure.
     */
    public int getPosition()
    {
        return position;
    }
}
