/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * An iterator that has the concept of a position during iteration. The position can be conceptualised as a point
 * between two elements in the sequence that is being iterated. An iterator that is traversing from the start will be in
 * position zero (0). An iterator is capable of being in a position beyond the last element of the sequence. That is to
 * say, the highest possible value of the position of the iterator is equal to the length of the sequence (not the
 * index of the last element).
 * A sequence can be conceptualised as:<br/>
 * <pre>
 * 0   1   2   3   4   5   6   7   8    position in sequence
 * |___|___|___|___|___|___|___|___|
 * |   |   |   |   |   |   |   |   |
 * | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 |    sequence element index
 * |___|___|___|___|___|___|___|___|
 * </pre>
 *
 * @deprecated Use {@link Positionable} instead.
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218</i>
 */
@Deprecated
public interface PositionableIterator
{
    /**
     * Returns the position of this iterator. The position is conceptually between elements in a sequence, unless it is
     * at the start or end, in which case,  this method returns zero or the length of the sequence respectively.
     *
     * @return The position of this iterator in a sequence.
     */
    int getPosition();
}
