/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.Serializable;

/**
 * A wrapper type typically backed by an array that provides read-only access to the elements of the array.
 *
 * @see SequenceFactory
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface ReadOnlyArray<E> extends Iterable<E>, Cloneable, Serializable
{
    /**
     * Returns the element at the given index in the underlying array.
     *
     * @param index The index of the element to return.
     * @return The element at the specified index.
     * @throws ArrayIndexOutOfBoundsException If the given index is out of range
     * (<code>index < 0 || index >= {@link #length length()}</code>).
     */
    E get(int index) throws ArrayIndexOutOfBoundsException;

    /**
     * Returns the number of elements held in this structure.
     *
     * @return The number of elements held in this structure.
     */
    int length();

    /**
     * Returns a clone of this <tt>ReadOnlyArray</tt> which is backed by a cloned array.
     *
     * @return A clone of this <tt>ReadOnlyArray</tt> which is backed by a cloned array.
     */
    ReadOnlyArray<E> clone();
}
