/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.Arrays;
import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.List;

/**
 * Returns instances of {@link ReadOnlyArray} which are backed by a raw array that cannot be modified.
 *
 * @deprecated Use {@link SequenceFactory} instead.
 * @see SequenceFactory
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
@Deprecated
public final class ReadOnlyArrayFactory
{
    private ReadOnlyArrayFactory()
    {

    }

    /**
     * Returns a new instance of {@link ReadOnlyArray}.
     *
     * @deprecated Use {@link SequenceFactory#newSequence} instead.
     * @param a The array that backs the returned {@link ReadOnlyArray}.
     * @return A new instance of {@link ReadOnlyArray}.
     * @throws NullPointerException If <code>a</code> is <code>null</code>.
     */
    @Deprecated
    public static <E> ReadOnlyArray<E> newReadOnlyArray(final E... a) throws NullPointerException
    {
        if(a == null)
        {
            throw new NullPointerException();
        }

        return new ReadOnlyArrayImpl<E>(a);
    }

    /**
     * Returns a new instance of {@link ReadOnlyArray}.
     *
     * @param l The {@link List} that backs the returned {@link ReadOnlyArray}.
     * @return A new instance of {@link ReadOnlyArray}.
     * @throws NullPointerException If <code>l</code> is <code>null</code>.
     */
    public static <E> ReadOnlyArray<E> newReadOnlyArray(final List<E> l) throws NullPointerException
    {
        if(l == null)
        {
            throw new NullPointerException();
        }

        return new ListReadOnlyArray<E>(l);
    }

    private static final class ReadOnlyArrayImpl<E> implements ReadOnlyArray<E>
    {
        private static final long serialVersionUID = 2L;

        private final E[] a;

        ReadOnlyArrayImpl(final E... a)
        {
            this.a = a;
        }

        public E get(final int index) throws ArrayIndexOutOfBoundsException
        {
            if(index < 0 || index >= a.length)
            {
                throw new ArrayIndexOutOfBoundsException(index);
            }
            
            return a[index];
        }

        public int length()
        {
            return a.length;
        }

        public Iterator<E> iterator()
        {
            return new IteratorImpl();
        }

        @Override
        public String toString()
        {
            return Arrays.toString(a);
        }

        @Override
        public boolean equals(final Object o)
        {
            if(this == o)
            {
                return true;
            }

            if(o == null || o.getClass() != ReadOnlyArrayImpl.class)
            {
                return false;
            }

            return Arrays.equals(((ReadOnlyArrayImpl)o).a, a);
        }

        @Override
        public int hashCode()
        {
            return Arrays.hashCode(a);
        }

        public ReadOnlyArray<E> clone()
        {
            return new ReadOnlyArrayImpl<E>(a.clone());
        }

        private final class IteratorImpl implements Iterator<E>
        {
            private int counter;

            IteratorImpl()
            {

            }

            public boolean hasNext()
            {
                return counter < a.length;
            }

            public E next()
            {
                if(counter < a.length)
                {
                    return a[counter++];
                }
                else
                {
                    throw new NoSuchElementException();
                }
            }

            public void remove()
            {
                throw new UnsupportedOperationException();
            }
        }
    }

    private static final class ListReadOnlyArray<E> implements ReadOnlyArray<E>
    {
        private static final long serialVersionUID = 2L;

        private List<E> l;

        ListReadOnlyArray(final List<E> l)
        {
            this.l = l;
        }

        public E get(final int index) throws ArrayIndexOutOfBoundsException
        {
            if(index < 0 || index >= l.size())
            {
                throw new ArrayIndexOutOfBoundsException(index);
            }

            return l.get(index);
        }

        public int length()
        {
            return l.size();
        }

        public ReadOnlyArray<E> clone()
        {
            return newReadOnlyArray(l);
        }

        public Iterator<E> iterator()
        {
            return l.iterator();
        }

        @Override
        public String toString()
        {
            return Arrays.toString(l.toArray());
        }

        @Override
        public boolean equals(final Object o)
        {
            if(this == o)
            {
                return true;
            }

            if(o == null || o.getClass() != ListReadOnlyArray.class)
            {
                return false;
            }

            return ((ListReadOnlyArray)o).l.equals(l);
        }

        @Override
        public int hashCode()
        {
            return l.hashCode();
        }
    }
}
