/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * An iterator of a {@link org.jtiger.framework.Sequence} that permits bidirectional traversal.
 *
 * @see org.jtiger.framework.Sequence
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218</i>
 */
public interface SequenceIterator<E> extends Positionable, Iterator<E>
{
    /**
     * Returns <code>true</code> if this iterator has a previous element that can be retrieved, <code>false</code>
     * otherwise.
     *
     * @return <code>true</code> if this iterator has a previous element that can be retrieved, <code>false</code>
     * otherwise.
     */
    boolean hasPrevious();

    /**
     * Returns the previous element from this iterator.
     *
     * @return The previous element from this iterator.
     * @throws NoSuchElementException If there is no previous element in this iterator. It is guaranteed that if
     * {@link #hasPrevious()} has returned <code>true</code>, then this exception will not be thrown. Conversely, if
     * {@link #hasPrevious()} has returned <code>false</code>, then this exception will certainly be thrown.
     */
    E previous() throws NoSuchElementException;
}
