/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * Provides an implementation of setting up and tearing down a test fixture.
 * <br/>
 * It is not guaranteed which order the framework executes the methods during either of these operations.
 * Custom implementations can be passed on {@link FixturesRunnerMain the command} line using
 * {@link FixturesRunnerMain#ARG_SUTD_CLASS the appropriate argument}.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface SetUpTearDown
{
    /**
     * Set up the given test fixture.
     *
     * @param fixture The test fixture to set up.
     * @throws SetUpException If an error occurs while setting up the test case.
     */
    void setUp(Object fixture) throws SetUpException;

    /**
     * Tear down the given test fixture.
     *
     * @param fixture The test fixture to tear down.
     * @throws TearDownException If an error occurs while tearing down the test case.
     */
    void tearDown(Object fixture) throws TearDownException;
}
