/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Used to annotate a test case method in a test fixture class. This indicates to the framework that the method should
 * be executed during test execution. A test case method should take no arguments.
 * <br/>
 * <li>If the test fixture cannot be {@link SetUp setup}, the test case results in
 * {@link TestResultType#FAILURE_SETUP failure (setup)}.</li>
 * <li>If the test fixture cannot be {@link TearDown torn down}, regardless of its success or failure during execution,
 * the test case results in {@link TestResultType#FAILURE_TEARDOWN failure (tear down)}.</li>
 * <li>If the test case method throws an exception that is wasn't {@link ExpectException expecting}, the test case
 * results in {@link TestResultType#FAILURE failure}</li>.
 * <li>If the test case method throws an exception that it was {@link ExpectException expecting}, the test case results
 * in {@link TestResultType#SUCCESS success}</li>.
 * <li>If the test case method does not throw an exception that is was {@link ExpectException expecting}, the test case
 * results in {@link TestResultType#FAILURE failure}.</li>
 * <li>If the test case method cannot be executed because it does not satisfy the criteria for being a test case method,
 * the test case results in {@link TestResultType#IGNORED_CANNOT_INVOKE ignored (cannot invoke)}.</li>
 * <li>If the test case method is not to be executed because it is {@link Ignore annotated that way}, the test case
 * results in {@link TestResultType#IGNORED_ANNOTATED ignored (annotated)}.</li>
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
@Documented
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface Test
{
    /**
     * Returns a name for the test case method, which is typically used in reporting.
     *
     * @return A name for the test case method, which is typically used in reporting.
     */
    String value() default "";

    /**
     * Returns a description for the test case method, which is typically used in reporting.
     *
     * @return A description for the test case method, which is typically used in reporting.
     */
    String description() default "";
}
