/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.LinkedHashSet;
import java.util.Set;

final class TestMethodCategoriesFactory
{
    private TestMethodCategoriesFactory()
    {

    }

    static TestMethodCategories newTestMethodCategories()
    {
        return new TestMethodCategoriesImpl();
    }

    private static final class TestMethodCategoriesImpl implements TestMethodCategories
    {
        TestMethodCategoriesImpl()
        {

        }

        public ReadOnlyArray<String> getTestMethodCategories(final Method m) throws NullPointerException
        {
            if(m == null)
            {
                throw new NullPointerException();
            }

            final Category mc = m.getAnnotation(Category.class);
            final Category cc = m.getDeclaringClass().getAnnotation(Category.class);

            final Set<String> categories = new LinkedHashSet<String>();

            if(mc != null)
            {
                categories.addAll(Arrays.asList(mc.value()));
            }

            if(cc != null)
            {
                categories.addAll(Arrays.asList(cc.value()));
            }

            return newSequence(categories.toArray(new String[categories.size()]));
        }
    }
}