/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.Serializable;

/**
 * Represents the result after execution of a test case method.
 *
 * @see Test
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public interface TestResult extends Serializable
{
    /**
     * Returns the type of the result.
     * This is never <code>null</code>.
     *
     * @return The type of the result. This is never <code>null</code>.
     */
    TestResultType getTestResultType();

    /**
     * Returns the message associated with the test result.
     * This may be <code>null</code>.
     *
     * @return The message associated with the test result. This may be <code>null</code>.
     */
    String getMessage();

    /**
     * Returns the exception associated with this test result.
     * This may be <code>null</code>.
     *
     * @return The exception associated with this test result. This may be <code>null</code>.
     */
    Throwable getException();

    /**
     * Returns the amount of time, in milliseconds, that the test method took for execution.
     * This may be <code>null</code>.
     *
     * @return The amount of time, in milliseconds, that the test method took for execution. This may be
     * <code>null</code>.
     */
    Long getElapsedTime();

    /**
     * Returns all categories that the test case method is in.
     * This is never <code>null</code>.
     *
     * @return All categories that the test case method is in. This is never <code>null</code>.
     */
    ReadOnlyArray<String> getCategories();

    /**
     * Returns the {@link Test#value() name of the test case method}.
     * If the test case method has not been given an explicit name, the method name is returned.
     * This is never <code>null</code>.
     *
     * @return The {@link Test#value() name of the test case method}. If the test case method has not been given an
     * explicit name, the method name is returned. This is never <code>null</code>.
     * @see Test#value()
     */
    String getTestName();

    /**
     * Returns the {@link Test#description() description of the test case method}.
     * This may be <code>null</code>.
     *
     * @return The {@link Test#description() description of the test case method}. This may be <code>null</code>.
     * @see Test#description()
     */
    String getTestDescription();

    /**
     * Returns the <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/reflect/Method.html#getName()">test case method name</a>.
     * This is never <code>null</code>.
     *
     * @return The <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/reflect/Method.html#getName()">test case method name</a>. This is
     * never <code>null</code>.
     */
    String getTestMethodName();

    /**
     * Returns the
     * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/reflect/Method.html#getParameterTypes()">test case method parameter</a> types.
     *
     * @return The
     * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/reflect/Method.html#getParameterTypes()">test case method parameter</a> types.
     * @since 2.1
     */
    ReadOnlyArray<Class<?>> getTestMethodParameterTypes();

    /**
     * Returns the {@link Fixture#value() name of the test fixture that contains the test case method}.
     * If the test fixture has not been given an explicit name, the class name is returned.
     * This is never <code>null</code>.
     *
     * @return The {@link Fixture#value() name of the test fixture that contains the test case method}. If the test
     * fixture has not been given an explicit name, the class name is returned. This is never <code>null</code>.
     * @see Fixture#value()
     */
    String getFixtureName();

    /**
     * Returns the {@link Fixture#description() description of the test fixture that contains the test case method}.
     * This may be <code>null</code>.
     *
     * @return The {@link Fixture#description() description of the test fixture that contains the test case method}.
     * This may be <code>null</code>.
     * @see Fixture#description()
     */
    String getFixtureDescription();

    /**
     * Returns the test fixture class.
     * This is never <code>null</code>.
     *
     * @return The test fixture class. This is never <code>null</code>.
     */
    Class<?> getFixtureClass();
}
