/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

/**
 * An enumeration of the possible result types of a test case execution.
 *
 * @see TestResult
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public enum TestResultType
{
    /**
     * Indicates that the test case execution resulted in success.
     */
    SUCCESS,

    /**
     * Indicates that the test case execution resulted in being ignored because it was annotated that way.
     *
     * @see Ignore
     */
    IGNORED_ANNOTATED,

    /**
     * Indicates that the test case execution resulted in being ignored because it does not satisfy the criteria for
     * a test case method.
     *
     * @see Test
     */
    IGNORED_CANNOT_INVOKE,

    /**
     * Indicates that the test case execution resulted in failure because the test fixture that contains it could not
     * be setup.
     *
     * @see SetUp
     */
    FAILURE_SETUP,

    /**
     * Indicates that the test case execution resulted in failure.
     */
    FAILURE,

    /**
     * Indicates that the test case execution resulted in failure because the test fixture that contains it could not
     * be torn down.
     *
     * @see TearDown
     */
    FAILURE_TEARDOWN;
}
