/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.Iterator;

final class UnmodifiableIteratorFactory
{
    private UnmodifiableIteratorFactory()
    {

    }

    static <E> Iterator<E> unmodifiableIterator(final Iterator<E> i) throws NullPointerException
    {
        if(i == null)
        {
            throw new NullPointerException();
        }

        return new UnmodifiableIterator<E>(i);
    }

    private static final class UnmodifiableIterator<E> implements Iterator<E>
    {
        private final Iterator<E> i;

        UnmodifiableIterator(final Iterator<E> i)
        {
            this.i = i;
        }

        public boolean hasNext()
        {
            return i.hasNext();
        }

        public E next()
        {
            return i.next();
        }

        public void remove()
        {
            throw new UnsupportedOperationException();
        }
    }
}
