/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.util.ListIterator;

final class UnmodifiableListIteratorFactory
{
    private UnmodifiableListIteratorFactory()
    {

    }

    static <E> ListIterator<E> unmodifiableListIterator(final ListIterator<E> i) throws NullPointerException
    {
        if(i == null)
        {
            throw new NullPointerException();
        }

        return new UnmodifiableListIterator<E>(i);
    }

    private static final class UnmodifiableListIterator<E> implements ListIterator<E>
    {
        private final ListIterator<E> i;

        UnmodifiableListIterator(final ListIterator<E> i)
        {
            this.i = i;
        }

        public boolean hasNext()
        {
            return i.hasNext();
        }

        public E next()
        {
            return i.next();
        }

        public boolean hasPrevious()
        {
            return i.hasPrevious();
        }

        public E previous()
        {
            return i.previous();
        }

        public int nextIndex()
        {
            return i.nextIndex();
        }

        public int previousIndex()
        {
            return i.previousIndex();
        }

        public void remove()
        {
            throw new UnsupportedOperationException();
        }

        public void set(final E e)
        {
            throw new UnsupportedOperationException();
        }

        public void add(final E e)
        {
            throw new UnsupportedOperationException();
        }
    }
}
