/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework.junit;

import java.lang.reflect.Method;

/**
 * This implementation of {@link org.jtiger.framework.TestDefinition} is intended to be used to execute test cases that
 * have been written using <a href="http://www.junit.org/" target="_blank">the JUnit Test Framework</a>. The implementation is
 * passed to the framework by returning an instance from
 * {@link org.jtiger.framework.FixturesRunnerConfig#getDefinitionClass()} or by passing the qualified class name as
 * {@link org.jtiger.framework.FixturesRunnerMain#ARG_DEFINITION_CLASS the appropriate argument} on the command line to
 * {@link org.jtiger.framework.FixturesRunnerMain#main(String[]) the framework main method}.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class JUnitTestDefinition implements org.jtiger.framework.TestDefinition
{
    private static final String TEST_METHOD_PREFIX = "test";

    /**
     * Create a default instance of <tt>JUnitTestDefinition</tt>.
     */
    public JUnitTestDefinition()
    {

    }

    /**
     * Returns <code>true</code> if the passed method is a test case designed for
     * <a href="http://www.junit.org/" target="_blank">the JUnit Test Framework</a>, <code>false</code> otherwise. This means that
     * the method name begins with <tt>"test"</tt> .
     *
     * @param m The method to check if it is a test case designed for
     * <a href="http://www.junit.org/" target="_blank">the JUnit Test Framework</a>.
     * @return <code>true</code> if the passed method is a test case designed for
     * <a href="http://www.junit.org/" target="_blank">the JUnit Test Framework</a>, <code>false</code> otherwise.
     */
    public boolean isTest(final Method m)
    {
        if(m == null)
        {
            return false;
        }

        final String name = m.getName();

        return name.startsWith(JUnitTestDefinition.TEST_METHOD_PREFIX);
    }
}
