/**
 * Provides a framework for performing automated testing based on fixtures and test cases.
 * A test fixture class is optionally annotated with {@link org.jtiger.framework.Fixture} and each test case method
 * within the class is annotated with {@link org.jtiger.framework.Test} to indicate that it is a test case method. A
 * test fixture class may contain methods that are annotated with {@link org.jtiger.framework.SetUp} or
 * {@link org.jtiger.framework.TearDown}, which are executed before and after each test case method respectively. Test
 * case methods, set up methods, and tear down methods should take no arguments and test fixture classes should have a
 * no argument constructor, or a constructor that takes a single
 * <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> argument.
 * Example:
<pre>
    // The presence of this annotation is optional.
    &#64Fixture("Demonstration")
    class MyTestFixture
    {
        &#64SetUp
        public void setUpFixture()
        {
            // ommitted
        }

        &#64Test
        public void doSomeTesting()
        {
            // ommitted
        }

        &#64TearDown
        public void tearDownFixture()
        {
            // ommitted
        }
    }
</pre>
 *
 * <br/>
 * The framework package defines two points of entry for execution of test fixtures;
 * <br/>
 * <li>{@link org.jtiger.framework.FixturesRunner} provides the ability to run test fixtures through an API.</li>
 * <li>{@link org.jtiger.framework.FixturesRunnerMain} provides the ability to run test fixtures from a command line
 * (since it contains a <code>main</code> method.</li>
 * <br/>
 * Other packages could typically provide other means of executing test fixtures. For example, an
 * <a href="http://ant.apache.org/" target="_blank">Apache Ant</a> task, or a swing application interface.
 * @see org.jtiger.framework.Fixture
 * @see org.jtiger.framework.Test
 * @see org.jtiger.framework.SetUp
 * @see org.jtiger.framework.TearDown
 * @see org.jtiger.framework.FixturesRunner
 * @see org.jtiger.framework.FixturesRunnerFactory
 * @see org.jtiger.framework.FixturesRunnerMain
 */
package org.jtiger.framework;
