/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.beans.XMLEncoder;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.jtiger.framework.FixtureResultsHandlerException;

final class FixtureHtmlFileWriterFactory
{
    private static final String XSL_RESOURCE = "/org/jtiger/report/xsl/fixture.xsl";
    private static final String PARAM_BUILD_TIME = "buildTime";
    private static final String PARAM_FIXTURE_NAME = "fixtureName";
    private static final String PARAM_FIXTURE_DESCRIPTION = "fixtureDescription";
    private static final String PARAM_FIXTURE_CLASS = "fixtureClass";

    private FixtureHtmlFileWriterFactory()
    {

    }

    static FixtureHtmlFileWriter newFixtureHtmlFileWriter()
    {
        return new FixtureHtmlFileWriterImpl();
    }

    private static final class FixtureHtmlFileWriterImpl implements FixtureHtmlFileWriter
    {
        FixtureHtmlFileWriterImpl()
        {

        }

        public void writeFixtureHtml(
                final FixtureResults result,
                final File destination,
                final FilenamePolicy policy,
                final String buildTime)
                throws FixtureResultsHandlerException
        {
            final ByteArrayOutputStream out = new ByteArrayOutputStream();
            final XMLEncoder encoder = new XMLEncoder(out);

            for(TestResult tr : result.getTestResults())
            {
                final Object bean = new TestResultBeanImpl(tr.getName(), tr.getException(), tr.getElapsedTime(),
                        tr.getMessage(), tr.getMethodName(), tr.getDescription(), tr.getResult());

                encoder.writeObject(bean);
            }

            encoder.close();


            InputStream in = null;

            try
            {
                in = getClass().getResourceAsStream(XSL_RESOURCE);
                final Transformer t = TransformerFactory.newInstance().newTransformer(new StreamSource(in));
                t.setParameter(PARAM_BUILD_TIME, buildTime);
                t.setParameter(PARAM_FIXTURE_NAME, result.getName());
                t.setParameter(PARAM_FIXTURE_DESCRIPTION, result.getDescription());
                t.setParameter(PARAM_FIXTURE_CLASS, result.getClassName());

                OutputStream o = null;

                try
                {
                    final File f = new File(destination, policy.nextFilename());
                    f.getParentFile().mkdirs();
                    o = new FileOutputStream(f);
                    final StreamResult r = new StreamResult(o);
                    t.transform(new StreamSource(new ByteArrayInputStream(out.toByteArray())), r);
                }
                catch(FileNotFoundException e)
                {
                    throw new FixtureResultsHandlerException(e.getMessage(), e);
                }
                finally
                {
                    if(o != null)
                    {
                        try
                        {
                            o.close();
                        }
                        catch(IOException e)
                        {
                            throw new FixtureResultsHandlerException(e.getMessage(), e);
                        }
                    }
                }
            }
            catch(TransformerConfigurationException e)
            {
                throw new FixtureResultsHandlerException(e.getMessage(), e);
            }
            catch(TransformerException e)
            {
                throw new FixtureResultsHandlerException(e.getMessage(), e);
            }
            finally
            {
                if(in != null)
                {
                    try
                    {
                        in.close();
                    }
                    catch(IOException e)
                    {
                        throw new FixtureResultsHandlerException(e.getMessage(), e);
                    }
                }
            }
        }
    }
}
