/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

/**
 * A bean that is used by {@link org.jtiger.report.html.HtmlFixtureResultsHandler the HTML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class FixtureResultBeanImpl implements FixtureResultBean
{
    private static final long serialVersionUID = 2L;

    private String name;
    private String href;

    /**
     * Create a default <tt>FixtureResultBeanImpl</tt>.
     */
    public FixtureResultBeanImpl()
    {

    }

    FixtureResultBeanImpl(final String name, final String href)
    {
        this.name = name;
        this.href = href;
    }

    /**
     * Returns the name property of the bean.
     *
     * @return The name property of the bean.
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the name property of the bean.
     *
     * @param name The name property of the bean.
     */
    public void setName(final String name)
    {
        this.name = name;
    }

    /**
     * Returns the href property of the bean.
     *
     * @return The href property of the bean.
     */
    public String getHref()
    {
        return href;
    }

    /**
     * Sets the href property of the bean.
     *
     * @param href The href property of the bean.
     */
    public void setHref(final String href)
    {
        this.href = href;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property and the href proeprty.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property and the href proeprty.
     */
    @Override
    public String toString()
    {
        final StringBuilder sb = new StringBuilder();

        sb.append('[');
        sb.append(name);
        sb.append("][");
        sb.append(href);
        sb.append(']');

        return sb.toString();
    }

    /**
     * Compares two instance of <tt>FixtureResultBeanImpl</tt> returning <code>true</code> iff the name and href properties
     * are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>FixtureResultBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the name and href properties are equal, <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != FixtureResultBeanImpl.class)
        {
            return false;
        }

        final FixtureResultBeanImpl f = (FixtureResultBeanImpl)o;

        return (name == null ? f.name == null : name.equals(f.name)) &&
                (href == null ? f.href == null : href.equals(f.href));
    }

    /**
     * Returns a hash code for this <tt>FixtureResultBeanImpl</tt> based on the name and href properties.
     *
     * @return A hash code for this <tt>FixtureResultBeanImpl</tt> based on the name and href properties.
     */
    @Override
    public int hashCode()
    {
        final int oddPrime = 461;
        int result = 73;

        if(name != null)
        {
            result = result * oddPrime + name.hashCode();
        }

        if(href != null)
        {
            result = result * oddPrime + href.hashCode();
        }

        return result;
    }
}
