/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;
import org.jtiger.framework.FixtureResult;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.TestResultType;
import static org.jtiger.report.html.FixtureResultsFactory.newFixtureResults;
import static org.jtiger.report.html.TestResultFactory.newTestResult;
import static org.jtiger.report.html.ResultMappingFactory.newResultMapping;

final class FixtureResultConverterFactory
{
    private static final String NA = "-";

    private FixtureResultConverterFactory()
    {

    }

    static FixtureResultConverter newFixtureResultConverter()
    {
        return new FixtureResultConverterImpl();
    }

    private static final class FixtureResultConverterImpl implements FixtureResultConverter
    {
        FixtureResultConverterImpl()
        {

        }

        public ReadOnlyArray<FixtureResults> convertFixtureResults(final org.jtiger.framework.FixtureResults results)
        {
            final List<FixtureResults> frs = new LinkedList<FixtureResults>();

            for(FixtureResult result : results)
            {
                final ResultMapping mapping = newResultMapping();

                final List<TestResult> trs = new LinkedList<TestResult>();

                String fixtureName = null;
                String fixtureDescription = null;
                String fixtureClassName = null;
                boolean set = false;

                for(org.jtiger.framework.TestResult tr : result)
                {
                    final String testName = tr.getTestName();
                    final Throwable exception = tr.getException();
                    final Long elapsedTime = tr.getElapsedTime();
                    final String message = tr.getMessage();
                    final String testMethodName = tr.getTestMethodName();
                    final String testDescription = tr.getTestDescription();
                    final TestResultType testResultType = tr.getTestResultType();

                    final TestResult r = newTestResult(
                            testName,
                            exception == null ? NA : exception.getClass().getName(),
                            elapsedTime == null ? NA : String.valueOf(elapsedTime),
                            message == null || message.length() == 0 ? NA : message,
                            testMethodName,
                            testDescription.length() == 0 ? NA : testDescription,
                            mapping.getResultMapping(testResultType));

                    fixtureName = tr.getFixtureName();
                    fixtureDescription = tr.getFixtureDescription() == null || tr.getFixtureDescription().length() == 0 ? NA : tr.getFixtureDescription();
                    fixtureClassName = tr.getFixtureClass().getName();
                    set = true;

                    trs.add(r);
                }

                if(set)
                {
                    Collections.sort(trs, new Comparator<TestResult>()
                    {
                        public int compare(final TestResult tr1, final TestResult tr2)
                        {
                            return tr1.getName().compareTo(tr2.getName());
                        }
                    });

                    final FixtureResults fr = newFixtureResults(
                            fixtureName,
                            fixtureDescription,
                            fixtureClassName,
                            newSequence(trs.toArray(new TestResult[trs.size()])));

                    frs.add(fr);
                }
            }

            Collections.sort(frs, new Comparator<FixtureResults>()
            {
                public int compare(final FixtureResults fr1, final FixtureResults fr2)
                {
                    return fr1.getName().compareTo(fr2.getName());
                }
            });

            return newSequence(frs.toArray(new FixtureResults[frs.size()]));
        }
    }
}
