/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.beans.XMLEncoder;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.ReadOnlyArray;
import static org.jtiger.report.html.FixturesFilenamePolicyFactory.newFixturesFilenamePolicy;

final class FixturesHtmlFileWriterFactory
{
    private static final String XSL_RESOURCE = "/org/jtiger/report/xsl/fixtures.xsl";
    private static final String FILENAME = "fixtures.html";

    private FixturesHtmlFileWriterFactory()
    {

    }

    static FixturesHtmlFileWriter newFixturesHtmlFileWriter()
    {
        return new FixturesHtmlFileWriterImpl();
    }

    private static final class FixturesHtmlFileWriterImpl implements FixturesHtmlFileWriter
    {
        FixturesHtmlFileWriterImpl()
        {

        }

        public void writeFixturesHtml(final ReadOnlyArray<FixtureResults> results, final File destination) throws FixtureResultsHandlerException
        {
            final ByteArrayOutputStream out = new ByteArrayOutputStream();
            final XMLEncoder encoder = new XMLEncoder(out);

            final FilenamePolicy policy = newFixturesFilenamePolicy();

            for(FixtureResults result : results)
            {
                final Object bean = new FixtureResultBeanImpl(result.getName(), policy.nextFilename());
                encoder.writeObject(bean);
            }

            encoder.close();

            InputStream in = null;

            try
            {
                in = getClass().getResourceAsStream(XSL_RESOURCE);
                final Transformer t = TransformerFactory.newInstance().newTransformer(new StreamSource(in));
                OutputStream o = null;

                try
                {
                    final File f = new File(destination, FILENAME);
                    o = new FileOutputStream(f);
                    final StreamResult r = new StreamResult(o);
                    t.transform(new StreamSource(new ByteArrayInputStream(out.toByteArray())), r);
                }
                catch(FileNotFoundException e)
                {
                    throw new FixtureResultsHandlerException(e.getMessage(), e);
                }
                finally
                {
                    if(o != null)
                    {
                        try
                        {
                            o.close();
                        }
                        catch(IOException e)
                        {
                            throw new FixtureResultsHandlerException(e.getMessage(), e);
                        }
                    }
                }
            }
            catch(TransformerConfigurationException e)
            {
                throw new FixtureResultsHandlerException(e.getMessage(), e);
            }
            catch(TransformerException e)
            {
                throw new FixtureResultsHandlerException(e.getMessage(), e);
            }
            finally
            {
                if(in != null)
                {
                    try
                    {
                        in.close();
                    }
                    catch(IOException e)
                    {
                        throw new FixtureResultsHandlerException(e.getMessage(), e);
                    }
                }
            }
        }
    }
}
