/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.io.File;
import java.util.Date;
import org.jtiger.framework.FixtureResultsHandler;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.ReadOnlyArray;
import static org.jtiger.report.html.IndexHtmlFileWriterFactory.newIndexHtmlFileWriter;
import static org.jtiger.report.html.FixtureResultConverterFactory.newFixtureResultConverter;
import static org.jtiger.report.html.FixturesHtmlFileWriterFactory.newFixturesHtmlFileWriter;
import static org.jtiger.report.html.FixtureHtmlFileWriterFactory.newFixtureHtmlFileWriter;
import static org.jtiger.report.html.FixturesFilenamePolicyFactory.newFixturesFilenamePolicy;
import static org.jtiger.report.html.OverallResultConverterFactory.newOverallResultConverter;
import static org.jtiger.report.html.OverallHtmlFileWriterFactory.newOverallHtmlFileWriter;
import static org.jtiger.report.html.OverallTotalFactory.newOverallTotal;

/**
 * A result handler that produces a HTML report of test run results.
 * The report is written to a directory which is passed in the parameters to
 * {@link #handleResult(org.jtiger.framework.FixtureResults, org.jtiger.framework.ReadOnlyArray) the handleResult method}.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class HtmlFixtureResultsHandler implements FixtureResultsHandler
{
    /**
     * Create a default <tt>HtmlFixtureResultsHandler</tt>.
     */
    public HtmlFixtureResultsHandler()
    {

    }

    /**
     * Write a HTML report of the given test run results to a directory which is passed in the parameters.
     * If the <tt>params</tt> are empty, the current directory is used to write the report to.
     *
     * @param results The test run results to produce the HTML report of.
     * @param params The parameters that contain at least one parameter which is the directory to write the HTML report
     * to otherwise the current directory is used.
     * @throws FixtureResultsHandlerException If an error occurs while writing the HTML report.
     */
    public void handleResult(final org.jtiger.framework.FixtureResults results, final ReadOnlyArray<String> params) throws FixtureResultsHandlerException
    {
        final File destination;

        if(params == null || params.length() == 0)
        {
            destination = new File(".");
        }
        else
        {
            destination = new File(params.get(0));
        }

        destination.mkdirs();
        final IndexHtmlFileWriter ihfw = newIndexHtmlFileWriter();
        ihfw.writeIndexHtmlFile(destination);
        final String buildTime = new Date().toString();

        final ReadOnlyArray<FixtureResults> frs = newFixtureResultConverter().convertFixtureResults(results);

        newFixturesHtmlFileWriter().writeFixturesHtml(frs, destination);

        FilenamePolicy policy = newFixturesFilenamePolicy();

        final FixtureHtmlFileWriter fhfw = newFixtureHtmlFileWriter();

        for(FixtureResults fr : frs)
        {
            fhfw.writeFixtureHtml(fr, destination, policy, buildTime);
        }

        final ReadOnlyArray<OverallResult> overallResults = newOverallResultConverter().convertOverallResult(frs);

        final OverallHtmlFileWriter ohfw = newOverallHtmlFileWriter();
        policy = newFixturesFilenamePolicy();
        ohfw.writeOverallHtml(overallResults, destination, policy, newOverallTotal(results), buildTime);
    }
}
