/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import org.jtiger.framework.FixtureResultsHandlerException;

final class IndexHtmlFileWriterFactory
{
    private IndexHtmlFileWriterFactory()
    {

    }

    static IndexHtmlFileWriter newIndexHtmlFileWriter()
    {
        return new IndexHtmlFileWriterImpl();
    }

    private static final class IndexHtmlFileWriterImpl implements IndexHtmlFileWriter
    {
        IndexHtmlFileWriterImpl()
        {

        }

        public void writeIndexHtmlFile(final File destination) throws FixtureResultsHandlerException
        {
            final File f = new File(destination, "index.html");

            OutputStream out = null;

            try
            {
                out = new FileOutputStream(f);
                InputStream in = null;

                try
                {
                    in = getClass().getResourceAsStream("/org/jtiger/report/html/index.html");
                    final byte[] buffer = new byte[4096];
                    int len;

                    while((len = in.read(buffer)) != -1)
                    {
                        out.write(buffer, 0, len);
                    }
                }
                finally
                {
                    if(in != null)
                    {
                        try
                        {
                            in.close();
                        }
                        catch(IOException e)
                        {
                            throw new FixtureResultsHandlerException(e.getMessage(), e);
                        }
                    }
                }
            }
            catch(IOException e)
            {
                throw new FixtureResultsHandlerException(e.getMessage(), e);
            }
            finally
            {
                if(out != null)
                {
                    try
                    {
                        out.close();
                    }
                    catch(IOException e)
                    {
                        throw new FixtureResultsHandlerException(e.getMessage(), e);
                    }
                }
            }            
        }
    }
}
