/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

/**
 * A bean that is used by {@link org.jtiger.report.html.HtmlFixtureResultsHandler the HTML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class OverallResultBeanImpl implements OverallResultBean
{
    private static final long serialVersionUID = 2L;

    private String name;
    private String href;
    private String description;
    private String elapsedTime;
    private String result;

    /**
     * Create a default <tt>OverallResultBeanImpl</tt>.
     */
    public OverallResultBeanImpl()
    {

    }

    OverallResultBeanImpl(final String name, final String href, final String description, final String elapsedTime, final String result)
    {
        this.name = name;
        this.href = href;
        this.description = description;
        this.elapsedTime = elapsedTime;
        this.result = result;
    }

    /**
     * Returns the name property of the bean.
     *
     * @return The name property of the bean.
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the name property of the bean.
     *
     * @param name The name property of the bean.
     */
    public void setName(final String name)
    {
        this.name = name;
    }

    /**
     * Returns the href property of the bean.
     *
     * @return The href property of the bean.
     */
    public String getHref()
    {
        return href;
    }

    /**
     * Sets the href property of the bean.
     *
     * @param href The href property of the bean.
     */
    public void setHref(final String href)
    {
        this.href = href;
    }

    /**
     * Returns the href property of the bean.
     *
     * @return The href property of the bean.
     */
    public String getDescription()
    {
        return description;
    }

    /**
     * Sets the description property of the bean.
     *
     * @param description The description property of the bean.
     */
    public void setDescription(final String description)
    {
        this.description = description;
    }

    /**
     * Returns the description property of the bean.
     *
     * @return The description property of the bean.
     */
    public String getElapsedTime()
    {
        return elapsedTime;
    }

    /**
     * Sets the elapsedTime property of the bean.
     *
     * @param elapsedTime The elapsedTime property of the bean.
     */
    public void setElapsedTime(final String elapsedTime)
    {
        this.elapsedTime = elapsedTime;
    }

    /**
     * Returns the result property of the bean.
     *
     * @return The result property of the bean.
     */
    public String getResult()
    {
        return result;
    }

    /**
     * Sets the result property of the bean.
     *
     * @param result The elapsedTime property of the bean.
     */
    public void setResult(final String result)
    {
        this.result = result;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property, the href property, the description property, the elapsedTime property, and the
     * result property.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property, the href property, the description property, the elapsedTime property, and the
     * result property.
     */
    @Override
    public String toString()
    {
        final StringBuilder sb = new StringBuilder();

        sb.append('[');
        sb.append(name);
        sb.append("][");
        sb.append(href);
        sb.append("][");
        sb.append(description);
        sb.append("][");
        sb.append(elapsedTime);
        sb.append("][");
        sb.append(result);
        sb.append(']');

        return sb.toString();
    }

    /**
     * Compares two instance of <tt>OverallResultBeanImpl</tt> returning <code>true</code> iff the name, href, description,
     * elapsedTime, and result properties are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>OverallResultBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the name, href, description, elapsedTime, and result properties are equal,
     * <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != OverallResultBeanImpl.class)
        {
            return false;
        }

        final OverallResultBeanImpl f = (OverallResultBeanImpl)o;

        return (name == null ? f.name == null : name.equals(f.name)) &&
                (href == null ? f.href == null : href.equals(f.href)) &&
                (description == null ? f.description == null : description.equals(f.description)) &&
                (elapsedTime == null ? f.elapsedTime == null : elapsedTime.equals(f.elapsedTime)) &&
                (result == null ? f.result == null : result.equals(f.result));
    }

    /**
     * Returns a hash code for this <tt>OverallResultBeanImpl</tt> based on the name, href, description, elapsedTime, and
     * result properties.
     *
     * @return A hash code for this <tt>OverallResultBeanImpl</tt> based on the name, href, description, elapsedTime, and
     * result properties.
     */
    @Override
    public int hashCode()
    {
        final int oddPrime = 461;
        int result = 73;

        if(name != null)
        {
            result = result * oddPrime + name.hashCode();
        }

        if(href != null)
        {
            result = result * oddPrime + href.hashCode();
        }

        if(description != null)
        {
            result = result * oddPrime + description.hashCode();
        }

        if(elapsedTime != null)
        {
            result = result * oddPrime + elapsedTime.hashCode();
        }

        if(this.result != null)
        {
            result = result * oddPrime + this.result.hashCode();
        }

        return result;
    }
}
