/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.util.LinkedList;
import java.util.List;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.TestResultType;
import static org.jtiger.report.html.OverallResultFactory.newOverallResult;
import static org.jtiger.report.html.ResultMappingFactory.newResultMapping;

final class OverallResultConverterFactory
{
    private static final String NA = "-";

    private OverallResultConverterFactory()
    {

    }

    static OverallResultConverter newOverallResultConverter()
    {
        return new OverallResultConverterImpl();
    }

    private static final class OverallResultConverterImpl implements OverallResultConverter
    {
        OverallResultConverterImpl()
        {

        }

        public ReadOnlyArray<OverallResult> convertOverallResult(final ReadOnlyArray<FixtureResults> results)
        {
            final List<OverallResult> overallResults = new LinkedList<OverallResult>();

            for(FixtureResults result : results)
            {
                final String name = result.getName();
                final String description = result.getDescription();
                final String elapsedTime = getElapsedTime(result);
                final String overallResult = getResult(result);

                final OverallResult or = newOverallResult(
                        name,
                        description == null || description.length() == 0 ? NA : description,
                        elapsedTime == null ? NA : elapsedTime,
                        overallResult);
                overallResults.add(or);
            }

            return newSequence(overallResults.toArray(new OverallResult[overallResults.size()]));
        }

        private String getElapsedTime(final FixtureResults result)
        {
            boolean added = false;
            long total = 0;

            for(TestResult tr : result.getTestResults())
            {
                if(isAllDigits(tr.getElapsedTime()))
                {
                    total += Long.parseLong(tr.getElapsedTime());
                    added = true;
                }
            }

            return added ? String.valueOf(total) : null;
        }

        private String getResult(final FixtureResults result)
        {
            TestResultType worstCase = TestResultType.values()[0];

            final ResultMapping mapping = newResultMapping();

            for(TestResult tr : result.getTestResults())
            {
                final TestResultType type = mapping.getResultMapping(tr.getResult());

                if(type != null && type.compareTo(worstCase) > 0)
                {
                    worstCase = type;
                }
            }

            return mapping.getResultMapping(worstCase);
        }

        private boolean isAllDigits(final String s)
        {
            if(s == null || s.length() == 0)
            {
                return false;
            }

            for(int i = 0; i < s.length(); i++)
            {
                if(!Character.isDigit(s.charAt(i)))
                {
                    return false;
                }
            }

            return true;
        }
    }
}
