/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import org.jtiger.framework.TestResultType;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_SETUP;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;
import static org.jtiger.framework.TestResultType.IGNORED_ANNOTATED;
import static org.jtiger.framework.TestResultType.IGNORED_CANNOT_INVOKE;

final class OverallTotalFactory
{
    private OverallTotalFactory()
    {

    }

    static OverallTotal newOverallTotal(final org.jtiger.framework.FixtureResults results) throws NullPointerException
    {
        if(results == null)
        {
            throw new NullPointerException();
        }

        return new OverallTotalImpl(results);
    }

    private static final class OverallTotalImpl implements OverallTotal
    {
        private long success;
        private long failure;
        private long failureSetUp;
        private long failureTearDown;
        private long ignoredAnnotated;
        private long ignoredCannotInvoke;
        private final long total;

        OverallTotalImpl(final org.jtiger.framework.FixtureResults results)
        {
            for(org.jtiger.framework.FixtureResult result : results)
            {
                for(org.jtiger.framework.TestResult tr : result)
                {
                    final TestResultType r = tr.getTestResultType();

                    if(r == SUCCESS)
                    {
                        success++;
                    }
                    else if(r == FAILURE)
                    {
                        failure++;
                    }
                    else if(r == FAILURE_SETUP)
                    {
                        failureSetUp++;
                    }
                    else if(r == FAILURE_TEARDOWN)
                    {
                        failureTearDown++;
                    }
                    else if(r == IGNORED_ANNOTATED)
                    {
                        ignoredAnnotated++;
                    }
                    else if(r == IGNORED_CANNOT_INVOKE)
                    {
                        ignoredCannotInvoke++;
                    }
                }
            }

            total = success + failure + failureSetUp + failureTearDown + ignoredAnnotated + ignoredCannotInvoke;
        }

        public long getSuccess()
        {
            return success;
        }

        public long getFailure()
        {
            return failure;
        }

        public long getFailureSetUp()
        {
            return failureSetUp;
        }

        public long getFailureTearDown()
        {
            return failureTearDown;
        }

        public long getIgnoredAnnotated()
        {
            return ignoredAnnotated;
        }

        public long getIgnoredCannotInvoke()
        {
            return ignoredCannotInvoke;
        }

        public long getTotal()
        {
            return total;
        }
    }
}
