/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.util.Map;
import java.util.ResourceBundle;
import java.util.TreeMap;
import org.jtiger.framework.TestResultType;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_SETUP;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;
import static org.jtiger.framework.TestResultType.IGNORED_ANNOTATED;
import static org.jtiger.framework.TestResultType.IGNORED_CANNOT_INVOKE;

final class ResultMappingFactory
{
    public static final String BUNDLE = "org/jtiger/report/html/ResultMapping";

    private ResultMappingFactory()
    {

    }

    static ResultMapping newResultMapping()
    {
        return new ResultMappingImpl();
    }

    private static final class ResultMappingImpl implements ResultMapping
    {
        private final Map<TestResultType, String> mapping;
        private final Map<String, TestResultType> reverseMapping;

        ResultMappingImpl()
        {
            mapping = new TreeMap<TestResultType, String>();
            reverseMapping = new TreeMap<String, TestResultType>();

            final String failure = ResourceBundle.getBundle(BUNDLE).getString("failure");
            final String failureSetup = ResourceBundle.getBundle(BUNDLE).getString("failure.setup");
            final String failureTeardown = ResourceBundle.getBundle(BUNDLE).getString("failure.teardown");
            final String ignoredAnnotated = ResourceBundle.getBundle(BUNDLE).getString("ignored.annotated");
            final String ignoredCannotInvoke = ResourceBundle.getBundle(BUNDLE).getString("ignored.cannot.invoke");
            final String success = ResourceBundle.getBundle(BUNDLE).getString("success");

            mapping.put(FAILURE, failure);
            mapping.put(FAILURE_SETUP, failureSetup);
            mapping.put(FAILURE_TEARDOWN, failureTeardown);
            mapping.put(IGNORED_ANNOTATED, ignoredAnnotated);
            mapping.put(IGNORED_CANNOT_INVOKE, ignoredCannotInvoke);
            mapping.put(SUCCESS, success);

            reverseMapping.put(failure, FAILURE);
            reverseMapping.put(failureSetup, FAILURE_SETUP);
            reverseMapping.put(failureTeardown, FAILURE_TEARDOWN);
            reverseMapping.put(ignoredAnnotated, IGNORED_ANNOTATED);
            reverseMapping.put(ignoredCannotInvoke, IGNORED_CANNOT_INVOKE);
            reverseMapping.put(success, SUCCESS);
        }

        public String getResultMapping(final TestResultType result)
        {
            if(result == null)
            {
                return null;
            }

            return mapping.get(result);
        }

        public TestResultType getResultMapping(final String s)
        {
            if(s == null)
            {
                return null;
            }

            return reverseMapping.get(s);
        }
    }
}
