/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

/**
 * A bean that is used by {@link org.jtiger.report.html.HtmlFixtureResultsHandler the HTML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class TestResultBeanImpl
        implements TestResultBean
{
    private static final long serialVersionUID = 2L;

    private String name;
    private String exception;
    private String elapsedTime;
    private String message;
    private String methodName;
    private String description;
    private String result;

    /**
     * Create a default <tt>TestResultBeanImpl</tt>.
     */
    public TestResultBeanImpl()
    {

    }

    TestResultBeanImpl(final String name, final String exception, final String elapsedTime,
                          final String message, final String methodName, final String description, final String result)
    {
        this.name = name;
        this.exception = exception;
        this.elapsedTime = elapsedTime;
        this.message = message;
        this.methodName = methodName;
        this.description = description;
        this.result = result;
    }

    /**
     * Returns the name property of the bean.
     *
     * @return The name property of the bean.
     */
    public String getName()
    {
        return name;
    }

    /**
     * Sets the name property of the bean.
     *
     * @param name The name property of the bean.
     */
    public void setName(final String name)
    {
        this.name = name;
    }

    /**
     * Returns the exception property of the bean.
     *
     * @return The exception property of the bean.
     */
    public String getException()
    {
        return exception;
    }

    /**
     * Sets the exception property of the bean.
     *
     * @param exception The exception property of the bean.
     */
    public void setException(final String exception)
    {
        this.exception = exception;
    }

    /**
     * Returns the elapsedTime property of the bean.
     *
     * @return The elapsedTime property of the bean.
     */
    public String getElapsedTime()
    {
        return elapsedTime;
    }

    /**
     * Sets the elapsedTime property of the bean.
     *
     * @param elapsedTime The elapsedTime property of the bean.
     */
    public void setElapsedTime(final String elapsedTime)
    {
        this.elapsedTime = elapsedTime;
    }

    /**
     * Returns the message property of the bean.
     *
     * @return The message property of the bean.
     */
    public String getMessage()
    {
        return message;
    }

    /**
     * Sets the message property of the bean.
     *
     * @param message The message property of the bean.
     */
    public void setMessage(final String message)
    {
        this.message = message;
    }

    /**
     * Returns the methodName property of the bean.
     *
     * @return The methodName property of the bean.
     */
    public String getMethodName()
    {
        return methodName;
    }

    /**
     * Sets the methodName property of the bean.
     *
     * @param methodName The methodName property of the bean.
     */
    public void setMethodName(final String methodName)
    {
        this.methodName = methodName;
    }

    /**
     * Returns the description property of the bean.
     *
     * @return The description property of the bean.
     */
    public String getDescription()
    {
        return description;
    }

    /**
     * Sets the description property of the bean.
     *
     * @param description The description property of the bean.
     */
    public void setDescription(final String description)
    {
        this.description = description;
    }

    /**
     * Returns the result property of the bean.
     *
     * @return The result property of the bean.
     */
    public String getResult()
    {
        return result;
    }

    /**
     * Sets the result property of the bean.
     *
     * @param result The result property of the bean.
     */
    public void setResult(final String result)
    {
        this.result = result;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property, the exception property, the elapsedTime property, the message property, the
     * methodName property, the description property, and the result property.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the name property, the exception property, the elapsedTime property, the message property, the
     * methodName property, the description property, and the result property.
     */
    @Override
    public String toString()
    {
        final StringBuilder sb = new StringBuilder();

        sb.append('[');
        sb.append(name);
        sb.append("][");
        sb.append(exception);
        sb.append("][");
        sb.append(elapsedTime);
        sb.append("][");
        sb.append(message);
        sb.append("][");
        sb.append(methodName);
        sb.append("][");
        sb.append(description);
        sb.append("][");
        sb.append(result);
        sb.append(']');

        return sb.toString();
    }

    /**
     * Compares two instance of <tt>TestResultBeanImpl</tt> returning <code>true</code> iff the name, exception,
     * elapsedTime, message, methodName, description, and result properties are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>TestResultBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the name, exception, elapsedTime, message, methodName, description, and result
     * properties are equal, <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != TestResultBeanImpl.class)
        {
            return false;
        }

        final TestResultBeanImpl f = (TestResultBeanImpl)o;

        return (name == null ? f.name == null : name.equals(f.name)) &&
                (exception == null ? f.exception == null : exception.equals(f.exception)) &&
                (elapsedTime == null ? f.elapsedTime == null : elapsedTime.equals(f.elapsedTime)) &&
                (message == null ? f.message == null : message.equals(f.message)) &&
                (methodName == null ? f.methodName == null : methodName.equals(f.methodName)) &&
                (description == null ? f.description == null : description.equals(f.description)) &&
                (result == null ? f.result == null : result.equals(f.result));
    }

    /**
     * Returns a hash code for this <tt>TestResultBeanImpl</tt> based on the name, exception, elapsedTime, message,
     * methodName, description, and result properties.
     *
     * @return A hash code for this <tt>TestResultBeanImpl</tt> based on the name, exception, elapsedTime, message,
     * methodName, description, and result properties.
     */
    @Override
    public int hashCode()
    {
        final int oddPrime = 461;
        int result = 73;

        if(name != null)
        {
            result = result * oddPrime + name.hashCode();
        }

        if(exception != null)
        {
            result = result * oddPrime + exception.hashCode();
        }

        if(elapsedTime != null)
        {
            result = result * oddPrime + elapsedTime.hashCode();
        }

        if(message != null)
        {
            result = result * oddPrime + message.hashCode();
        }

        if(methodName != null)
        {
            result = result * oddPrime + methodName.hashCode();
        }

        if(description != null)
        {
            result = result * oddPrime + description.hashCode();
        }

        if(this.result != null)
        {
            result = result * oddPrime + this.result.hashCode();
        }

        return result;
    }
}
