/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.text;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.File;
import org.jtiger.framework.FixtureResult;
import org.jtiger.framework.FixtureResults;
import org.jtiger.framework.FixtureResultsHandler;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.TestResult;

/**
 * A result handler that produces a plain text report of test run results.
 * The report is written to a file which is passed in the parameters to
 * {@link #handleResult(org.jtiger.framework.FixtureResults, org.jtiger.framework.ReadOnlyArray) the handleResult method}.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class TextFixtureResultsHandler implements FixtureResultsHandler
{
    /**
     * Create a default <tt>TextFixtureResultsHandler</tt>.
     */
    public TextFixtureResultsHandler()
    {

    }

    /**
     * Write a plain text report of the given test run results to a file which is passed in the parameters.
     * If the <tt>params</tt> are empty, the current directory is used to write the report to in a file called
     * 'result.txt'.
     *
     * @param results The test run results to produce the plain text report of.
     * @param params The parameters that contain at least one parameter which is the file to write the plain text report
     * to otherwise the current directory is used.
     * @throws FixtureResultsHandlerException If an error occurs while writing the plain text report.
     */
    public void handleResult(final FixtureResults results,  final ReadOnlyArray<String> params) throws FixtureResultsHandlerException
    {
        final File destination;

        if(params == null || params.length() == 0)
        {
            destination = new File("result.txt");
        }
        else
        {
            destination = new File(params.get(0));
        }

        PrintWriter out = null;

        try
        {
            out = new PrintWriter(new FileWriter(destination));

            for(FixtureResult result : results)
            {
                for(TestResult tr : result)
                {
                    out.println(tr);
                }

                out.println();
            }
        }
        catch(IOException e)
        {
            throw new FixtureResultsHandlerException(e.getMessage(), e);
        }
        finally
        {
            if(out != null)
            {
                out.close();
            }
        }
    }

}
