/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import java.util.Arrays;
import org.jtiger.framework.FixtureResult;

/**
 * A bean that is used by {@link org.jtiger.report.xml.XmlFixtureResultsHandler the XML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class FixtureResultBeanImpl implements FixtureResultBean
{
    private static final long serialVersionUID = 2L;

    private TestResultBean[] testResults;

    /**
     * Create a default <tt>FixtureResultBeanImpl</tt>.
     */
    public FixtureResultBeanImpl()
    {
        testResults = new TestResultBean[0];
    }

    FixtureResultBeanImpl(final FixtureResult fr)
    {
        testResults = new TestResultBean[fr.size()];

        for(int index = 0; index < testResults.length; index++)
        {
            testResults[index] = new TestResultBeanImpl(fr.get(0));
        }
    }

    /**
     * Returns the testResults property of the bean.
     *
     * @return The testResults property of the bean.
     */
    public TestResultBean[] getTestResults()
    {
        return testResults;
    }

    /**
     * Sets the testResults property of the bean.
     *
     * @param testResults The testResults property of the bean.
     */
    public void setTestResults(final TestResultBean[] testResults)
    {
        this.testResults = testResults;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the testResults property.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the testResults property.
     */
    @Override
    public String toString()
    {
        return Arrays.toString(testResults);
    }

    /**
     * Compares two instance of <tt>FixtureResultBeanImpl</tt> returning <code>true</code> iff the testResults
     * properties are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>FixtureResultBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the testResults properties are equal, <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != FixtureResultBeanImpl.class)
        {
            return false;
        }

        final FixtureResultBeanImpl r = (FixtureResultBeanImpl)o;

        return Arrays.equals(testResults, r.testResults);
    }

    /**
     * Returns a hash code for this <tt>FixtureResultBeanImpl</tt> based on the testResults property.
     *
     * @return A hash code for this <tt>FixtureResultBeanImpl</tt> based on the testResults property.
     */
    @Override
    public int hashCode()
    {
        return Arrays.hashCode(testResults);
    }
}
