/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import java.util.Arrays;
import org.jtiger.framework.FixtureResult;
import org.jtiger.framework.FixtureResults;

/**
 * A bean that is used by {@link XmlFixtureResultsHandler the XML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class FixtureResultsBeanImpl
        implements FixtureResultsBean
{
    private static final long serialVersionUID = 2L;

    private FixtureResultBean[] fixtureResults;

    /**
     * Create a default <tt>FixtureResultsBeanImpl</tt>.
     */
    public FixtureResultsBeanImpl()
    {
        fixtureResults = new FixtureResultBean[0];
    }

    FixtureResultsBeanImpl(final FixtureResults fr)
    {
        fixtureResults = new FixtureResultBean[fr.size()];

        int index = 0;

        for(FixtureResult result : fr)
        {
            fixtureResults[index] = new FixtureResultBeanImpl(result);

            index++;
        }
    }

    /**
     * Returns the fixtureResults property of the bean.
     *
     * @return The fixtureResults property of the bean.
     */
    public FixtureResultBean[] getFixtureResults()
    {
        return fixtureResults;
    }

    /**
     * Sets the fixtureResults property of the bean.
     *
     * @param fixtureResults The fixtureResults property of the bean.
     */
    public void setFixtureResults(final FixtureResultBean[] fixtureResults)
    {
        this.fixtureResults = fixtureResults;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the fixtureResults property.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the fixtureResults property.
     */
    @Override
    public String toString()
    {
        return Arrays.toString(fixtureResults);
    }

    /**
     * Compares two instance of <tt>FixtureResultsBeanImpl</tt> returning <code>true</code> iff the fixtureResults
     * properties are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>FixtureResultsBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the fixtureResults properties are equal, <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != FixtureResultsBeanImpl.class)
        {
            return false;
        }

        final FixtureResultsBeanImpl r = (FixtureResultsBeanImpl)o;

        return Arrays.equals(fixtureResults, r.fixtureResults);
    }

    /**
     * Returns a hash code for this <tt>FixtureResultsBeanImpl</tt> based on the fixtureResults property.
     *
     * @return A hash code for this <tt>FixtureResultsBeanImpl</tt> based on the fixtureResults property.
     */
    @Override
    public int hashCode()
    {
        return Arrays.hashCode(fixtureResults);
    }
}
