/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import java.util.Arrays;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.TestResult;

/**
 * A bean that is used by {@link XmlFixtureResultsHandler the XML result handler} to produce a report.
 *
 * @author Tony Morris
 * @version 2.1<br/>
 *          <i>Build Number 0376</i><br/>
 *          <i>Build Time 2006-07-28 01:50.16.218 CET (GMT + 1)</i>
 */
public final class TestResultBeanImpl
        implements TestResultBean
{
    private static final long serialVersionUID = 2L;

    private String testResult;
    private String message;
    private Throwable exception;
    private Long elapsedTime;
    private String[] categories;
    private String testName;
    private String testDescription;
    private String testMethodName;
    private String fixtureName;
    private String fixtureDescription;
    private Class<?> fixtureClass;

    /**
     * Create a default <tt>TestResultBeanImpl</tt>.
     */
    public TestResultBeanImpl()
    {

    }

    TestResultBeanImpl(final TestResult tr)
    {
        setTestResult(tr.getTestResultType().toString());
        setMessage(tr.getMessage());
        setException(tr.getException());
        setElapsedTime(tr.getElapsedTime());

        final ReadOnlyArray<String> categories = tr.getCategories();
        final String[] aCategories = new String[categories.length()];
        for(int i = 0; i < aCategories.length; i++)
        {
            aCategories[i] = categories.get(i);
        }
        setCategories(aCategories);

        setTestName(tr.getTestName());
        setTestDescription(tr.getTestDescription());
        setTestMethodName(tr.getTestMethodName());
        setFixtureName(tr.getFixtureName());
    }

    /**
     * Returns the testResult property of the bean.
     *
     * @return The testResult property of the bean.
     */
    public String getTestResult()
    {
        return testResult;
    }

    /**
     * Sets the testResult property of the bean.
     *
     * @param testResult The testResult property of the bean.
     */
    public void setTestResult(final String testResult)
    {
        this.testResult = testResult;
    }

    /**
     * Returns the message property of the bean.
     *
     * @return The message property of the bean.
     */
    public String getMessage()
    {
        return message;
    }

    /**
     * Sets the message property of the bean.
     *
     * @param message The message property of the bean.
     */
    public void setMessage(final String message)
    {
        this.message = message;
    }

    /**
     * Returns the exception property of the bean.
     *
     * @return The exception property of the bean.
     */
    public Throwable getException()
    {
        return exception;
    }

    /**
     * Sets the exception property of the bean.
     *
     * @param exception The exception property of the bean.
     */
    public void setException(final Throwable exception)
    {
        this.exception = exception;
    }

    /**
     * Returns the elapsedTime property of the bean.
     *
     * @return The elapsedTime property of the bean.
     */
    public Long getElapsedTime()
    {
        return elapsedTime;
    }

    /**
     * Sets the elapsedTime property of the bean.
     *
     * @param elapsedTime The elapsedTime property of the bean.
     */
    public void setElapsedTime(final Long elapsedTime)
    {
        this.elapsedTime = elapsedTime;
    }

    /**
     * Returns the categories property of the bean.
     *
     * @return The categories property of the bean.
     */
    public String[] getCategories()
    {
        return categories;
    }

    /**
     * Sets the categories property of the bean.
     *
     * @param categories The categories property of the bean.
     */
    public void setCategories(final String[] categories)
    {
        this.categories = categories;
    }

    /**
     * Returns the testName property of the bean.
     *
     * @return The testName property of the bean.
     */
    public String getTestName()
    {
        return testName;
    }

    /**
     * Sets the testName property of the bean.
     *
     * @param testName The testName property of the bean.
     */
    public void setTestName(final String testName)
    {
        this.testName = testName;
    }

    /**
     * Returns the testDescription property of the bean.
     *
     * @return The testDescription property of the bean.
     */
    public String getTestDescription()
    {
        return testDescription;
    }

    /**
     * Sets the testDescription property of the bean.
     *
     * @param testDescription The testDescription property of the bean.
     */
    public void setTestDescription(final String testDescription)
    {
        this.testDescription = testDescription;
    }

    /**
     * Returns the testMethodName property of the bean.
     *
     * @return The testMethodName property of the bean.
     */
    public String getTestMethodName()
    {
        return testMethodName;
    }

    /**
     * Sets the testMethodName property of the bean.
     *
     * @param testMethodName The testMethodName property of the bean.
     */
    public void setTestMethodName(final String testMethodName)
    {
        this.testMethodName = testMethodName;
    }

    /**
     * Returns the fixtureName property of the bean.
     *
     * @return The fixtureName property of the bean.
     */
    public String getFixtureName()
    {
        return fixtureName;
    }

    /**
     * Sets the fixtureName property of the bean.
     *
     * @param fixtureName The fixtureName property of the bean.
     */
    public void setFixtureName(final String fixtureName)
    {
        this.fixtureName = fixtureName;
    }

    /**
     * Returns the fixtureDescription property of the bean.
     *
     * @return The fixtureDescription property of the bean.
     */
    public String getFixtureDescription()
    {
        return fixtureDescription;
    }

    /**
     * Sets the fixtureDescription property of the bean.
     *
     * @param fixtureDescription The fixtureDescription property of the bean.
     */
    public void setFixtureDescription(final String fixtureDescription)
    {
        this.fixtureDescription = fixtureDescription;
    }

    /**
     * Returns the fixtureClass property of the bean.
     *
     * @return The fixtureClass property of the bean.
     */
    public Class<?> getFixtureClass()
    {
        return fixtureClass;
    }

    /**
     * Sets the fixtureClass property of the bean.
     *
     * @param fixtureClass The fixtureClass property of the bean.
     */
    public void setFixtureClass(final Class<?> fixtureClass)
    {
        this.fixtureClass = fixtureClass;
    }

    /**
     * Returns a <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the testResult property, the message property, the exception property, the elapsedTime property, the
     * categories property, the testName property, the testDescription property, the testMethodName property, the
     * testMethodParameterTypes property, the fixtureName property, the fixtureDescription property, and the
     * fixtureClass property.
     *
     * @return A <a href="http://java.sun.com/j2se/1.5.0/docs/api/java/lang/String.html">java.lang.String</a> representation of the bean, which
     * consists of the testResult property, the message property, the exception property, the elapsedTime property, the
     * categories property, the testName property, the testDescription property, the testMethodName property, the
     * testMethodParameterTypes property, the fixtureName property, the fixtureDescription property, and the
     * fixtureClass property.
     */
    @Override
    public String toString()
    {
        final StringBuilder sb = new StringBuilder();

        sb.append('[');
        sb.append(testResult);
        sb.append("][");
        sb.append(message);
        sb.append("][");
        sb.append(exception);
        sb.append("][");
        sb.append(elapsedTime);
        sb.append("][");
        sb.append(Arrays.toString(categories));
        sb.append("][");
        sb.append(testName);
        sb.append("][");
        sb.append(testDescription);
        sb.append("][");
        sb.append(testMethodName);
        sb.append("][");
        sb.append(fixtureName);
        sb.append("][");
        sb.append(fixtureDescription);
        sb.append("][");
        sb.append(fixtureClass);
        sb.append(']');

        return sb.toString();
    }

    /**
     * Compares two instance of <tt>TestResultBeanImpl</tt> returning <code>true</code> iff the testResult, message,
     * exception, elapsedTime, categories, testName, testDescription, testMethodName, testMethodParameterTypes,
     * fixtureName, fixtureDescription, and fixtureClass properties are equal, <code>false</code> otherwise.
     *
     * @param o An instance of <tt>TestResultBeanImpl</tt> to compare for equality.
     * @return <code>true</code> iff the testResult, message, exception, elapsedTime, categories, testName,
     * testDescription, testMethodName, testMethodParameterTypes, fixtureName, fixtureDescription, and fixtureClass
     * properties are equal, <code>false</code> otherwise.
     */
    @Override
    public boolean equals(final Object o)
    {
        if(this == o)
        {
            return true;
        }

        if(o == null || o.getClass() != TestResultBeanImpl.class)
        {
            return false;
        }

        final TestResultBeanImpl r = (TestResultBeanImpl)o;

        return (testResult == null ? r.testResult == null : testResult.equals(r.testResult)) &&
                (message == null ? r.message == null : message.equals(r.message)) &&
                (exception == null ? r.exception == null : exception.equals(r.exception)) &&
                (elapsedTime == null ? r.elapsedTime == null : elapsedTime.equals(r.elapsedTime)) &&
                (categories == null ? r.categories == null : Arrays.equals(categories, r.categories)) &&
                (testName == null ? r.testName == null : testName.equals(r.testName)) &&
                (testDescription == null ? r.testDescription == null : testDescription.equals(r.testDescription)) &&
                (testMethodName == null ? r.testMethodName == null : testMethodName.equals(r.testMethodName)) &&
                (fixtureName == null ? r.fixtureName == null : fixtureName.equals(r.fixtureName)) &&
                (fixtureDescription == null ? r.fixtureDescription == null : fixtureDescription.equals(r.fixtureDescription)) &&
                (fixtureClass == r.fixtureClass);
    }

    /**
     * Returns a hash code for this <tt>TestResultBeanImpl</tt> based on the testResult, message, exception, elapsedTime,
     * categories, testName, testDescription, testMethodName, testMethodParameterTypes, fixtureName, fixtureDescription,
     * and fixtureClass properties.
     *
     * @return A hash code for this <tt>TestResultBeanImpl</tt> based on the testResult, message, exception, elapsedTime,
     * categories, testName, testDescription, testMethodName, testMethodParameterTypes, fixtureName, fixtureDescription,
     * and fixtureClass properties.
     */
    @Override
    public int hashCode()
    {
        final int oddPrime = 461;
        int result = 73;

        if(testResult != null)
        {
            result = result * oddPrime + testResult.hashCode();
        }

        if(message != null)
        {
            result = result * oddPrime + message.hashCode();
        }

        if(exception != null)
        {
            result = result * oddPrime + exception.hashCode();
        }

        if(elapsedTime != null)
        {
            result = result * oddPrime + elapsedTime.hashCode();
        }

        if(categories != null)
        {
            result = result * oddPrime + Arrays.hashCode(categories);
        }

        if(testName != null)
        {
            result = result * oddPrime + testName.hashCode();
        }

        if(testDescription != null)
        {
            result = result * oddPrime + testDescription.hashCode();
        }

        if(testMethodName != null)
        {
            result = result * oddPrime + testMethodName.hashCode();
        }

        if(fixtureName != null)
        {
            result = result * oddPrime + fixtureName.hashCode();
        }

        if(fixtureDescription != null)
        {
            result = result * oddPrime + fixtureDescription.hashCode();
        }

        if(fixtureClass != null)
        {
            result = result * oddPrime + fixtureClass.hashCode();
        }

        return result;
    }
}
