/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertTrue;

@org.jtiger.framework.Fixture(value = "BuildExceptionMessages", description = "Performs Unit Tests on org.jtiger.ant.BuildExceptionMessages")
@org.jtiger.framework.Category("org.jtiger.ant.BuildExceptionMessages")
public final class TestBuildExceptionMessages
{
    public TestBuildExceptionMessages()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(BuildExceptionMessages.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void missingJavaElement()
    {
        assertNotNull(BuildExceptionMessages.missingJavaElement());
        assertTrue(BuildExceptionMessages.missingJavaElement().length() > 0);
    }

    @Test
    public void missingFixturesElement()
    {
        assertNotNull(BuildExceptionMessages.missingFixturesElement());
        assertTrue(BuildExceptionMessages.missingFixturesElement().length() > 0);
    }

    @Test
    public void missingFixturesClasses()
    {
        assertNotNull(BuildExceptionMessages.missingFixturesClasses());
        assertTrue(BuildExceptionMessages.missingFixturesClasses().length() > 0);
    }

    @Test
    public void missingClassnameAttributeFixtureElement()
    {
        assertNotNull(BuildExceptionMessages.missingClassnameAttributeFixtureElement());
        assertTrue(BuildExceptionMessages.missingClassnameAttributeFixtureElement().length() > 0);
    }

    @Test
    public void missingRegexAttributeCategoryElement()
    {
        assertNotNull(BuildExceptionMessages.missingRegexAttributeCategoryElement());
        assertTrue(BuildExceptionMessages.missingRegexAttributeCategoryElement().length() > 0);
    }

    @Test
    public void missingNameAttributeResultElement()
    {
        assertNotNull(BuildExceptionMessages.missingNameAttributeResultElement());
        assertTrue(BuildExceptionMessages.missingNameAttributeResultElement().length() > 0);
    }

    @Test
    public void badResultName()
    {
        assertNotNull(BuildExceptionMessages.badResultName("name"));
        assertTrue(BuildExceptionMessages.badResultName("name").length() > 0);
    }
}
