/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.ant.FileNameToClassNameFactory.newFileNameToClassName;

@org.jtiger.framework.Fixture(value = "FileNameToClassNameFactory", description = "Performs Unit Tests on org.jtiger.ant.FileNameToClassNameFactory")
@org.jtiger.framework.Category("org.jtiger.ant.FileNameToClassNameFactory")
public final class TestFileNameToClassNameFactory
{
    public TestFileNameToClassNameFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FileNameToClassNameFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void toClassName()
    {
        assertNull(newFileNameToClassName().toClassName(null));
        assertNull(newFileNameToClassName().toClassName("x"));
        assertNull(newFileNameToClassName().toClassName("java"));
        assertNull(newFileNameToClassName().toClassName(".java"));
        assertNull(newFileNameToClassName().toClassName("class"));
        assertNull(newFileNameToClassName().toClassName(".class"));
        assertNull(newFileNameToClassName().toClassName("X.JAVA"));
        assertNull(newFileNameToClassName().toClassName("X.CLASS"));
        assertEqual("X", newFileNameToClassName().toClassName("X.java"));
        assertEqual("com.foo.bar.X", newFileNameToClassName().toClassName("com/foo/bar/X.java"));
        assertEqual("X", newFileNameToClassName().toClassName("X.class"));
        assertEqual("com.foo.bar.X", newFileNameToClassName().toClassName("com/foo/bar/X.class"));
    }
}
