/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Test;
import org.jtiger.framework.FixtureResultsHandler;
import org.jtiger.framework.FixtureResults;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.report.html.HtmlFixtureResultsHandler;
import org.jtiger.report.text.TextFixtureResultsHandler;
import org.jtiger.report.xml.XmlFixtureResultsHandler;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.ant.FixtureResultsHandlerFactory.newFixtureResultsHandler;

@org.jtiger.framework.Fixture(value = "FixtureResultsHandlerFactory", description = "Performs Unit Tests on org.jtiger.ant.FixtureResultsHandlerFactory")
@org.jtiger.framework.Category("org.jtiger.ant.FixtureResultsHandlerFactory")
public final class TestFixtureResultsHandlerFactory
{
    public TestFixtureResultsHandlerFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureResultsHandlerFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testNewFixtureResultsHandler() throws ClassNotFoundException
    {
        assertNull(newFixtureResultsHandler(null));
        assertSame(TextFixtureResultsHandler.class, newFixtureResultsHandler("~text"));
        assertSame(TextFixtureResultsHandler.class, newFixtureResultsHandler("~TEXT"));
        assertSame(XmlFixtureResultsHandler.class, newFixtureResultsHandler("~xml"));
        assertSame(XmlFixtureResultsHandler.class, newFixtureResultsHandler("~XML"));
        assertSame(HtmlFixtureResultsHandler.class, newFixtureResultsHandler("~html"));
        assertSame(HtmlFixtureResultsHandler.class, newFixtureResultsHandler("~HTML"));
        assertEqual(FixtureResultsHandlerImpl.class, newFixtureResultsHandler(FixtureResultsHandlerImpl.class.getName()));
        assertNull(newFixtureResultsHandler(NotFixtureResultsHandler.class.getName()));
    }

    private final class FixtureResultsHandlerImpl implements FixtureResultsHandler
    {
        public void handleResult(final FixtureResults results, final ReadOnlyArray<String> params)
        {

        }
    }

    private final class NotFixtureResultsHandler
    {

    }
}
