/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.FileSet;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertEqual;

@org.jtiger.framework.Fixture(value = "Fixtures", description = "Performs Unit Tests on org.jtiger.ant.Fixtures")
@org.jtiger.framework.Category("org.jtiger.ant.Fixtures")
public final class TestFixtures
{
    public TestFixtures()
    {

    }

    @Test
    public void constructor()
    {
        new Fixtures();
    }

    @Test
    public void fixtures()
    {
        final Fixtures f = new Fixtures();
        final Fixture f1 = f.createFixture();
        final Fixture f2 = f.createFixture();
        final List<Fixture> l = new LinkedList<Fixture>();
        l.add(f1);
        l.add(f2);
        assertEqual(l, f.getFixtures());
    }

    @Test
    public void filesets()
    {
        final Fixtures f = new Fixtures();
        final FileSet f1 = f.createFileSet();
        final FileSet f2 = f.createFileSet();
        final List<FileSet> l = new LinkedList<FileSet>();
        l.add(f1);
        l.add(f2);
        assertEqual(l, f.getFileSets());
    }

    @Test
    public void toStringArray() throws IOException
    {
        final File dir = new File(System.getProperty("java.io.tmpdir"), "dir" + System.currentTimeMillis());
        dir.mkdirs();
        final File file1 = new File(dir, "file1.java");
        final File file2 = new File(dir, "file2.class");
        final File file3 = new File(dir, "file3.java");
        final File file4 = new File(dir, "file4.java");
        final File file5 = new File(dir, "file5.class");
        new FileOutputStream(file1).close();
        new FileOutputStream(file2).close();
        new FileOutputStream(file3).close();
        new FileOutputStream(file4).close();
        new FileOutputStream(file5).close();

        final Fixtures f = new Fixtures();
        final FileSet fileset = f.createFileSet();
        fileset.setDir(dir);

        final Fixture fixture1 = f.createFixture();
        fixture1.setClassname(String.class.getName());
        final Fixture fixture2 = f.createFixture();
        fixture2.setClassname(Integer.class.getName());
        final String[] a = f.toStringArray(new Project());

        assertEqual(7, a.length);
        assertEqual(String.class.getName(), a[0]);
        assertEqual(Integer.class.getName(), a[1]);
        assertEqual("file1", a[2]);
        assertEqual("file2", a[3]);
        assertEqual("file3", a[4]);
        assertEqual("file4", a[5]);
        assertEqual("file5", a[6]);
    }
}
