/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertNotNull;

@org.jtiger.framework.Fixture(value = "JTigerTask", description = "Performs Unit Tests on org.jtiger.ant.JTigerTask")
@org.jtiger.framework.Category("org.jtiger.ant.JTigerTask")
public final class TestJTigerTask
{
    public TestJTigerTask()
    {

    }

    @Test
    public void constructor()
    {
        new JTigerTask();
    }

    @Test
    public void createFixtures()
    {
        final JTigerTask t = new JTigerTask();
        final Fixtures f = t.createFixtures();
        assertNotNull(f);
    }

    @Test
    public void setDefinitionClass()
    {
        final JTigerTask t = new JTigerTask();
        t.setDefinitionClass("definitionclass");
    }

    @Test
    public void setSutdClass()
    {
        final JTigerTask t = new JTigerTask();
        t.setSutdClass("sutdclass");
    }

    @Test
    public void createCategory()
    {
        final JTigerTask t = new JTigerTask();
        final Category c = t.createCategory();
        assertNotNull(c);
    }

    @Test
    public void setHaltOnFailure()
    {
        final JTigerTask t = new JTigerTask();
        t.setHaltOnFailure(true);
    }

    @Test
    public void setJUnit()
    {
        final JTigerTask t = new JTigerTask();
        t.setJUnit(true);
    }

    @Test
    public void createResult()
    {
        final JTigerTask t = new JTigerTask();
        final Result r = t.createResult();
        assertNotNull(r);
    }

    @Test
    public void createJava()
    {
        final JTigerTask t = new JTigerTask();
        final Java j = t.createJava();
        assertNotNull(j);
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute1()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute2()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute3()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        t.createFixtures();
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute4()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname"));
        f.getFixtures().add(new Fixture(null));
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute5()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname1"));
        f.getFixtures().add(new Fixture("classname2"));
        final Result r = t.createResult();
        r.setName(null);
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute6()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname1"));
        f.getFixtures().add(new Fixture("classname2"));
        t.setDefinitionClass("definitionclass");
        t.setSutdClass("sutdclass");
        t.setHaltOnFailure(true);
        final Category cat1 = t.createCategory();
        cat1.setRegex("regex1");
        final Category cat2 = t.createCategory();
        cat2.setRegex("regex2");
        final Category cat3 = t.createCategory();
        cat3.setRegex(null);
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute7()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname1"));
        f.getFixtures().add(new Fixture("classname2"));
        t.setDefinitionClass("definitionclass");
        t.setSutdClass("sutdclass");
        t.setHaltOnFailure(true);
        final Category cat1 = t.createCategory();
        cat1.setRegex("regex1");
        final Category cat2 = t.createCategory();
        cat2.setRegex("regex2");
        final Result r = t.createResult();
        r.setName(null);
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute8()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname1"));
        f.getFixtures().add(new Fixture("classname2"));
        t.setJUnit(true);
        t.setHaltOnFailure(true);
        final Category cat1 = t.createCategory();
        cat1.setRegex("regex1");
        final Category cat2 = t.createCategory();
        cat2.setRegex("regex2");
        final Result r = t.createResult();
        r.setName("bad.class");
        t.execute();
    }

    @Test
    @ExpectException(BuildException.class)
    public void execute9()
    {
        final JTigerTask t = new JTigerTask();
        t.setProject(new Project());
        t.createJava();
        final Fixtures f = t.createFixtures();
        f.getFixtures().add(new Fixture("classname1"));
        f.getFixtures().add(new Fixture("classname2"));
        t.setJUnit(true);
        t.setHaltOnFailure(true);
        final Category cat1 = t.createCategory();
        cat1.setRegex("regex1");
        final Category cat2 = t.createCategory();
        cat2.setRegex("regex2");
        final Result r = t.createResult();
        r.setName("java.lang.String");
        t.execute();
    }
}
