/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.io.File;
import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Target;
import org.apache.tools.ant.types.Assertions;
import org.apache.tools.ant.types.Commandline;
import org.apache.tools.ant.types.Environment;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.Permissions;
import org.apache.tools.ant.types.PropertySet;
import org.apache.tools.ant.types.Reference;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertTrue;

@org.jtiger.framework.Fixture(value = "Java", description = "Performs Unit Tests on org.jtiger.ant.Java")
@org.jtiger.framework.Category("org.jtiger.ant.Java")
public final class TestJava
{
    public TestJava()
    {

    }

    @Test
    public void constructor()
    {
        new Java(new org.apache.tools.ant.taskdefs.Java());
    }

    @Test
    public void addAssertions()
    {
        final Assertions a = new Assertions();
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.addAssertions(a);
    }

    @Test
    public void addEnv()
    {
        final Environment.Variable envvar = new Environment.Variable();
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.addEnv(envvar);
    }

    @Test
    public void addSysproperty()
    {
        final Environment.Variable sysprop = new Environment.Variable();
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.addSysproperty(sysprop);
    }

    @Test
    public void addSyspropertyset()
    {
        final PropertySet syspropset = new PropertySet();
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.addSyspropertyset(syspropset);
    }

    @Test
    public void createBootclasspath()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final Path bootclasspath = j.createBootclasspath();
        assertNotNull(bootclasspath);
    }

    @Test
    public void createClasspath()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final Path classpath = j.createClasspath();
        assertNotNull(classpath);
    }

    @Test
    public void createJvmArg()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final Commandline.Argument  arg = j.createJvmarg();
        assertNotNull(arg);
    }

    @Test
    public void createPermissions()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final Permissions p = j.createPermissions();
        assertNotNull(p);
    }

    @Test
    public void setAppend()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setAppend(true);
    }

    @Test
    public void setClasspath()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setClasspath(new Path(new Project()));
    }

    @Test
    public void setClasspathref()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setClasspathRef(new Reference());
    }

    @Test
    public void setDir()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setDir(new File("."));
    }

    @Test
    public void setError()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setError(new File("."));
    }

    @Test
    public void setErrorProperty()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setErrorProperty("property");
    }

    @Test
    public void setFailonerror()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setFailonerror(true);
    }

    @Test
    public void setJvm()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setJvm("java");
    }

    @Test
    public void setLogError()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setLogError(true);
    }

    @Test
    public void setMaxmemory()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setMaxmemory("max");
    }

    @Test
    public void setNewenvironment()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setNewenvironment(true);
    }

    @Test
    public void setOutput()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setOutput(new File("."));
    }

    @Test
    public void setOutputproperty()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setOutputproperty("property");
    }

    @Test
    public void setResultProperty()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setResultProperty("property");
    }

    @Test
    public void setSpawn()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setSpawn(true);
    }

    @Test
    public void setTimeout()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setTimeout(7L);
    }

    @Test
    public void execute()
    {
        final DummyJava dummy = new DummyJava();
        final Java j = new Java(dummy);
        j.execute();
        assertTrue(dummy.isExecuted());
    }

    @Test
    public void setDescription()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setDescription("description");
    }

    @Test
    public void createArg()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final Commandline.Argument  arg = j.createArg();
        assertNotNull(arg);
    }

    @Test
    public void setClassname()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setClassname("classname");
    }

    @Test
    public void setFork()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setFork(true);
    }

    @Test
    public void setLocation()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setLocation(new Location("location"));
    }

    @Test
    public void setOwningTarget()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setOwningTarget(new Target());
    }

    @Test
    public void setTaskName()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setTaskName("taskname");
    }

    @Test
    public void setProject()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        j.setProject(new Project());
    }

    @Test
    public void getJava()
    {
        final Java j = new Java(new org.apache.tools.ant.taskdefs.Java());
        final org.apache.tools.ant.taskdefs.Java java = j.getJava();
        assertNotNull(java);
    }

    private static final class DummyJava extends org.apache.tools.ant.taskdefs.Java
    {
        private boolean executed;

        public DummyJava()
        {

        }

        public void execute()
        {
            executed = true;
        }

        boolean isExecuted()
        {
            return executed;
        }
    }
}
