/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.ant;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.LinkedList;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertTrue;

@org.jtiger.framework.Fixture(value = "LogMessages", description = "Performs Unit Tests on org.jtiger.ant.LogMessages")
@org.jtiger.framework.Category("org.jtiger.ant.LogMessages")
public final class TestLogMessages
{
    public TestLogMessages()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(LogMessages.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void usingFixtureClasses()
    {
        assertNotNull(LogMessages.usingFixtureClasses());
        assertTrue(LogMessages.usingFixtureClasses().length() > 0);
    }

    @Test
    public void usingDefinitionClass()
    {
        assertNotNull(LogMessages.usingDefinitionClass("x"));
        assertTrue(LogMessages.usingDefinitionClass("x").length() > 0);
    }

    @Test
    public void usingSetUpTearDownClass()
    {
        assertNotNull(LogMessages.usingSetUpTearDownClass("x"));
        assertTrue(LogMessages.usingSetUpTearDownClass("x").length() > 0);
    }

    @Test
    public void haltOnFailure()
    {
        assertNotNull(LogMessages.haltOnFailure(true));
        assertTrue(LogMessages.haltOnFailure(true).length() > 0);
    }

    @Test
    public void totalNumberOfCategories()
    {
        assertNotNull(LogMessages.totalNumberOfCategories(7));
        assertTrue(LogMessages.totalNumberOfCategories(7).length() > 0);
    }

    @Test
    public void usingCategoryRegularExpression()
    {
        assertNotNull(LogMessages.usingCategoryRegularExpression("regex"));
        assertTrue(LogMessages.usingCategoryRegularExpression("regex").length() > 0);
    }

    @Test
    public void usingDefaultResultName()
    {
        assertNotNull(LogMessages.usingDefaultResultName());
        assertTrue(LogMessages.usingDefaultResultName().length() > 0);
    }

    @Test
    public void usingResultName()
    {
        assertNotNull(LogMessages.usingResultName("x"));
        assertTrue(LogMessages.usingResultName("x").length() > 0);
    }

    @Test
    public void usingResultParams()
    {
        assertNotNull(LogMessages.usingResultParams(new LinkedList<Param>()));
        assertTrue(LogMessages.usingResultParams(new LinkedList<Param>()).length() > 0);
    }

    @Test
    public void usingJUnit()
    {
        assertNotNull(LogMessages.usingJUnit());
        assertTrue(LogMessages.usingJUnit().length() > 0);
    }
}
