/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertNotEqual;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.Basic.assertNotSame;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;

@Fixture(value = "Basic", description = "Performs Unit Tests on org.jtiger.framework.Basic")
@Category("org.jtiger.assertion.Basic")
public final class TestBasic
{
    public TestBasic()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(Basic.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertTrue1()
    {
        assertTrue(true);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertTrue2()
    {
        assertTrue(false);
    }

    @Test
    public void testAssertFalse1()
    {
        assertFalse(false);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertFalse2()
    {
        assertFalse(true);
    }

    @Test
    public void testAssertNull1()
    {
        assertNull(null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNull2()
    {
        assertNull(new Object());
    }

    @Test
    public void testAssertNotNull1()
    {
        assertNotNull(new Object());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotNull2()
    {
        assertNotNull(null);
    }

    @Test
    public void testAssertEqual1()
    {
        assertEqual(new String("x"), new String("x"));
        assertEqual((Object)null, (Object)null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual2()
    {
        assertEqual(new String("x"), new String("y"));
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual3()
    {
        assertEqual(null, new String("y"));
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual4()
    {
        assertEqual(new String("x"), null);
    }

    @Test
    public void testAssertEqual5()
    {
        assertEqual(7.0, 7.0);
        final double d = 0.0;
        final float f = 0.0F;
        assertEqual(7.0/d, 7.0/d);
        assertEqual(7.0/f, 7.0/d);
    }

    @Test
    public void testAssertEqual6()
    {
        assertEqual(7.0F, 7.0F);
        final float f = 0.0F;
        final double d = 0.0;
        assertEqual(7.0F/d, 7.0F/f);
    }

    @Test
    public void testAssertEqual7()
    {
        assertEqual(true, true);
        assertEqual(false, false);
        assertEqual((byte)7, (byte)7);
        assertEqual((short)7, (short)7);
        assertEqual('a', 'a');
        assertEqual(7, 7);
        assertEqual(7L, 7L);
        assertEqual(7, 7L);
        assertEqual((short)7, 7L);
        assertEqual((char)7, 7L);
        assertEqual((byte)7, 7L);
        assertEqual((byte)7, (short)7);
        assertEqual((short)7, (char)7);
        assertEqual((byte)7, (char)7);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual8()
    {
        assertEqual(7.0, 9.0);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual9()
    {
        final double d = 0.0;
        assertEqual(7.0/d, 7.0/1.0);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual10()
    {
        final double d = 0.0;
        assertEqual(7.0/1.0, 7.0/d);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual11()
    {
        final float f = 0.0F;
        assertEqual(7.0F/1.0F, 7.0F/f);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual12()
    {
        assertEqual(true, false);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual13()
    {
        assertEqual((byte)7, (byte)8);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual14()
    {
        assertEqual((short)7, (short)8);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual15()
    {
        assertEqual('a', 'A');
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual16()
    {
        assertEqual(7, 8);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual17()
    {
        assertEqual(7L, 8L);
    }

    @Test
    public void testAssertEqual18()
    {
        final String[] a1 = new String[]{"x", "y"};
        final String[] a2 = new String[]{"x", "y"};
        assertEqual(a1, a2);
        assertEqual((String[])null, (String[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual19()
    {
        final String[] a1 = new String[]{"x", "y"};
        final String[] a2 = new String[]{"y", "x"};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual20()
    {
        final double[] a1 = new double[]{3.0, 4.0};
        final double[] a2 = new double[]{3.0, 4.0};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual21()
    {
        assertEqual((double[])null, (double[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual22()
    {
        final double[] a1 = new double[]{3.0, 4.0};
        final double[] a2 = new double[]{4.0, 3.0};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual23()
    {
        final float[] a1 = new float[]{3.0F, 4.0F};
        final float[] a2 = new float[]{3.0F, 4.0F};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual24()
    {
        assertEqual((float[])null, (float[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual25()
    {
        final float[] a1 = new float[]{3.0F, 4.0F};
        final float[] a2 = new float[]{4.0F, 3.0F};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual26()
    {
        final boolean[] a1 = new boolean[]{true, false};
        final boolean[] a2 = new boolean[]{true, false};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual27()
    {
        assertEqual((boolean[])null, (boolean[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual28()
    {
        final boolean[] a1 = new boolean[]{true, false};
        final boolean[] a2 = new boolean[]{false, true};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual29()
    {
        final byte[] a1 = new byte[]{7, 8};
        final byte[] a2 = new byte[]{7, 8};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual30()
    {
        assertEqual((byte[])null, (byte[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual31()
    {
        final byte[] a1 = new byte[]{7, 8};
        final byte[] a2 = new byte[]{8, 7};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual32()
    {
        final short[] a1 = new short[]{7, 8};
        final short[] a2 = new short[]{7, 8};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual33()
    {
        assertEqual((short[])null, (short[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual34()
    {
        final short[] a1 = new short[]{7, 8};
        final short[] a2 = new short[]{8, 7};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual35()
    {
        final char[] a1 = new char[]{'a', 'b'};
        final char[] a2 = new char[]{'a', 'b'};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual36()
    {
        assertEqual((char[])null, (char[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual37()
    {
        final char[] a1 = new char[]{'a', 'b'};
        final char[] a2 = new char[]{'b', 'a'};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual38()
    {
        final int[] a1 = new int[]{7, 8};
        final int[] a2 = new int[]{7, 8};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual39()
    {
        assertEqual((int[])null, (int[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual40()
    {
        final int[] a1 = new int[]{7, 8};
        final int[] a2 = new int[]{8, 7};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual41()
    {
        final long[] a1 = new long[]{7L, 8L};
        final long[] a2 = new long[]{7L, 8L};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertEqual42()
    {
        assertEqual((long[])null, (long[])null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqual43()
    {
        final long[] a1 = new long[]{7L, 8L};
        final long[] a2 = new long[]{8L, 7L};
        assertEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual1()
    {
        assertNotEqual(new String("x"), new String("y"));
    }

    @Test
    public void testAssertNotEqual2()
    {
        assertNotEqual(null, new String("y"));
    }

    @Test
    public void testAssertNotEqual3()
    {
        assertNotEqual(new String("x"), null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual4()
    {
        assertNotEqual(new String("x"), new String("x"));
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual5()
    {
        assertNotEqual((Object)null, (Object)null);
    }

    @Test
    public void testAssertNotEqual6()
    {
        assertNotEqual(7.0, 9.0);
        final double d = 0.0;
        assertNotEqual(7.0/d, 7.0/1.0);
        assertNotEqual(7.0/1.0, 7.0/d);
    }

    @Test
    public void testAssertNotEqual7()
    {
        assertNotEqual(7.0F, 9.0F);
        final float f = 0.0F;
        assertNotEqual(7.0F/f, 7.0F/1.0F);
        assertNotEqual(7.0F/1.0F, 7.0F/f);
    }

    @Test
    public void testAssertNotEqual8()
    {
        assertNotEqual(true, false);
        assertNotEqual(false, true);
        assertNotEqual((byte)7, (byte)8);
        assertNotEqual((short)7, (short)8);
        assertNotEqual('a', 'A');
        assertNotEqual(7, 8);
        assertNotEqual(7L, 8L);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual9()
    {
        final String[] s1 = new String[]{"x", "y"};
        final String[] s2 = new String[]{"x", "y"};
        assertNotEqual(s1, s2);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual10()
    {
        assertNotEqual(7.0, 7.0, 1.0);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual11()
    {
        final double d = 0.0;
        assertNotEqual(7.0/d, 7.0/d);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual12()
    {
        assertNotEqual(7.0F, 7.0F);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual13()
    {
        final float f = 0.0F;
        assertNotEqual(7.0F/f, 7.0f/f);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual14()
    {
        assertNotEqual(true, true);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual15()
    {
        assertNotEqual((byte)7, (byte)7);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual16()
    {
        assertNotEqual((short)7, (short)7);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual17()
    {
        assertNotEqual('a', 'a');
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual18()
    {
        assertNotEqual(7 ,7);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual19()
    {
        assertNotEqual(7L ,7L);
    }

    @Test
    public void testAssertNotEqual20()
    {
        final String[] a1 = new String[]{"x", "y"};
        final String[] a2 = new String[]{"y", "x"};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual21()
    {
        final String[] a = new String[]{"x", "y"};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual22()
    {
        final String[] a = new String[]{"x", "y"};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual23()
    {
        assertNotEqual((Object[])null, (Object[])null);
    }

    @Test
    public void testAssertNotEqual24()
    {
        final double[] a1 = new double[]{7.0, 8.0};
        final double[] a2 = new double[]{8.0, 7.0};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual25()
    {
        final double[] a = new double[]{7.0, 8.0};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual26()
    {
        final double[] a = new double[]{7.0, 8.0};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual27()
    {
        assertNotEqual((double[])null, (double[])null);
    }

    @Test
    public void testAssertNotEqual28()
    {
        final float[] a1 = new float[]{7.0F, 8.0F};
        final float[] a2 = new float[]{8.0F, 7.0F};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual29()
    {
        final float[] a = new float[]{7.0F, 8.0F};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual30()
    {
        final float[] a = new float[]{7.0F, 8.0F};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual31()
    {
        assertNotEqual((float[])null, (float[])null);
    }

    @Test
    public void testAssertNotEqual32()
    {
        final boolean[] a1 = new boolean[]{true, false};
        final boolean[] a2 = new boolean[]{false, true};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual33()
    {
        final boolean[] a = new boolean[]{true, false};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual34()
    {
        final boolean[] a = new boolean[]{true, false};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual35()
    {
        assertNotEqual((boolean[])null, (boolean[])null);
    }

    @Test
    public void testAssertNotEqual36()
    {
        final byte[] a1 = new byte[]{7, 8};
        final byte[] a2 = new byte[]{8, 7};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual37()
    {
        final byte[] a = new byte[]{7, 8};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual38()
    {
        final byte[] a = new byte[]{7, 8};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual39()
    {
        assertNotEqual((byte[])null, (byte[])null);
    }

    @Test
    public void testAssertNotEqual40()
    {
        final short[] a1 = new short[]{7, 8};
        final short[] a2 = new short[]{8, 7};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual41()
    {
        final short[] a = new short[]{7, 8};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual42()
    {
        final short[] a = new short[]{7, 8};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual43()
    {
        assertNotEqual((short[])null, (short[])null);
    }

    @Test
    public void testAssertNotEqual44()
    {
        final char[] a1 = new char[]{'a', 'b'};
        final char[] a2 = new char[]{'b', 'a'};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual45()
    {
        final char[] a = new char[]{'a', 'b'};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual46()
    {
        final char[] a = new char[]{'a', 'b'};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual47()
    {
        assertNotEqual((char[])null, (char[])null);
    }

    @Test
    public void testAssertNotEqual48()
    {
        final int[] a1 = new int[]{7, 8};
        final int[] a2 = new int[]{8, 7};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual49()
    {
        final int[] a = new int[]{7, 8};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual50()
    {
        final int[] a = new int[]{7, 8};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual51()
    {
        assertNotEqual((int[])null, (int[])null);
    }

    @Test
    public void testAssertNotEqual52()
    {
        final long[] a1 = new long[]{7L, 8L};
        final long[] a2 = new long[]{8L, 7L};
        assertNotEqual(a1, a2);
    }

    @Test
    public void testAssertNotEqual53()
    {
        final long[] a = new long[]{7L, 8L};
        assertNotEqual(null, a);
    }

    @Test
    public void testAssertNotEqual54()
    {
        final long[] a = new long[]{7L, 8L};
        assertNotEqual(a, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotEqual55()
    {
        assertNotEqual((long[])null, (long[])null);
    }

    @Test
    public void testAssertSame1()
    {
        assertSame("x", "x");
        assertSame(null, null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSame2()
    {
        assertSame("x", new String("x"));
        assertSame(null, new String("x"));
        assertSame("x", null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSame3()
    {
        assertSame("x", new String("x"));
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSame4()
    {
        assertSame(null, new String("x"));
    }

    @Test
    public void testAssertNotSame1()
    {
        assertNotSame("x", null);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotSame2()
    {
        assertNotSame("x", "x");
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotSame3()
    {
        assertNotSame(null, null);
    }
}
