/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import static org.jtiger.assertion.BoxedTypePromoterFactory.newBoxedTypePromoter;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Category;
import org.jtiger.framework.Test;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Constructor;

@Fixture(value = "BoxedTypePromoterFactory", description = "Performs Unit Tests on org.jtiger.framework.BoxedTypePromoterFactory")
@Category("org.jtiger.assertion.BoxedTypePromoterFactory")
public final class TestBoxedTypePromoterFactory
{
    public TestBoxedTypePromoterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(BoxedTypePromoterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void promote1()
    {
        BoxedTypePromoter btp = newBoxedTypePromoter();

        assertNull(btp.promote(null));
        assertEqual(new Long(7), btp.promote((byte)7));
        assertEqual(new Long(7), btp.promote((short)7));
        assertEqual(new Long(7), btp.promote((char)7));
        assertEqual(new Long(7), btp.promote(7));
        assertEqual(new Double(7.0), btp.promote(7F));
    }
}
