/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Comparable.assertEqualComparesToZero;
import static org.jtiger.assertion.Comparable.assertNotEqualNotComparesToZero;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Category;
import org.jtiger.framework.Test;
import org.jtiger.framework.ExpectException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Constructor;

@Fixture(value = "Comparable", description = "Performs Unit Tests on org.jtiger.assertion.Comparable")
@Category("org.jtiger.assertion.Comparable")
public final class TestComparable
{
    public TestComparable()
    {

    }
    
    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(Comparable.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertEqualComparesToZero1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualComparesToZero(factory);
    }

    @Test
    @ExpectException(AssertionException.class)
    public void testAssertEqualComparesToZero2()
    {
        final ObjectFactory<EqualNotComparesToZero> factory = new ObjectFactory<EqualNotComparesToZero>()
        {
            public EqualNotComparesToZero newInstanceX()
            {
                return new EqualNotComparesToZero(true);
            }

            public EqualNotComparesToZero newInstanceY()
            {
                return new EqualNotComparesToZero(false);
            }
        };

        assertEqualComparesToZero(factory);
    }

    @Test
    public void testNotEqualNotComparesToZero1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertNotEqualNotComparesToZero(factory);
    }

    @Test
    @ExpectException(AssertionException.class)
    public void testNotEqualNotComparesToZero2()
    {
        final ObjectFactory<EqualNotComparesToZero> factory = new ObjectFactory<EqualNotComparesToZero>()
        {
            public EqualNotComparesToZero newInstanceX()
            {
                return new EqualNotComparesToZero(true);
            }

            public EqualNotComparesToZero newInstanceY()
            {
                return new EqualNotComparesToZero(false);
            }
        };

        assertNotEqualNotComparesToZero(factory);
    }

    public static final class EqualNotComparesToZero implements java.lang.Comparable<EqualNotComparesToZero>
    {
        private final boolean b;

        public EqualNotComparesToZero(final boolean b)
        {
            this.b = b;
        }

        @Override
        public boolean equals(final Object o)
        {
            return b == ((EqualNotComparesToZero)o).b;
        }

        public int compareTo(final EqualNotComparesToZero o)
        {
            if(b)
            {
                return -1;
            }
            else
            {
                return 0;
            }
        }
    }
}
