/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.ComparableTesterFactory.newComparableTester;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Category;
import org.jtiger.framework.Test;
import org.jtiger.framework.ExpectException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Constructor;
import java.lang.*;

@Fixture(value = "ComparableTesterFactory", description = "Performs Unit Tests on org.jtiger.assertion.ComparableTesterFactory")
@Category("org.jtiger.assertion.ComparableTesterFactory")
public final class TestComparableTesterFactory
{
    public TestComparableTesterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ComparableTesterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newComparableTester(null);
    }

    @Test
    public void equalComparesToZero1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertTrue(newComparableTester(factory).equalComparesToZero());
    }

    @Test
    public void equalComparesToZero2()
    {
        final ObjectFactory<EqualNotComparesToZero> factory = new ObjectFactory<EqualNotComparesToZero>()
        {
            public EqualNotComparesToZero newInstanceX()
            {
                return new EqualNotComparesToZero(true);
            }

            public EqualNotComparesToZero newInstanceY()
            {
                return new EqualNotComparesToZero(false);
            }
        };

        assertFalse(newComparableTester(factory).equalComparesToZero());
    }

    @Test
    public void equalNotComparesToZero1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertTrue(newComparableTester(factory).notEqualNotComparesToZero());
    }

    @Test
    public void equalNotComparesToZero2()
    {
        final ObjectFactory<EqualNotComparesToZero> factory = new ObjectFactory<EqualNotComparesToZero>()
        {
            public EqualNotComparesToZero newInstanceX()
            {
                return new EqualNotComparesToZero(true);
            }

            public EqualNotComparesToZero newInstanceY()
            {
                return new EqualNotComparesToZero(false);
            }
        };

        assertFalse(newComparableTester(factory).notEqualNotComparesToZero());
    }

    public static final class EqualNotComparesToZero implements java.lang.Comparable<EqualNotComparesToZero>
    {
        private final boolean b;

        public EqualNotComparesToZero(final boolean b)
        {
            this.b = b;
        }

        @Override
        public boolean equals(final Object o)
        {
            return b == ((EqualNotComparesToZero)o).b;
        }

        public int compareTo(final EqualNotComparesToZero o)
        {
            if(b)
            {
                return -1;
            }
            else
            {
                return 0;
            }
        }
    }
}
