/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodUnequalToNull;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodConsistentAcrossInvocations;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodReflexive;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodSymmetric;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodTransitive;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodUnequalToUnequalInstance;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;

@Fixture(value = "EqualsMethodContract", description = "Performs Unit Tests on org.jtiger.assertion.EqualsMethodContract")
@Category("org.jtiger.assertion.EqualsMethodContract")
public final class TestEqualsMethodContract
{
    public TestEqualsMethodContract()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(EqualsMethodContract.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertEqualsMethodUnequalToNull1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodUnequalToNull(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodUnequalToNull2()
    {
        final ObjectFactory<NotUnequalToNull> factory = new ObjectFactory<NotUnequalToNull>()
        {
            public NotUnequalToNull newInstanceX()
            {
                return new NotUnequalToNull();
            }

            public NotUnequalToNull newInstanceY()
            {
                return new NotUnequalToNull();
            }
        };

        assertEqualsMethodUnequalToNull(factory);
    }

    @Test
    public void testAssertEqualsMethodConsistentAcrossInvocations1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodConsistentAcrossInvocations(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodConsistentAcrossInvocations2()
    {
        final ObjectFactory<NotUnequalToNull> factory = new ObjectFactory<NotUnequalToNull>()
        {
            public NotUnequalToNull newInstanceX()
            {
                return new NotUnequalToNull();
            }

            public NotUnequalToNull newInstanceY()
            {
                return new NotUnequalToNull();
            }
        };

        assertEqualsMethodConsistentAcrossInvocations(factory);
    }

    @Test
    public void testAssertEqualsMethodReflexive1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodReflexive(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodReflexive2()
    {
        final ObjectFactory<NotReflexive> factory = new ObjectFactory<NotReflexive>()
        {
            public NotReflexive newInstanceX()
            {
                return new NotReflexive();
            }

            public NotReflexive newInstanceY()
            {
                return new NotReflexive();
            }
        };

        assertEqualsMethodReflexive(factory);
    }

    @Test
    public void testAssertEqualsMethodSymmetric1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodSymmetric(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodSymmetric2()
    {
        final ObjectFactory<NotSymmetric> factory = new ObjectFactory<NotSymmetric>()
        {
            public NotSymmetric newInstanceX()
            {
                return new NotSymmetric();
            }

            public NotSymmetric newInstanceY()
            {
                return new NotSymmetric();
            }
        };

        assertEqualsMethodSymmetric(factory);
    }

    @Test
    public void testAssertEqualsMethodTransitive1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodTransitive(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodTransitive2()
    {
        final ObjectFactory<NotTransitive> factory = new ObjectFactory<NotTransitive>()
        {
            public NotTransitive newInstanceX()
            {
                return new NotTransitive();
            }

            public NotTransitive newInstanceY()
            {
                return new NotTransitive();
            }
        };

        assertEqualsMethodTransitive(factory);
    }

    @Test
    public void testAssertEqualsMethodUnequalToUnequalInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodUnequalToUnequalInstance(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodUnequalToUnequalInstance2()
    {
        final ObjectFactory<NotUnequalToUnequalInstance> factory = new ObjectFactory<NotUnequalToUnequalInstance>()
        {
            public NotUnequalToUnequalInstance newInstanceX()
            {
                return new NotUnequalToUnequalInstance();
            }

            public NotUnequalToUnequalInstance newInstanceY()
            {
                return new NotUnequalToUnequalInstance();
            }
        };

        assertEqualsMethodUnequalToUnequalInstance(factory);
    }

    @Test
    public void testAssertEqualsMethodFillsContract1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertEqualsMethodFillsContract(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertEqualsMethodFillsContract2()
    {
        final ObjectFactory<NotUnequalToUnequalInstance> factory = new ObjectFactory<NotUnequalToUnequalInstance>()
        {
            public NotUnequalToUnequalInstance newInstanceX()
            {
                return new NotUnequalToUnequalInstance();
            }

            public NotUnequalToUnequalInstance newInstanceY()
            {
                return new NotUnequalToUnequalInstance();
            }
        };

        assertEqualsMethodFillsContract(factory);
    }

    private static final class NotUnequalToNull
    {
        @Override
        public boolean equals(final Object o)
        {
            return o == null;
        }
    }

    private static final class NotReflexive
    {
        @Override
        public boolean equals(final Object o)
        {
            return this != o;
        }
    }

    private static final class NotSymmetric
    {
        private static NotSymmetric o1;
        private static NotSymmetric o2;

        @Override
        public boolean equals(final Object o)
        {
            if(o1 == null || o2 == null)
            {
                o1 = this;
                o2 = (NotSymmetric)o;
                return true;
            }
            else
            {
                return !(this == o2 && o == o1);
            }
        }
    }

    private static final class NotTransitive
    {
        private static NotTransitive o1;
        private static NotTransitive o2;

        private NotTransitive()
        {

        }

        @Override
        public boolean equals(final Object o)
        {
            if(o == null)
            {
                return false;
            }
            else if(this == o)
            {
                return true;
            }
            else if(o1 == null || o2 == null && new Throwable().getStackTrace()[0].getMethodName().equals("isTransitive"))
            {
                o1 = this;
                o2 = (NotTransitive)o;
                return true;
            }
            else
            {
                return !(this == NotTransitive.o1 && o != NotTransitive.o2);
            }
        }
    }

    private static final class NotUnequalToUnequalInstance
    {
        private NotUnequalToUnequalInstance()
        {

        }

        @Override
        public boolean equals(final Object o)
        {
            return o != null;
        }
    }
}
