/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodConsistentResult;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodEqualOnEqualInstance;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;

@Fixture(value = "HashCodeMethodContract", description = "Performs Unit Tests on org.jtiger.assertion.HashCodeMethodContract")
@Category("org.jtiger.assertion.HashCodeMethodContract")
public final class TestHashCodeMethodContract
{
    public TestHashCodeMethodContract()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(HashCodeMethodContract.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertHashCodeMethodConsistentResult1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertHashCodeMethodConsistentResult(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHashCodeMethodConsistentResult2()
    {
        final ObjectFactory<NotConsistentResult> factory = new ObjectFactory<NotConsistentResult>()
        {
            public NotConsistentResult newInstanceX()
            {
                return new NotConsistentResult();
            }

            public NotConsistentResult newInstanceY()
            {
                return new NotConsistentResult();
            }
        };

        assertHashCodeMethodConsistentResult(factory);
    }

    @Test
    public void testAssertHashCodeMethodEqualOnEqualInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertHashCodeMethodEqualOnEqualInstance(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHashCodeMethodEqualOnEqualInstance2()
    {
        final ObjectFactory<NotEqualOnEqualInstance> factory = new ObjectFactory<NotEqualOnEqualInstance>()
        {
            private int i;

            public NotEqualOnEqualInstance newInstanceX()
            {
                return new NotEqualOnEqualInstance(i++);
            }

            public NotEqualOnEqualInstance newInstanceY()
            {
                return new NotEqualOnEqualInstance(-1);
            }
        };

        assertHashCodeMethodEqualOnEqualInstance(factory);
    }

    @Test
    public void testAssertHashCodeMethodFillsContract1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHashCodeMethodFillsContract2()
    {
        final ObjectFactory<NotEqualOnEqualInstance> factory = new ObjectFactory<NotEqualOnEqualInstance>()
        {
            private int i;

            public NotEqualOnEqualInstance newInstanceX()
            {
                return new NotEqualOnEqualInstance(i++);
            }

            public NotEqualOnEqualInstance newInstanceY()
            {
                return new NotEqualOnEqualInstance(-1);
            }
        };

        assertHashCodeMethodFillsContract(factory);
    }

    private static final class NotConsistentResult
    {
        private NotConsistentResult()
        {

        }

        @Override
        public int hashCode()
        {
            return (int)(Math.random() * Integer.MAX_VALUE);
        }
    }

    private static final class NotEqualOnEqualInstance
    {
        private final int hc;

        private NotEqualOnEqualInstance(final int hc)
        {
            this.hc = hc;
        }

        @Override
        public boolean equals(final Object o)
        {
            if(o == null)
            {
                return false;
            }

            if(this == o)
            {
                return true;
            }

            if(!(o.getClass() == NotEqualOnEqualInstance.class))
            {
                return false;
            }

            return true;
        }

        @Override
        public int hashCode()
        {
            return hc;
        }
    }
}
