/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryXConsistentlyNewInstance;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryYConsistentlyNewInstance;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryXConsistentlyEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryYConsistentlyEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryXYConsistentlyUnequal;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;

@Fixture(value = "ObjectFactoryContract", description = "Performs Unit Tests on org.jtiger.assertion.ObjectFactoryContract")
@Category("org.jtiger.assertion.ObjectFactoryContract")
public final class TestObjectFactoryContract
{
    public TestObjectFactoryContract()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ObjectFactoryContract.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertObjectFactoryXConsistentlyNewInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryXConsistentlyNewInstance(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryXConsistentlyNewInstance2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        assertObjectFactoryXConsistentlyNewInstance(factory);
    }

    @Test
    public void testAssertObjectFactoryYConsistentlyNewInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryYConsistentlyNewInstance(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryYConsistentlyNewInstance2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        assertObjectFactoryYConsistentlyNewInstance(factory);
    }

    @Test
    public void testAssertObjectFactoryXConsistentlyEqual1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryXConsistentlyEqual(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryXConsistentlyEqual2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            private int i;

            public String newInstanceX()
            {
                return "x" + i++;
            }

            public String newInstanceY()
            {
                return "y" + i++;
            }
        };

        assertObjectFactoryXConsistentlyEqual(factory);
    }

    @Test
    public void testAssertObjectFactoryYConsistentlyEqual1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryYConsistentlyEqual(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryYConsistentlyEqual2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            private int i;

            public String newInstanceX()
            {
                return "x" + i++;
            }

            public String newInstanceY()
            {
                return "y" + i++;
            }
        };

        assertObjectFactoryYConsistentlyEqual(factory);
    }

    @Test
    public void testAssertObjectFactoryXYConsistentlyUnequal1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryXYConsistentlyUnequal(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryXYConsistentlyUnequal2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("x");
            }
        };

        assertObjectFactoryXYConsistentlyUnequal(factory);
    }

    @Test
    public void testAssertObjectFactoryFillsContract1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        assertObjectFactoryFillsContract(factory);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertObjectFactoryFillsContract2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        assertObjectFactoryFillsContract(factory);
    }
}
