/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.ObjectFactoryContractTesterFactory.newObjectFactoryContractTester;

@Fixture(value = "ObjectFactoryContractTesterFactory", description = "Performs Unit Tests on org.jtiger.assertion.ObjectFactoryContractTesterFactory")
@Category("org.jtiger.assertion.ObjectFactoryContractTesterFactory")
public final class TestObjectFactoryContractTesterFactory
{
    public TestObjectFactoryContractTesterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ObjectFactoryContractTesterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newObjectFactoryContractTester(null);
    }

    @Test
    public void testIsXConsistentlyNewInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("x");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.isXConsistentlyNewInstance());
    }

    @Test
    public void testIsXConsistentlyNewInstance2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXConsistentlyNewInstance());
    }

    @Test
    public void testIsXConsistentlyNewInstance3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXConsistentlyNewInstance());
    }

    @Test
    public void testIsYConsistentlyNewInstance1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.isYConsistentlyNewInstance());
    }

    @Test
    public void testIsYConsistentlyNewInstance2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isYConsistentlyNewInstance());
    }

    @Test
    public void testIsYConsistentlyNewInstance3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isYConsistentlyNewInstance());
    }

    @Test
    public void testIsXConsistentlyEqual1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.isXConsistentlyEqual());
    }

    @Test
    public void testIsXConsistentlyEqual2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXConsistentlyEqual());
    }

    @Test
    public void testIsXConsistentlyEqual3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            private int i;

            public String newInstanceX()
            {
                return "x" + i++;
            }

            public String newInstanceY()
            {
                return "y" + i++;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXConsistentlyEqual());
    }

    @Test
    public void testIsYConsistentlyEqual1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.isYConsistentlyEqual());
    }

    @Test
    public void testIsYConsistentlyEqual2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isYConsistentlyEqual());
    }

    @Test
    public void testIsYConsistentlyEqual3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            private int i;

            public String newInstanceX()
            {
                return "x" + i++;
            }

            public String newInstanceY()
            {
                return "y" + i++;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isYConsistentlyEqual());
    }

    @Test
    public void testIsXYConsistentlyUnequal1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.isXYConsistentlyUnequal());
    }

    @Test
    public void testIsXYConsistentlyUnequal2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXYConsistentlyUnequal());
    }

    @Test
    public void testIsXYConsistentlyUnequal3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("x");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.isXYConsistentlyUnequal());
    }

    @Test
    public void testFillsContract1()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("y");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertTrue(tester.fillsContract());
    }

    @Test
    public void testFillsContract2()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.fillsContract());
    }

    @Test
    public void testFillsContract3()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return null;
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.fillsContract());
    }

    @Test
    public void testFillsContract4()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return null;
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.fillsContract());
    }

    @Test
    public void testFillsContract5()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return "x";
            }

            public String newInstanceY()
            {
                return "y";
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.fillsContract());
    }

    @Test
    public void testFillsContract6()
    {
        final ObjectFactory<String> factory = new ObjectFactory<String>()
        {
            public String newInstanceX()
            {
                return new String("x");
            }

            public String newInstanceY()
            {
                return new String("x");
            }
        };

        final ObjectFactoryContractTester tester = newObjectFactoryContractTester(factory);
        assertFalse(tester.fillsContract());
    }
}
