/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasConstructor;
import static org.jtiger.assertion.Reflection.assertNotHasConstructor;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertNotHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Reflection.assertNotHasMethod;
import static org.jtiger.assertion.Reflection.assertHasDeclaredMethod;
import static org.jtiger.assertion.Reflection.assertNotHasDeclaredMethod;
import static org.jtiger.assertion.Reflection.assertHasField;
import static org.jtiger.assertion.Reflection.assertNotHasField;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Reflection.assertNotHasDeclaredField;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;

@Fixture(value = "Reflection", description = "Performs Unit Tests on org.jtiger.assertion.Reflection")
@Category("org.jtiger.assertion.Reflection")
public final class TestReflection
{
    public TestReflection()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(Reflection.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertHasConstructor1()
    {
        final Class<?> c = X.class;
        assertHasConstructor(c, new Class<?>[]{int.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasConstructor2()
    {
        final Class<?> c = X.class;
        assertHasConstructor(c, new Class<?>[]{long.class});
    }

    @Test
    public void testAssertNotHasConstructor1()
    {
        final Class<?> c = X.class;
        assertNotHasConstructor(c, new Class<?>[]{long.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasConstructor2()
    {
        final Class<?> c = X.class;
        assertNotHasConstructor(c, new Class<?>[]{int.class});
    }

    @Test
    public void testAssertHasDeclaredConstructor1()
    {
        final Class<?> c = X.class;
        assertHasDeclaredConstructor(c, new Class<?>[]{int.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasDeclaredConstructor2()
    {
        final Class<?> c = X.class;
        assertHasDeclaredConstructor(c, new Class<?>[]{char.class});
    }

    @Test
    public void testAssertNotHasDeclaredConstructor1()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredConstructor(c, new Class<?>[]{char.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasDeclaredConstructor2()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredConstructor(c, new Class<?>[]{int.class});
    }

    @Test
    public void testAssertHasMethod1()
    {
        final Class<?> c = X.class;
        assertHasMethod(c, "m", new Class<?>[]{long.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasMethod2()
    {
        final Class<?> c = X.class;
        assertHasMethod(c, "m", new Class<?>[]{String.class});
    }

    @Test
    public void testAssertNotHasMethod1()
    {
        final Class<?> c = X.class;
        assertNotHasMethod(c, "m", new Class<?>[]{String.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasMethod2()
    {
        final Class<?> c = X.class;
        assertNotHasMethod(c, "m", new Class<?>[]{long.class});
    }

    @Test
    public void testAssertHasDeclaredMethod1()
    {
        final Class<?> c = X.class;
        assertHasDeclaredMethod(c, "m", new Class<?>[]{long.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasDeclaredMethod2()
    {
        final Class<?> c = X.class;
        assertHasDeclaredMethod(c, "m", new Class<?>[]{float.class});
    }

    @Test
    public void testAssertNotHasDeclaredMethod1()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredMethod(c, "m", new Class<?>[]{float.class});
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasDeclaredMethod2()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredMethod(c, "m", new Class<?>[]{long.class});
    }

    @Test
    public void testAssertHasField1()
    {
        final Class<?> c = X.class;
        assertHasField(c, "f");
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasField2()
    {
        final Class<?> c = X.class;
        assertHasField(c, "ff");
    }

    @Test
    public void testAssertNotHasField1()
    {
        final Class<?> c = X.class;
        assertNotHasField(c, "ff");
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasField2()
    {
        final Class<?> c = X.class;
        assertNotHasField(c, "f");
    }

    @Test
    public void testAssertHasDeclaredField1()
    {
        final Class<?> c = X.class;
        assertHasDeclaredField(c, "f");
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertHasDeclaredField2()
    {
        final Class<?> c = X.class;
        assertHasDeclaredField(c, "ff");
    }

    @Test
    public void testAssertNotHasDeclaredField1()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredField(c, "ff");
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotHasDeclaredField2()
    {
        final Class<?> c = X.class;
        assertNotHasDeclaredField(c, "f");
    }

    private static final class X
    {
        public int f;

        public X(final int i)
        {
            new Integer(i);
        }

        public void m(final long l)
        {

        }
    }

}
