/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.io.Serializable;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertNotSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesSame;
import static org.jtiger.assertion.Serialization.assertSerializesUnsame;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.Serialization.assertSerializesUnequal;

@Fixture(value = "Serialization", description = "Performs Unit Tests on org.jtiger.assertion.Serialization")
@Category("org.jtiger.assertion.Serialization")
public final class TestSerialization
{
    public TestSerialization()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(Serialization.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAssertSerializes1()
    {
        assertSerializes(new Serializes());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSerializes2()
    {
        assertSerializes(new NotSerializes());
    }

    @Test
    public void testAssertNotSerializes1()
    {
        assertNotSerializes(new NotSerializes());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertNotSerializes2()
    {
        assertNotSerializes(new Serializes());
    }

    @Test
    public void testAssertSerializesSame1()
    {
        assertSerializesSame(SerializesSame.INSTANCE);
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSerializesSame2()
    {
        assertSerializesSame(new SerializesUnsame());
    }

    @Test
    public void testAssertSerializesUnsame1()
    {
        assertSerializesUnsame(new SerializesUnsame());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSerializesUnsame2()
    {
        assertSerializesUnsame(SerializesSame.INSTANCE);
    }

    @Test
    public void testAssertSerializesEqual1()
    {
        assertSerializesEqual(new SerializesEqual());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSerializesEqual2()
    {
        assertSerializesEqual(new SerializesUnequal());
    }

    @Test
    public void testAssertSerializesUnequal1()
    {
        assertSerializesUnequal(new SerializesUnequal());
    }

    @Test
    @ExpectException(value = AssertionException.class)
    public void testAssertSerializesUnequal2()
    {
        assertSerializesUnequal(new SerializesEqual());
    }

    private static final class Serializes implements Serializable
    {

    }

    private static final class NotSerializes implements Serializable
    {
        private final Object o = new Object();

        // provide compile-time safety.
        Object m()
        {
            return o;
        }
    }

    private static final class SerializesSame implements Serializable
    {
        private static final SerializesSame INSTANCE = new SerializesSame();

        Object readResolve()
        {
            return SerializesSame.INSTANCE;
        }
    }

    private static final class SerializesUnsame implements Serializable
    {

    }

    private static final class SerializesEqual implements Serializable
    {
        @Override
        public boolean equals(final Object o)
        {
            return true;
        }
    }

    private static final class SerializesUnequal implements Serializable
    {
        @Override
        public boolean equals(final Object o)
        {
            return false;
        }
    }
}
