/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.assertion;

import java.io.Serializable;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.SerializationTesterFactory.newSerializationTester;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;

@Fixture(value = "SerializationTesterFactory", description = "Performs Unit Tests on org.jtiger.assertion.SerializationTesterFactory")
@Category("org.jtiger.assertion.SerializationTesterFactory")
public final class TestSerializationTesterFactory
{
    public TestSerializationTesterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(SerializationTesterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newSerializationTester(null);
    }

    @Test
    public void testSerializes1()
    {
        final SerializationTester tester = newSerializationTester(new Serializes());
        assertTrue(tester.serializes());
    }

    @Test
    public void testSerializes2()
    {
        final SerializationTester tester = newSerializationTester(new NotSerializes());
        assertFalse(tester.serializes());
    }

    @Test
    public void testSerializesSame1()
    {
        final SerializationTester tester = newSerializationTester(SerializesSame.INSTANCE);
        assertTrue(tester.serializesSame());
    }

    @Test
    public void testSerializesSame2()
    {
        final SerializationTester tester = newSerializationTester(new NotSerializesSame());
        assertFalse(tester.serializesSame());
    }

    @Test
    public void testSerializesSame3()
    {
        final SerializationTester tester = newSerializationTester(new NotSerializes());
        assertFalse(tester.serializesSame());
    }

    @Test
    public void testSerializesEqual1()
    {
        final SerializationTester tester = newSerializationTester(new SerializesEqual());
        assertTrue(tester.serializesEqual());
    }

    @Test
    public void testSerializesEqual2()
    {
        final SerializationTester tester = newSerializationTester(new SerializesUnequal());
        assertFalse(tester.serializesEqual());
    }

    @Test
    public void testSerializesEqual3()
    {
        final SerializationTester tester = newSerializationTester(new NotSerializes());
        assertFalse(tester.serializesEqual());
    }

    private static final class Serializes implements Serializable
    {

    }

    private static final class NotSerializes implements Serializable
    {
        private final Object o = new Object();

        // provide compile-time safety.
        Object m()
        {
            return o;
        }
    }

    private static final class SerializesSame implements Serializable
    {
        private static final SerializesSame INSTANCE = new SerializesSame();

        Object readResolve()
        {
            return SerializesSame.INSTANCE;
        }
    }

    private static final class NotSerializesSame implements Serializable
    {

    }

    private static final class SerializesEqual implements Serializable
    {
        @Override
        public boolean equals(final Object o)
        {
            return true;
        }
    }

    private static final class SerializesUnequal implements Serializable
    {
        @Override
        public boolean equals(final Object o)
        {
            return false;
        }
    }
}
