/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.ClassAliasMappingFactory.newClassAliasMapping;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertFalse;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Constructor;

@Fixture(value = "ClassAliasMappingFactory", description = "Performs Unit Tests on org.jtiger.framework.ClassAliasMappingFactory")
@Category("org.jtiger.framework.ClassAliasMappingFactory")
public final class TestClassAliasMappingFactory
{
    public TestClassAliasMappingFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ClassAliasMappingFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getMappedClassNameNullArg()
    {
        newClassAliasMapping().getMappedClassName(null);
    }

    @Test
    public void getAliases()
    {
        final ClassAliasMapping mapping = newClassAliasMapping();
        final ReadOnlyArray<String> aliases = mapping.getAliases();

        for(String alias : aliases)
        {
            final String className = mapping.getMappedClassName(alias);
            assertNotNull(className);
        }
    }
}
