/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.framework.ClassConstructionFactory.newClassConstruction;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.Basic.assertEqual;

@Fixture(value = "ClassConstructionFactory", description = "Performs Unit Tests on org.jtiger.framework.ClassConstructionFactory")
@Category("org.jtiger.framework.ClassConstructionFactory")
public final class TestClassConstructionFactory
{
    public TestClassConstructionFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ClassConstructionFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void construct1() throws IllegalAccessException, InvocationTargetException, InstantiationException
    {
        assertNull(newClassConstruction().construct(null));
        assertSame(A.class, newClassConstruction().construct(A.class).getClass());
        assertSame(B.class, newClassConstruction().construct(B.class).getClass());
        assertEqual(B.class.getCanonicalName(), newClassConstruction().construct(B.class).getName());
        assertSame(C.class, newClassConstruction().construct(C.class).getClass());
        assertSame(D.class, newClassConstruction().construct(D.class).getClass());
        assertEqual(D.class.getCanonicalName(), newClassConstruction().construct(D.class).getName());
    }

    @Test
    public void construct2() throws IllegalAccessException, InvocationTargetException, InstantiationException
    {
        assertNull(newClassConstruction().construct(null));
        assertNull(newClassConstruction().construct(Z.class));
    }

    private static final class A
    {
        public A()
        {

        }
    }

    private static final class B
    {
        private final String s;

        public B(final String s)
        {
            this.s = s;
        }

        public String getName()
        {
            return s;
        }
    }

    private static final class C
    {
        public C()
        {

        }
    }

    private static final class D
    {
        private final String s;

        public D(final String s)
        {
            this.s = s;
        }

        public String getName()
        {
            return s;
        }
    }

    private static final class Z
    {
        public Z(final int i)
        {
            new Integer(i);
        }
    }

}
