/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.SequenceFactory.newSequence;
import static org.jtiger.framework.SequenceFactory.newConstantSequence;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertNotSame;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import java.util.Iterator;
import java.util.NoSuchElementException;
import org.jtiger.assertion.ObjectFactory;

@Fixture(value = "TestSequenceFactory", description = "Performs Unit Tests on SequenceFactory")
@Category({"org.jtiger.framework.SequenceFactory", "ConstantSequence"})
public final class TestConstantSequence
{
    public TestConstantSequence()
    {

    }

    @Test
    @Category("get")
    void get1()
    {
        final org.jtiger.framework.Sequence<String> s1 = newConstantSequence("x", 3);
        assertEqual("x", s1.get(0));
        assertEqual("x", s1.get(1));
        assertEqual("x", s1.get(2));

        final Sequence<String> s2 = newConstantSequence("x", 3).append(newConstantSequence("y", 3));
        assertEqual("x", s2.get(0));
        assertEqual("x", s2.get(1));
        assertEqual("x", s2.get(2));
        assertEqual("y", s2.get(3));
        assertEqual("y", s2.get(4));
        assertEqual("y", s2.get(5));

        final Sequence<String> s3 = newConstantSequence("x", 6).getSubSequence(1, 5);
        assertEqual("x", s3.get(0));
        assertEqual("x", s3.get(1));
        assertEqual("x", s3.get(2));
        assertEqual("x", s3.get(3));

        final Sequence<String> s4 = newConstantSequence("x", 6).getSubSequence(0, 5);
        assertEqual("x", s4.get(0));
        assertEqual("x", s4.get(1));
        assertEqual("x", s4.get(2));
        assertEqual("x", s4.get(3));
        assertEqual("x", s4.get(4));

        final Sequence<String> s5 = newConstantSequence("x", 6).getSubSequence(2, 6);
        assertEqual("x", s5.get(0));
        assertEqual("x", s5.get(1));
        assertEqual("x", s5.get(2));
        assertEqual("x", s5.get(3));
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    @Category("get")
    void get2()
    {
        newConstantSequence(new Object(), 3).get(-1);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    @Category("get")
    void get3()
    {
        newConstantSequence(new Object(), 3).get(3);
    }

    @Test
    @Category("length")
    void length()
    {
        assertEqual(1, newConstantSequence(new Object(), 1).length());
        assertEqual(3, newConstantSequence(new Object(), 3).length());
        assertEqual(6, newConstantSequence(new Object(), 6).length());
        assertEqual(6, newConstantSequence(new Object(), 3).append(newConstantSequence(new Object(), 3)).length());
        assertEqual(4, newConstantSequence(new Object(), 6).getSubSequence(1, 5).length());
        assertEqual(5, newConstantSequence(new Object(), 6).getSubSequence(0, 5).length());
        assertEqual(4, newConstantSequence(new Object(), 6).getSubSequence(2, 6).length());
    }

    @Test
    @Category("append")
    void append()
    {
        final Sequence<String> s1 = newConstantSequence("x", 3)
                .append(newConstantSequence("y", 3));
        assertEqual(6, s1.length());
        assertEqual("x", s1.get(0));
        assertEqual("x", s1.get(1));
        assertEqual("x", s1.get(2));
        assertEqual("y", s1.get(3));
        assertEqual("y", s1.get(4));
        assertEqual("y", s1.get(5));

        final Sequence<String> s2 = newConstantSequence("x", 3)
                .append(newConstantSequence("y", 3))
                .append(newConstantSequence("z", 3));
        assertEqual(9, s2.length());
        assertEqual("x", s2.get(0));
        assertEqual("x", s2.get(1));
        assertEqual("x", s2.get(2));
        assertEqual("y", s2.get(3));
        assertEqual("y", s2.get(4));
        assertEqual("y", s2.get(5));
        assertEqual("z", s2.get(6));
        assertEqual("z", s2.get(7));
        assertEqual("z", s2.get(8));

        final Sequence<String> s3 = newConstantSequence("x", 3)
                .append(newConstantSequence("y", 3))
                .getSubSequence(1, 5)
                .append(newConstantSequence("z", 6))
                .getSubSequence(3, 8);
        assertEqual(5, s3.length());
        assertEqual("y", s3.get(0));
        assertEqual("z", s3.get(1));
        assertEqual("z", s3.get(2));
        assertEqual("z", s3.get(3));
        assertEqual("z", s3.get(4));

        final Sequence<String> s4 = newConstantSequence("x", 3)
                .append(newSequence(new String[0]));
        assertEqual(3, s4.length());
        assertEqual("x", s4.get(0));
        assertEqual("x", s4.get(1));
        assertEqual("x", s4.get(2));

    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("append")
    void append2()
    {
        newConstantSequence(new Object(), 3).append(null);
    }

    @Test
    @Category("getSubSequence")
    void getSubSequence1()
    {
        final Sequence<String> s1 = newConstantSequence("x", 6).getSubSequence(1, 4);
        assertEqual(3, s1.length());
        assertEqual("x", s1.get(0));
        assertEqual("x", s1.get(1));
        assertEqual("x", s1.get(2));

        final Sequence<String> s2 = newConstantSequence("x", 6).getSubSequence(0, 0);
        assertEqual(0, s2.length());

        final Sequence<String> s3 = newConstantSequence("x", 6).getSubSequence(0, 1);
        assertEqual(1, s3.length());
        assertEqual("x", s3.get(0));

        final Sequence<String> s4 = newConstantSequence("x", 6).getSubSequence(6, 6);
        assertEqual(0, s4.length());

        final Sequence<String> s5 = newConstantSequence("x", 6).getSubSequence(4, 6);
        assertEqual(2, s5.length());
        assertEqual("x", s5.get(0));
        assertEqual("x", s5.get(1));

        final Sequence<String> s6 = newConstantSequence("x", 6).getSubSequence(2, 6)
                .append(newConstantSequence("y", 3)).getSubSequence(2, 6);
        assertEqual(4, s6.length());
        assertEqual("x", s6.get(0));
        assertEqual("x", s6.get(1));
        assertEqual("y", s6.get(2));
        assertEqual("y", s6.get(3));
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence2()
    {
        newConstantSequence(new Object(), 3).getSubSequence(-1, 3);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence3()
    {
        newConstantSequence(new Object(), 3).getSubSequence(0, 4);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence4()
    {
        newConstantSequence(new Object(), 3).getSubSequence(2, 1);
    }

    @Test
    @Category("insert")
    void insert1()
    {
        final Sequence<String> s1 = newConstantSequence("x", 2).insert(1, newSequence("y"));
        assertEqual(3, s1.length());
        assertEqual("x", s1.get(0));
        assertEqual("y", s1.get(1));
        assertEqual("x", s1.get(2));
    }

    @Test
    @Category("insert")
    void insert2()
    {
        final Sequence<String> s1 = newConstantSequence("x", 2).insert(0, newSequence("y"));
        assertEqual(3, s1.length());
        assertEqual("y", s1.get(0));
        assertEqual("x", s1.get(1));
        assertEqual("x", s1.get(2));
    }

    @Test
    @Category("insert")
    void insert3()
    {
        final Sequence<String> s1 = newConstantSequence("x", 2).insert(2, newSequence("y"));
        assertEqual(3, s1.length());
        assertEqual("x", s1.get(0));
        assertEqual("x", s1.get(1));
        assertEqual("y", s1.get(2));
    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("insert")
    void insert4()
    {
        final Sequence<Integer> s = null;
        newConstantSequence(5, 3).insert(0, s);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("insert")
    void insert5()
    {
        newConstantSequence(5, 3).insert(-1, newSequence(10));
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("insert")
    void insert6()
    {
        newConstantSequence(5, 3).insert(4, newSequence(10));
    }

    @Test
    @Category("delete")
    void delete1()
    {
        final Sequence<String> s1 = newConstantSequence("x", 3).delete(0, 1);
        assertEqual(2, s1.length());
        assertEqual("x", s1.get(0));
        assertEqual("x", s1.get(1));

        final Sequence<String> s2 = newConstantSequence("x", 3).delete(2, 3);
        assertEqual(2, s2.length());
        assertEqual("x", s2.get(0));
        assertEqual("x", s2.get(1));

        final Sequence<String> s3 = newConstantSequence("x", 3).delete(1, 2);
        assertEqual(2, s3.length());
        assertEqual("x", s3.get(0));
        assertEqual("x", s3.get(1));

        final Sequence<String> s4 = newConstantSequence("x", 3).delete(1, 1);
        assertEqual(3, s4.length());
        assertEqual("x", s4.get(0));
        assertEqual("x", s4.get(1));
        assertEqual("x", s4.get(2));
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete2()
    {
        newConstantSequence(5, 3).delete(-1, 3);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete3()
    {
        newConstantSequence(5, 3).delete(0, 4);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete4()
    {
        newConstantSequence(5, 3).delete(2, 1);
    }

    @Test
    @Category("indexOf")
    void indexOf1()
    {
        final Sequence<String> s1 = newConstantSequence("x", 9);
        assertEqual(0, s1.indexOf("x"));
        assertTrue(s1.indexOf("xyz") < 0);
    }

    @Test
    @Category("indexOf")
    void indexOf2()
    {
        final Sequence<String> s1 = newConstantSequence("x", 5);
        assertEqual(0, s1.indexOf(0, "x"));
        assertEqual(1, s1.indexOf(1, "x"));
        assertEqual(2, s1.indexOf(2, "x"));
        assertEqual(3, s1.indexOf(3, "x"));
        assertEqual(4, s1.indexOf(4, "x"));
        assertEqual(-1, s1.indexOf(5, "x"));
        assertTrue(s1.indexOf("xyz") < 0);
        assertTrue(s1.indexOf("xyz") < 0);
        assertTrue(s1.indexOf(2, "xyz") < 0);
        assertTrue(s1.indexOf(3, "xyz") < 0);
        assertTrue(s1.indexOf(4, "xyz") < 0);
        assertTrue(s1.indexOf(5, "xyz") < 0);
        assertTrue(s1.indexOf(0, null) < 0);
        assertTrue(s1.indexOf(1, null) < 0);
        assertTrue(s1.indexOf(2, null) < 0);
        assertTrue(s1.indexOf(3, null) < 0);
        assertTrue(s1.indexOf(4, null) < 0);
        assertTrue(s1.indexOf(5, null) < 0);

        final Sequence<String> s2 = newConstantSequence(null, 5);
        assertEqual(0, s2.indexOf(0, null));
        assertEqual(1, s2.indexOf(1, null));
        assertEqual(2, s2.indexOf(2, null));
        assertEqual(3, s2.indexOf(3, null));
        assertEqual(4, s2.indexOf(4, null));
        assertTrue(s2.indexOf(0, "xyz") < 0);
        assertTrue(s2.indexOf(1, "xyz") < 0);
        assertTrue(s2.indexOf(2, "xyz") < 0);
        assertTrue(s2.indexOf(3, "xyz") < 0);
        assertTrue(s2.indexOf(4, "xyz") < 0);
    }

    @Test
    @Category("indexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void indexOf3()
    {
        newConstantSequence("x", 5).indexOf(-1, "x");
    }

    @Test
    @Category("indexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void indexOf4()
    {
        newConstantSequence("x", 5).indexOf(6, "x");
    }

    @Test
    @Category("lastIndexOf")
    void lastIndexOf1()
    {
        final Sequence<String> s1 = newConstantSequence("x", 9);
        assertEqual(8, s1.lastIndexOf("x"));
        assertTrue(s1.lastIndexOf("xyz") < 0);
    }

    @Test
    @Category("lastIndexOf")
    void lastIndexOf2()
    {
        final Sequence<String> s1 = newConstantSequence("x", 5);
        assertEqual(4, s1.lastIndexOf(5, "x"));
        assertEqual(3, s1.lastIndexOf(4, "x"));
        assertEqual(2, s1.lastIndexOf(3, "x"));
        assertEqual(1, s1.lastIndexOf(2, "x"));
        assertEqual(0, s1.lastIndexOf(1, "x"));
        assertEqual(-1, s1.lastIndexOf(0, "x"));
        assertTrue(s1.lastIndexOf(5, "xyz") < 0);
        assertTrue(s1.lastIndexOf(4, "xyz") < 0);
        assertTrue(s1.lastIndexOf(3, "xyz") < 0);
        assertTrue(s1.lastIndexOf(2, "xyz") < 0);
        assertTrue(s1.lastIndexOf(1, "xyz") < 0);
        assertTrue(s1.lastIndexOf(0, "xyz") < 0);
        assertTrue(s1.lastIndexOf(0, null) < 0);
        assertTrue(s1.lastIndexOf(1, null) < 0);
        assertTrue(s1.lastIndexOf(2, null) < 0);
        assertTrue(s1.lastIndexOf(3, null) < 0);
        assertTrue(s1.lastIndexOf(4, null) < 0);
        assertTrue(s1.lastIndexOf(5, null) < 0);

        final Sequence<String> s2 = newConstantSequence(null, 5);
        assertEqual(4, s2.lastIndexOf(5, null));
        assertEqual(3, s2.lastIndexOf(4, null));
        assertEqual(2, s2.lastIndexOf(3, null));
        assertEqual(1, s2.lastIndexOf(2, null));
        assertEqual(0, s2.lastIndexOf(1, null));
        assertEqual(-1, s2.lastIndexOf(0, null));
        assertTrue(s2.lastIndexOf(5, "xyz") < 0);
        assertTrue(s2.lastIndexOf(4, "xyz") < 0);
        assertTrue(s2.lastIndexOf(3, "xyz") < 0);
        assertTrue(s2.lastIndexOf(2, "xyz") < 0);
        assertTrue(s2.lastIndexOf(1, "xyz") < 0);
        assertTrue(s2.lastIndexOf(0, "xyz") < 0);
    }

    @Test
    @Category("lastIndexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void lastIndexOf3()
    {
        newConstantSequence("x", 5).lastIndexOf(-1, "x");
    }

    @Test
    @Category("lastIndexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void lastIndexOf4()
    {
        newConstantSequence("x", 5).lastIndexOf(6, "x");
    }

    @Test
    @Category("isEmpty")
    void isEmpty()
    {
        assertFalse(newConstantSequence(new Object(), 3).isEmpty());
    }

    @Test
    @Category("iterator")
    void iterator1()
    {
        final Iterator<String> i1 = newConstantSequence("x", 9).iterator();
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertTrue(i1.hasNext());
        assertEqual("x", i1.next());
        assertFalse(i1.hasNext());
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("iterator")
    void iterator2()
    {
        final Iterator<String> i = newConstantSequence("x", 3).iterator();
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        i.next();
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    @Category("iterator")
    void iterator3()
    {
        newConstantSequence("x", 3).iterator().remove();
    }

    @Test
    @Category("getIterator")
    void getIterator1()
    {
        final SequenceIterator<String> i = newConstantSequence("x", 3).getIterator();
        assertTrue(i.hasNext());
        assertEqual(0, i.getPosition());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual(1, i.getPosition());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual(2, i.getPosition());
        assertEqual("x", i.next());
        assertFalse(i.hasNext());
        assertEqual(3, i.getPosition());

        assertTrue(i.hasPrevious());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(2, i.getPosition());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(1, i.getPosition());
        assertEqual("x", i.previous());
        assertFalse(i.hasPrevious());
        assertEqual(0, i.getPosition());

        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual(1, i.getPosition());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual(2, i.getPosition());
        assertEqual("x", i.next());
        assertFalse(i.hasNext());
        assertEqual(3, i.getPosition());
    }

    @Test
    @Category("getIterator")
    void getIterator2()
    {
        final SequenceIterator<String> i = newConstantSequence("x", 3).getIterator(3);
        assertTrue(i.hasPrevious());
        assertEqual(3, i.getPosition());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(2, i.getPosition());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(1, i.getPosition());
        assertEqual("x", i.previous());
        assertFalse(i.hasPrevious());
        assertEqual(0, i.getPosition());
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator3()
    {
        final SequenceIterator<String> i = newConstantSequence("x", 3).getIterator();
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        assertTrue(i.hasNext());
        assertEqual("x", i.next());
        i.next();
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator4()
    {
        final SequenceIterator<String> i = newConstantSequence("x", 3).getIterator(3);
        assertTrue(i.hasPrevious());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual("x", i.previous());
        assertTrue(i.hasPrevious());
        assertEqual("x", i.previous());
        i.previous();
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    @Category("getIterator")
    void getIterator5()
    {
        newConstantSequence("x", 3).getIterator().remove();
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getIterator")
    void getIterator6()
    {
        newConstantSequence("x", 3).getIterator(-1);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getIterator")
    void getIterator7()
    {
        newConstantSequence("x", 3).getIterator(4);
    }

    @Test
    @Category("toString")
    void _toString()
    {
        assertEqual("[x][x][x]", newConstantSequence("x", 3).toString());
        assertEqual("[x][x][x][y][y][y][y]", newConstantSequence("x", 3)
                .append(newConstantSequence("y", 4)).toString());
    }

    @Test
    @Category({"equals", "hashCode"})
    void equalsHashCode()
    {
        final ObjectFactory<Sequence<String>> factory1 = new ObjectFactory<Sequence<String>>()
        {
            public Sequence<String> newInstanceX()
            {
                return newConstantSequence("x", 6);
            }

            public Sequence<String> newInstanceY()
            {
                return newConstantSequence("x", 9);
            }
        };

        final ObjectFactory<Sequence<String>> factory2 = new ObjectFactory<Sequence<String>>()
        {
            public Sequence<String> newInstanceX()
            {
                return newConstantSequence("x", 4);
            }

            public Sequence<String> newInstanceY()
            {
                return newConstantSequence("y", 6);
            }
        };

        final ObjectFactory<Sequence<String>> factory3 = new ObjectFactory<Sequence<String>>()
        {
            public Sequence<String> newInstanceX()
            {
                return newConstantSequence("x", 4);
            }

            public Sequence<String> newInstanceY()
            {
                return newConstantSequence(null, 4);
            }
        };

        assertObjectFactoryFillsContract(factory1);
        assertEqualsMethodFillsContract(factory1);
        assertHashCodeMethodFillsContract(factory1);

        assertObjectFactoryFillsContract(factory2);
        assertEqualsMethodFillsContract(factory2);
        assertHashCodeMethodFillsContract(factory2);

        assertObjectFactoryFillsContract(factory3);
        assertEqualsMethodFillsContract(factory3);
        assertHashCodeMethodFillsContract(factory3);
    }

    @Test
    @Category("clone")
    public void _clone()
    {
        final Sequence<Integer> a1 = newConstantSequence(7, 4);
        final Sequence<Integer> b1 = a1.clone();
        assertNotSame(a1, b1);
        assertEqual(a1, b1);
    }
}
