/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.DummyFixture1;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.framework.DefaultFixtureResultsHandlerFactory.newDefaultFixtureResultsHandler;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;
import static org.jtiger.assertion.Basic.assertNotNull;
import static org.jtiger.assertion.Basic.assertTrue;

@Fixture(value = "DefaultFixtureResultsHandlerFactory", description = "Performs Unit Tests on org.jtiger.framework.DefaultFixtureResultsHandlerFactory")
@Category("org.jtiger.framework.DefaultFixtureResultsHandlerFactory")
public final class TestDefaultFixtureResultsHandlerFactory
{
    public TestDefaultFixtureResultsHandlerFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(DefaultFixtureResultsHandlerFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void handleResult()
            throws RunnerException, FixtureResultsHandlerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(newSequence(new Class<?>[]{DummyFixture1.class}), null, null, false);
        final FixtureResults results = runner.run(config);
        final FixtureResultsHandler handler = newDefaultFixtureResultsHandler();
        final PrintStream stdout = System.out;
        final ByteArrayOutputStream out = new ByteArrayOutputStream();
        System.setOut(new PrintStream(out));

        handler.handleResult(results, null);

        System.setOut(stdout);
        assertNotNull(new String(out.toByteArray()));
        assertTrue(new String(out.toByteArray()).length() > 0);
    }
}
