/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.framework.DefaultSetUpTearDownFactory.newDefaultSetUpTearDown;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;

@Fixture(value = "DefaultSetUpTearDownFactory", description = "Performs Unit Tests on org.jtiger.framework.DefaultSetUpTearDownFactory")
@Category("org.jtiger.framework.DefaultSetUpTearDownFactory")
public final class TestDefaultSetUpTearDownFactory
{
    public TestDefaultSetUpTearDownFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(DefaultSetUpTearDownFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void setUp1() throws SetUpException
    {
        final SetUpTearDown sutd = newDefaultSetUpTearDown();
        final A a = new A();

        sutd.setUp(a);
        assertTrue(a.m1);
        assertFalse(a.m2);
        assertTrue(a.m3);
        assertFalse(a.m4);
    }

    @Test
    @ExpectException(SetUpException.class)
    public void setUp2() throws SetUpException
    {
        final SetUpTearDown sutd = newDefaultSetUpTearDown();
        final Z z = new Z();

        sutd.setUp(z);
    }

    @Test
    public void tearDown1() throws TearDownException
    {
        final SetUpTearDown sutd = newDefaultSetUpTearDown();
        final B b = new B();

        sutd.tearDown(b);
        assertTrue(b.m1);
        assertFalse(b.m2);
        assertTrue(b.m3);
        assertFalse(b.m4);
    }

    @Test
    @ExpectException(TearDownException.class)
    public void tearDown2() throws TearDownException
    {
        final SetUpTearDown sutd = newDefaultSetUpTearDown();
        final Y y = new Y();

        sutd.tearDown(y);
    }

    private static final class A
    {
        private boolean m1;
        private boolean m2;
        private boolean m3;
        private boolean m4;

        A()
        {
            m1();
            m2(7);
            m1 = false;
            m2 = false;
            m3 = false;
            m4 = false;
        }

        @SetUp
        private void m1()
        {
            m1 = true;
        }

        @SetUp
        private void m2(final int i)
        {
            m2 = true;
            new Integer(i);
        }

        @SetUp
        public void m3()
        {
            m3 = true;
        }

        public void m4()
        {
            m4 = true;
        }
    }

    private static final class B
    {
        private boolean m1;
        private boolean m2;
        private boolean m3;
        private boolean m4;

        B()
        {
            m1();
            m2(7);
            m1 = false;
            m2 = false;
            m3 = false;
            m4 = false;
        }

        @TearDown
        private void m1()
        {
            m1 = true;
        }

        @TearDown
        private void m2(final int i)
        {
            m2 = true;
            new Integer(i);
        }

        @TearDown
        public void m3()
        {
            m3 = true;
        }

        public void m4()
        {
            m4 = true;
        }
    }

    private static final class Y
    {
        @TearDown
        public void m()
        {
            throw new NullPointerException();
        }
    }

    private static final class Z
    {
        @SetUp
        public void m()
        {
            throw new NullPointerException();
        }
    }

}
