/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.framework.DefaultTestDefinitionFactory.newDefaultTestDefinition;

@Fixture(value = "DefaultTestDefinitionFactory", description = "Performs Unit Tests on org.jtiger.framework.DefaultTestDefinitionFactory")
@Category("org.jtiger.framework.DefaultTestDefinitionFactory")
public final class TestDefaultTestDefinitionFactory
{
    public TestDefaultTestDefinitionFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(DefaultTestDefinitionFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void isTest()
    {
        final Method m1 = assertHasMethod(X.class, "m1", new Class<?>[]{});
        assertFalse(newDefaultTestDefinition().isTest(null));
        assertTrue(newDefaultTestDefinition().isTest(m1));
        final Method m2 = assertHasMethod(X.class, "m2", new Class<?>[]{});
        assertFalse(newDefaultTestDefinition().isTest(m2));
    }

    private static final class X
    {
        @Test
        public void m1()
        {

        }

        public void m2()
        {

        }
    }
}
