/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.framework.FixtureDescriptionFactory.newFixtureDescription;
import static org.jtiger.assertion.Basic.assertEqual;

@Fixture(value = "FixtureDescriptionFactory", description = "Performs Unit Tests on org.jtiger.framework.FixtureDescriptionFactory")
@Category("org.jtiger.framework.FixtureDescriptionFactory")
public final class TestFixtureDescriptionFactory
{
    public TestFixtureDescriptionFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureDescriptionFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getFixtureDescriptionNullArg()
    {
        newFixtureDescription().getFixtureDescription(null);
    }

    @Test
    public void getFixtureDescription()
    {
        assertNull(newFixtureDescription().getFixtureDescription(A.class));
        assertEqual("", newFixtureDescription().getFixtureDescription(B.class));
        assertEqual("", newFixtureDescription().getFixtureDescription(C.class));
        assertEqual("fixture description", newFixtureDescription().getFixtureDescription(D.class));
    }

    private static final class A
    {

    }

    @Fixture("fixture name")
    private static final class B
    {

    }

    @Fixture(value = "fixture name", description = "")
    private static final class C
    {

    }

    @Fixture(value = "", description = "fixture description")
    private static final class D
    {

    }
}
