/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.framework.FixtureNameFactory.newFixtureName;

@Fixture(value = "FixtureNameFactory", description = "Performs Unit Tests on org.jtiger.framework.FixtureNameFactory")
@Category("org.jtiger.framework.FixtureNameFactory")
public final class TestFixtureNameFactory
{
    public TestFixtureNameFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureNameFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getFixtureNameNullArg()
    {
        newFixtureName().getFixtureName(null);
    }

    @Test
    public void getFixtureName()
    {
        assertEqual(A.class.getCanonicalName(), newFixtureName().getFixtureName(A.class));
        assertEqual("fixture name", newFixtureName().getFixtureName(B.class));
        assertEqual("fixture name", newFixtureName().getFixtureName(C.class));
        assertEqual(D.class.getCanonicalName(), newFixtureName().getFixtureName(D.class));
        assertEqual(E.class.getCanonicalName(), newFixtureName().getFixtureName(E.class));       
    }

    private static final class A
    {

    }

    @Fixture("fixture name")
    private static final class B
    {

    }

    @Fixture(value = "fixture name", description = "fixture description")
    private static final class C
    {

    }

    @Fixture(value = "", description = "fixture description")
    private static final class D
    {

    }

    @Fixture(value = "")
    private static final class E
    {

    }
}
