/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import org.jtiger.assertion.ObjectFactory;
import static org.jtiger.framework.FixtureResultFactory.newFixtureResult;
import static org.jtiger.framework.TestResultFactory.newTestResult;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;

@Fixture(value = "FixtureResultFactory", description = "Performs Unit Tests on org.jtiger.framework.FixtureResultFactory")
@Category("org.jtiger.framework.FixtureResultFactory")
public final class TestFixtureResultFactory
{
    private List<TestResult> list;

    public TestFixtureResultFactory()
    {

    }

    @SetUp
    public void createTestList()
    {
        list = new LinkedList<TestResult>();
        list.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        list.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        list.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));
        list.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})));
    }

    @TearDown
    public void emptyTestList()
    {
        list = null;
    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureResultFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newFixtureResult(null);
    }


    @Test
    public void get1()
    {
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})), newFixtureResult(list).get(0));
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})), newFixtureResult(list).get(1));
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})), newFixtureResult(list).get(2));
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})), newFixtureResult(list).get(3));
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void get2()
    {
        newFixtureResult(list).get(4);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void get3()
    {
        newFixtureResult(list).get(-7);
    }

    @Test
    public void listIterator1()
    {
        final ListIterator<TestResult> i = newFixtureResult(list).listIterator();

        int counter = 0;

        while(i.hasNext())
        {
            final TestResult r;

            if(counter == 0)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
            }
            else if(counter == 1)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
            }
            else if(counter == 2)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
            }
            else
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    public void listIterator2()
    {
        final ListIterator<TestResult> i = newFixtureResult(list).listIterator(1);

        int counter = 0;

        while(i.hasNext())
        {
            final TestResult r;

            if(counter == 0)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
            }
            else if(counter == 1)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
            }
            else
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void listIterator3()
    {
        newFixtureResult(list).listIterator(5);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void listIterator4()
    {
        newFixtureResult(list).listIterator(-7);
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void listIterator5()
    {
        final ListIterator<TestResult> i = newFixtureResult(list).listIterator(1);
        i.next();
        i.remove();
    }

    @Test
    public void size()
    {
        assertEqual(4, newFixtureResult(list).size());
    }

    @Test
    public void toArray()
    {
        final Object[] a = newFixtureResult(list).toArray();

        assertEqual(4, a.length);
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})), a[0]);
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})), a[1]);
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})), a[2]);
        assertEqual(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})), a[3]);
    }

    @Test
    public void iterator1()
    {
        final Iterator<TestResult> i = newFixtureResult(list).iterator();

        int counter = 0;

        while(i.hasNext())
        {
            final TestResult r;

            if(counter == 0)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
            }
            else if(counter == 1)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
            }
            else if(counter == 2)
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
            }
            else
            {
                r = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void iterator2()
    {
        final Iterator<TestResult> i = newFixtureResult(list).iterator();
        i.next();
        i.remove();
    }

    @Test
    public void serialization()
    {
        final FixtureResult result = newFixtureResult(list);

        assertSerializes(result);
        assertSerializesEqual(result);
        assertHasDeclaredField(result.getClass(), "serialVersionUID");
    }
   
    @Test
    public void testToString()
    {
        assertEqual(newFixtureResult(list).toString(), list.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final List<TestResult> l1 = new LinkedList<TestResult>();
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})));

        final List<TestResult> l2 = new LinkedList<TestResult>();
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));

        final ObjectFactory<FixtureResult> factory = new ObjectFactory<FixtureResult>()
        {
            public FixtureResult newInstanceX()
            {
                return newFixtureResult(l1);
            }

            public FixtureResult newInstanceY()
            {
                return newFixtureResult(l2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final List<TestResult> l1 = new LinkedList<TestResult>();
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));

        final List<TestResult> l2 = new LinkedList<TestResult>();
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));

        final ObjectFactory<FixtureResult> factory = new ObjectFactory<FixtureResult>()
        {
            public FixtureResult newInstanceX()
            {
                return newFixtureResult(l1);
            }

            public FixtureResult newInstanceY()
            {
                return newFixtureResult(l2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final List<TestResult> l1 = new LinkedList<TestResult>();
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));
        l1.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{})));

        final List<TestResult> l2 = new LinkedList<TestResult>();
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{})));
        l2.add(newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{})));

        final ObjectFactory<FixtureResult> factory = new ObjectFactory<FixtureResult>()
        {
            public FixtureResult newInstanceX()
            {
                return newFixtureResult(l1);
            }

            public FixtureResult newInstanceY()
            {
                return newFixtureResult(l2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    private static final class A
    {
        @Test
        public void m1()
        {

        }

        @Test
        public void m2()
        {

        }

        @Test
        public void m3()
        {

        }

        @Test
        public void m4()
        {

        }
    }
}
