/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import org.jtiger.assertion.ObjectFactory;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.framework.TestResultFactory.newTestResult;
import static org.jtiger.framework.FixtureResultFactory.newFixtureResult;
import static org.jtiger.framework.FixtureResultsFactory.newFixtureResults;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;

@Fixture(value = "FixtureResultsFactory", description = "Performs Unit Tests on org.jtiger.framework.FixtureResultsFactory")
@Category("org.jtiger.framework.FixtureResultsFactory")
public final class TestFixtureResultsFactory
{
    private List<FixtureResult> list;

    public TestFixtureResultsFactory()
    {

    }

    @SetUp
    public void createTestList()
    {
        list = new LinkedList<FixtureResult>();

        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        list.add(newFixtureResult(results1));
        list.add(newFixtureResult(results2));
        list.add(newFixtureResult(results3));
    }

    @TearDown
    public void emptyTestList()
    {
        list = null;
    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureResultsFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newFixtureResults(null);
    }


    @Test
    public void get1()
    {
        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        assertEqual(newFixtureResult(results1), newFixtureResults(list).get(0));
        assertEqual(newFixtureResult(results2), newFixtureResults(list).get(1));
        assertEqual(newFixtureResult(results3), newFixtureResults(list).get(2));
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void get2()
    {
        newFixtureResults(list).get(3);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void get3()
    {
        newFixtureResults(list).get(-7);
    }

    @Test
    public void listIterator1()
    {
        final ListIterator<FixtureResult> i = newFixtureResults(list).listIterator();

        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        int counter = 0;

        while(i.hasNext())
        {
            final FixtureResult r;

            if(counter == 0)
            {
                r = newFixtureResult(results1);
            }
            else if(counter == 1)
            {
                r = newFixtureResult(results2);
            }
            else
            {
                r = newFixtureResult(results3);
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    public void listIterator2()
    {
        final ListIterator<FixtureResult> i = newFixtureResults(list).listIterator(1);

        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        int counter = 0;

        while(i.hasNext())
        {
            final FixtureResult r;

            if(counter == 0)
            {
                r = newFixtureResult(results2);
            }
            else
            {
                r = newFixtureResult(results3);
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void listIterator3()
    {
        newFixtureResults(list).listIterator(4);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    public void listIterator4()
    {
        newFixtureResults(list).listIterator(-7);
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void listIterator5()
    {
        final ListIterator<FixtureResult> i = newFixtureResults(list).listIterator(0);
        i.next();
        i.remove();
    }

    @Test
    public void size()
    {
        assertEqual(3, newFixtureResults(list).size());
    }

    @Test
    public void toArray()
    {
        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        final Object[] a = newFixtureResults(list).toArray();

        assertEqual(3, a.length);
        assertEqual(newFixtureResult(results1), a[0]);
        assertEqual(newFixtureResult(results2), a[1]);
        assertEqual(newFixtureResult(results3), a[2]);
    }

    @Test
    public void iterator1()
    {
        final Iterator<FixtureResult> i = newFixtureResults(list).iterator();

        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        int counter = 0;

        while(i.hasNext())
        {
            final FixtureResult r;

            if(counter == 0)
            {
                r = newFixtureResult(results1);
            }
            else if(counter == 1)
            {
                r = newFixtureResult(results2);
            }
            else
            {
                r = newFixtureResult(results3);
            }

            assertEqual(r, i.next());
            counter++;
        }
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void iterator2()
    {
        final Iterator<FixtureResult> i = newFixtureResults(list).iterator();
        i.next();
        i.remove();
    }

    @Test
    public void serialization()
    {                                     
        final FixtureResults results = newFixtureResults(list);

        assertSerializes(results);
        assertSerializesEqual(results);
        assertHasDeclaredField(results.getClass(), "serialVersionUID");
    }

    @Test
    public void testToString()
    {
        assertEqual(newFixtureResults(list).toString(), list.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        final List<FixtureResult> list1 = new LinkedList<FixtureResult>();
        list1.add(newFixtureResult(results1));
        list1.add(newFixtureResult(results2));
        list1.add(newFixtureResult(results3));

        final List<FixtureResult> list2 = new LinkedList<FixtureResult>();
        list2.add(newFixtureResult(results1));
        list2.add(newFixtureResult(results3));
        list2.add(newFixtureResult(results2));

        final ObjectFactory<FixtureResults> factory = new ObjectFactory<FixtureResults>()
        {
            public FixtureResults newInstanceX()
            {
                return newFixtureResults(list1);
            }

            public FixtureResults newInstanceY()
            {
                return newFixtureResults(list2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        final List<FixtureResult> list1 = new LinkedList<FixtureResult>();
        list1.add(newFixtureResult(results1));
        list1.add(newFixtureResult(results2));
        list1.add(newFixtureResult(results3));

        final List<FixtureResult> list2 = new LinkedList<FixtureResult>();
        list2.add(newFixtureResult(results1));
        list2.add(newFixtureResult(results2));

        final ObjectFactory<FixtureResults> factory = new ObjectFactory<FixtureResults>()
        {
            public FixtureResults newInstanceX()
            {
                return newFixtureResults(list1);
            }

            public FixtureResults newInstanceY()
            {
                return newFixtureResults(list2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final TestResult tr1 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m1", new Class<?>[]{}));
        final TestResult tr2 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m2", new Class<?>[]{}));
        final TestResult tr3 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m3", new Class<?>[]{}));
        final TestResult tr4 = newTestResult(null, null, null, null, assertHasMethod(A.class, "m4", new Class<?>[]{}));

        final List<TestResult> results1 = new LinkedList<TestResult>();
        results1.add(tr1);
        results1.add(tr2);

        final List<TestResult> results2 = new LinkedList<TestResult>();
        results2.add(tr3);

        final List<TestResult> results3 = new LinkedList<TestResult>();
        results3.add(tr4);

        final List<FixtureResult> list1 = new LinkedList<FixtureResult>();
        list1.add(newFixtureResult(results1));
        list1.add(newFixtureResult(results2));

        final List<FixtureResult> list2 = new LinkedList<FixtureResult>();
        list2.add(newFixtureResult(results1));
        list2.add(newFixtureResult(results2));
        list2.add(newFixtureResult(results3));

        final ObjectFactory<FixtureResults> factory = new ObjectFactory<FixtureResults>()
        {
            public FixtureResults newInstanceX()
            {
                return newFixtureResults(list1);
            }

            public FixtureResults newInstanceY()
            {
                return newFixtureResults(list2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
    }

    private static final class A
    {
        @Test
        public void m1()
        {

        }

        @Test
        public void m2()
        {

        }

        @Test
        public void m3()
        {

        }

        @Test
        public void m4()
        {

        }
    }

}
