/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;

@Fixture(value = "FixturesRunnerFactory", description = "Performs Unit Tests on org.jtiger.framework.FixturesRunnerFactory")
@Category("org.jtiger.framework.FixturesRunnerFactory")
public final class TestFixturesRunnerFactory
{
    public TestFixturesRunnerFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixturesRunnerFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void runNullArg1() throws RunnerException
    {
        newFixturesRunner().run(null);
    }

    @Test
    public void runNullArg2() throws RunnerException
    {
        newFixturesRunner().run(newFixturesRunnerConfig(null, null, null, false));
    }
}
