/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertNotNull;

@Fixture(value = "FixturesRunnerMain", description = "Performs Unit Tests on org.jtiger.framework.FixturesRunnerMain")
@Category("org.jtiger.framework.FixturesRunnerMain")
public final class TestFixturesRunnerMain
{
    public TestFixturesRunnerMain()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixturesRunnerMain.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void isCorrectFormat1() throws ClassNotFoundException
    {
        final String[] s = null;
        assertFalse(FixturesRunnerMain.isCorrectFormat(s));
        assertFalse(FixturesRunnerMain.isCorrectFormat());
    }

    @Test
    public void isCorrectFormat2() throws ClassNotFoundException
    {
        assertTrue(FixturesRunnerMain.isCorrectFormat("-fixtureClasses", String.class.getName()));
    }

    @Test
    @ExpectException(ClassNotFoundException.class)
    public void isCorrectFormat3() throws ClassNotFoundException
    {
        FixturesRunnerMain.isCorrectFormat("-fixtureClasses", "xxx");
    }

    @Test
    public void main1()
    {
        final PrintStream stderr = System.err;
        final ByteArrayOutputStream out = new ByteArrayOutputStream();
        System.setErr(new PrintStream(out));

        FixturesRunnerMain.main("-fixtureClasses", "xxx");

        System.setErr(stderr);

        assertNotNull(new String(out.toByteArray()));
        assertTrue(new String(out.toByteArray()).length() > 0);
    }

    @Test
    public void usage()
    {
        final PrintStream stderr = System.err;
        final ByteArrayOutputStream out = new ByteArrayOutputStream();
        System.setErr(new PrintStream(out));

        FixturesRunnerMain.usage();

        System.setErr(stderr);

        assertNotNull(new String(out.toByteArray()));
        assertTrue(new String(out.toByteArray()).length() > 0);
    }
}
