/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static java.util.Arrays.asList;
import static org.jtiger.framework.SequenceFactory.newSequence;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.framework.SequenceTesterFactory.newSequenceTester;
import java.util.NoSuchElementException;

@Fixture(value = "TestSequenceFactory", description = "Performs Unit Tests on SequenceFactory")
@Category({"org.jtiger.framework.SequenceFactory", "ListSequence"})
public final class TestListSequence
{
    public TestListSequence()
    {

    }

    @Test
    @Category("methods")
    void methods()
    {
        final SequenceCreator<Integer> creator = new SequenceCreator<Integer>()
        {
            public org.jtiger.framework.Sequence<Integer> createSequence(final Integer... elements) throws NullPointerException
            {
                if(elements == null)
                {
                    throw new NullPointerException();
                }
                else
                {
                    return newSequence(asList(elements));
                }
            }
        };
        final SequenceTester<Integer> tester = newSequenceTester();

        tester.serialization(creator);
        tester.get(creator);
        tester.length(creator);
        tester.append(creator);
        tester.getSubSequence(creator);
        tester.insert(creator);
        tester.delete(creator);
        tester.indexOf1(creator);
        tester.indexOf2(creator);
        tester.lastIndexOf1(creator);
        tester.lastIndexOf2(creator);
        tester.iterator(creator);
        tester.getIterator1(creator);
        tester.getIterator2(creator);
        tester.isEmpty(creator);
        tester._toString(creator);
        tester.equalsHashCode(creator);
        tester.clone(creator);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    @Category("get")
    void get1()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).get(-1);
    }

    @Test
    @ExpectException(IndexOutOfBoundsException.class)
    @Category("get")
    void get2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).get(3);
    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("append")
    void append()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).append(null);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence1()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getSubSequence(-1, 3);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getSubSequence(0, 4);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getSubSequence")
    void getSubSequence3()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getSubSequence(2, 1);
    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("insert")
    void insert1()
    {
        final Sequence<Integer> s = null;
        newSequence(asList(new Integer[]{7, 8, 9})).insert(0, s);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("insert")
    void insert2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).insert(-1, newSequence(10));
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("insert")
    void insert3()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).insert(4, newSequence(10));
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete1()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).delete(-1, 3);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).delete(0, 4);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("delete")
    void delete3()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).delete(2, 1);
    }

    @Test
    @Category("index")
    @ExpectException(PositionOutOfBoundsException.class)
    void indexOf1()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).indexOf(-1, 1);
    }

    @Test
    @Category("index")
    @ExpectException(PositionOutOfBoundsException.class)
    void indexOf2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).indexOf(4, 1);
    }

    @Test
    @Category("lastIndexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void lastIndexOf1()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).lastIndexOf(-1, 1);
    }

    @Test
    @Category("lastIndexOf")
    @ExpectException(PositionOutOfBoundsException.class)
    void lastIndexOf2()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).lastIndexOf(4, 1);
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator1()
    {
        final SequenceIterator<Integer> i = newSequence(asList(new Integer[]{7, 8, 9})).getIterator();
        assertTrue(i.hasNext());
        assertEqual(7, i.next());
        assertTrue(i.hasNext());
        assertEqual(8, i.next());
        assertTrue(i.hasNext());
        assertEqual(9, i.next());
        i.next();
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator2()
    {
        final SequenceIterator<Integer> i = newSequence(asList(new Integer[]{7, 8, 9})).getIterator(3);
        assertTrue(i.hasPrevious());
        assertEqual(9, i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(8, i.previous());
        assertTrue(i.hasPrevious());
        assertEqual(7, i.previous());
        i.previous();
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    @Category("getIterator")
    void getIterator3()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getIterator().remove();
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getIterator")
    void getIterator4()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getIterator(-1);
    }

    @Test
    @ExpectException(PositionOutOfBoundsException.class)
    @Category("getIterator")
    void getIterator5()
    {
        newSequence(asList(new Integer[]{7, 8, 9})).getIterator(4);
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator6()
    {
        newSequence(asList(new Integer[0])).getIterator().next();
    }

    @Test
    @ExpectException(NoSuchElementException.class)
    @Category("getIterator")
    void getIterator7()
    {
        newSequence(asList(new Integer[0])).getIterator().previous();
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    @Category("getIterator")
    void getIterator8()
    {
        newSequence(asList(new Integer[0])).getIterator().remove();
    }
}
