/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import static org.jtiger.framework.MethodCategoryFactory.newMethodCategory;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;

@Fixture(value = "MethodCategoryFactory", description = "Performs Unit Tests on org.jtiger.framework.MethodCategoryFactory")
@Category("org.jtiger.framework.MethodCategoryFactory")
public final class TestMethodCategoryFactory
{
    public TestMethodCategoryFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(MethodCategoryFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void isInAnyCategories1()
    {
        newMethodCategory().isInAnyCategories(null, null);
    }

    @Test
    public void isInAnyCategories2()
    {
        final Method m = assertHasMethod(A.class, "m", new Class<?>[]{});
        assertTrue(newMethodCategory().isInAnyCategories(m, null));
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence(new String[0])));
    }

    @Test
    public void isInAnyCategories3()
    {
        final Method m = assertHasMethod(A.class, "m", new Class<?>[]{});
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence("[a-z]", "1", "5")));
    }

    @Test
    public void isInAnyCategories4()
    {
        final Method m = assertHasMethod(B.class, "m", new Class<?>[]{});
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence("[a-z]1")));
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence("[a-z]2")));
    }

    @Test
    public void isInAnyCategories5()
    {
        final Method m = assertHasMethod(C.class, "m", new Class<?>[]{});
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence("[a-z]1")));
    }

    @Test
    public void isInAnyCategories6()
    {
        final Method m = assertHasMethod(D.class, "m", new Class<?>[]{});
        assertTrue(newMethodCategory().isInAnyCategories(m, newSequence("[a-d]3")));
    }

    @Test
    public void isInAnyCategories7()
    {
        final Method m = assertHasMethod(D.class, "m", new Class<?>[]{});
        assertFalse(newMethodCategory().isInAnyCategories(m, newSequence("[a-d]")));
    }

    private static final class A
    {
        @Category("c")
        public void m()
        {

        }
    }

    @Category("c1")
    private static final class B
    {
        @Category("c2")
        public void m()
        {

        }
    }

    @Category("c1")
    private static final class C
    {
        public void m()
        {

        }
    }

    @Category({"c1", "c2", "c3"})
    private static final class D
    {
        public void m()
        {

        }
    }
}
