/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.framework.SequenceFactory.newSequence;
import static org.jtiger.framework.SequenceFactory.newConstantSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.List;

@Fixture(value = "TestSequenceFactory", description = "Performs Unit Tests on SequenceFactory")
@Category("org.jtiger.framework.SequenceFactory")
public final class TestSequenceFactory
{
    public TestSequenceFactory()
    {

    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    @Category("Constructor")
    void constructor() throws Throwable
    {
        final Constructor<?> c = assertHasDeclaredConstructor(org.jtiger.framework.SequenceFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        try
        {
            c.newInstance();
        }
        catch(InvocationTargetException e)
        {
            throw e.getCause();
        }
    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("newSequence")
    void newSequence1()
    {
        newSequence((Object[])null);
    }

    @Test
    @ExpectException(NullPointerException.class)
    @Category("newSubSequence")
    void newSequence2()
    {
        newSequence((List<?>)null);
    }

    @Test
    @ExpectException(IllegalArgumentException.class)
    @Category("newCostantSequence")
    void newCostantSequence1()
    {
        newConstantSequence(new Object(), 0);
    }

    @Test
    @ExpectException(IllegalArgumentException.class)
    @Category("newCostantSequence")
    void newCostantSequence2()
    {
        newConstantSequence(new Object(), -1);
    }
}
