/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import static org.jtiger.framework.TestDescriptionFactory.newTestDescription;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertNull;

@Fixture(value = "TestDescriptionFactory", description = "Performs Unit Tests on org.jtiger.framework.TestDescriptionFactory")
@Category("org.jtiger.framework.TestDescriptionFactory")
public final class TestTestDescriptionFactory
{
    public TestTestDescriptionFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(TestDescriptionFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getTestDescriptionNullArg()
    {
        newTestDescription().getTestDescription(null);
    }

    @Test
    public void getTestDescription1()
    {
        final Method m1 = assertHasMethod(DummyFixture.class, "m1", new Class<?>[]{});
        assertEqual("", newTestDescription().getTestDescription(m1));
        final Method m2 = assertHasMethod(DummyFixture.class, "m2", new Class<?>[]{});
        assertEqual("test description", newTestDescription().getTestDescription(m2));
        final Method m3 = assertHasMethod(DummyFixture.class, "m3", new Class<?>[]{});
        assertEqual("", newTestDescription().getTestDescription(m3));
        final Method m4 = assertHasMethod(DummyFixture.class, "m4", new Class<?>[]{});
        assertEqual("test description", newTestDescription().getTestDescription(m4));
        final Method m5 = assertHasMethod(DummyFixture.class, "m5", new Class<?>[]{});
        assertNull(newTestDescription().getTestDescription(m5));
    }

    private static final class DummyFixture
    {
        @Test
        public void m1()
        {

        }

        @Test(description = "test description")
        public void m2()
        {

        }

        @Test(value = "", description = "")
        public void m3()
        {

        }

        @Test(value = "test name", description = "test description")
        public void m4()
        {

        }

        public void m5()
        {

        }
    }
}
