/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.framework.TestFailureFactory.newTestFailure;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_SETUP;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;
import static org.jtiger.framework.TestResultType.IGNORED_ANNOTATED;
import static org.jtiger.framework.TestResultType.IGNORED_CANNOT_INVOKE;

@Fixture(value = "TestFailureFactory", description = "Performs Unit Tests on org.jtiger.framework.TestFailureFactory")
@Category("org.jtiger.framework.TestFailureFactory")
public final class TestTestFailureFactory
{
    public TestTestFailureFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(TestFailureFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void isFailure()
    {
        assertFalse(newTestFailure().isFailure(SUCCESS));
        assertFalse(newTestFailure().isFailure(IGNORED_ANNOTATED));
        assertFalse(newTestFailure().isFailure(IGNORED_CANNOT_INVOKE));
        assertTrue(newTestFailure().isFailure(FAILURE_SETUP));
        assertTrue(newTestFailure().isFailure(FAILURE));
        assertTrue(newTestFailure().isFailure(FAILURE_TEARDOWN));
    }
}
