/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import static org.jtiger.framework.TestIgnoredFactory.newTestIgnored;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_SETUP;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;
import static org.jtiger.framework.TestResultType.IGNORED_ANNOTATED;
import static org.jtiger.framework.TestResultType.IGNORED_CANNOT_INVOKE;

@Fixture(value = "TestIgnoredFactory", description = "Performs Unit Tests on org.jtiger.framework.TestIgnoredFactory")
@Category("org.jtiger.framework.TestIgnoredFactory")
public final class TestTestIgnoredFactory
{
    public TestTestIgnoredFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(TestIgnoredFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void isIgnored()
    {
        assertFalse(newTestIgnored().isIgnored(SUCCESS));
        assertTrue(newTestIgnored().isIgnored(IGNORED_ANNOTATED));
        assertTrue(newTestIgnored().isIgnored(IGNORED_CANNOT_INVOKE));
        assertFalse(newTestIgnored().isIgnored(FAILURE_SETUP));
        assertFalse(newTestIgnored().isIgnored(FAILURE));
        assertFalse(newTestIgnored().isIgnored(FAILURE_TEARDOWN));
    }

}

