/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.framework.TestMethodCategoriesFactory.newTestMethodCategories;

@Fixture(value = "TestMethodCategoriesFactory", description = "Performs Unit Tests on org.jtiger.framework.TestMethodCategoriesFactory")
@Category("org.jtiger.framework.TestMethodCategoriesFactory")
public final class TestTestMethodCategoriesFactory
{
    public TestTestMethodCategoriesFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(TestMethodCategoriesFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getTestMethodCategoriesNullArg()
    {
        newTestMethodCategories().getTestMethodCategories(null);
    }

    @Test
    public void getTestMethodCategories1()
    {
        final Method m = assertHasMethod(A.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(0, a.length());
    }

    @Test
    public void getTestMethodCategories2()
    {
        final Method m = assertHasMethod(B.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(1, a.length());
        assertEqual("cat1", a.get(0));
    }

    @Test
    public void getTestMethodCategories3()
    {
        final Method m = assertHasMethod(C.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(2, a.length());
    }

    @Test
    public void getTestMethodCategories4()
    {
        final Method m = assertHasMethod(D.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(3, a.length());
    }

    @Test
    public void getTestMethodCategories5()
    {
        final Method m = assertHasMethod(E.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(4, a.length());
    }

    @Test
    public void getTestMethodCategories6()
    {
        final Method m = assertHasMethod(F.class, "m", new Class<?>[]{});
        final ReadOnlyArray<String> a = newTestMethodCategories().getTestMethodCategories(m);
        assertEqual(4, a.length());
    }

    private static final class A
    {
        public void m()
        {

        }
    }

    @Category("cat1")
    private static final class B
    {
        public void m()
        {

        }
    }

    @Category({"cat1", "cat2"})
    private static final class C
    {
        public void m()
        {

        }
    }

    @Category({"cat1", "cat2"})
    private static final class D
    {
        @Category("cat3")
        public void m()
        {

        }
    }

    @Category({"cat1", "cat2"})
    private static final class E
    {
        @Category({"cat3", "cat4"})
        public void m()
        {

        }
    }

    @Category({"cat1", "cat2"})
    private static final class F
    {
        @Category({"cat3", "cat4", "cat2"})
        public void m()
        {

        }
    }
}
