/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import static org.jtiger.framework.TestNameFactory.newTestName;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertFalse;

@Fixture(value = "TestNameFactory", description = "Performs Unit Tests on org.jtiger.framework.TestNameFactory")
@Category("org.jtiger.framework.TestNameFactory")
public final class TestTestNameFactory
{
    public TestTestNameFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(TestNameFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void getTestNameNullArg()
    {
        newTestName().getTestName(null);
    }

    @Test
    public void getTestName1()
    {
        final Method m1 = assertHasMethod(DummyFixture.class, "m1", new Class<?>[]{});
        assertEqual(m1.getName(), newTestName().getTestName(m1));
        final Method m2 = assertHasMethod(DummyFixture.class, "m2", new Class<?>[]{});
        assertEqual("test name", newTestName().getTestName(m2));
        final Method m3 = assertHasMethod(DummyFixture.class, "m3", new Class<?>[]{});
        assertEqual(m3.getName(), newTestName().getTestName(m3));
        final Method m4 = assertHasMethod(DummyFixture.class, "m4", new Class<?>[]{});
        assertEqual("test name", newTestName().getTestName(m4));
        final Method m5 = assertHasMethod(DummyFixture.class, "m5", new Class<?>[]{});
        assertEqual(m5.getName(), newTestName().getTestName(m5));
    }

    private static final class DummyFixture
    {
        @Test
        public void m1()
        {

        }

        @Test("test name")
        public void m2()
        {

        }

        @Test("")
        public void m3()
        {

        }

        @Test(value = "test name", description = "test description")
        public void m4()
        {

        }

        public void m5()
        {

        }
    }
}
