/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import static org.jtiger.framework.UnmodifiableIteratorFactory.unmodifiableIterator;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertSame;

@Fixture(value = "UnmodifiableIteratorFactory", description = "Performs Unit Tests on org.jtiger.framework.UnmodifiableIteratorFactory")
@Category("org.jtiger.framework.UnmodifiableIteratorFactory")
public final class TestUnmodifiableIteratorFactory
{
    public TestUnmodifiableIteratorFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(UnmodifiableIteratorFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        unmodifiableIterator(null);
    }

    @Test
    public void iterator1()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final Iterator<String> i = unmodifiableIterator(l.iterator());
        assertTrue(i.hasNext());
        assertSame("a", i.next());
        assertTrue(i.hasNext());
        assertSame("b", i.next());
        assertTrue(i.hasNext());
        assertSame("c", i.next());
        assertFalse(i.hasNext());
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void iterator2()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final Iterator<String> i = unmodifiableIterator(l.iterator());
        i.next();
        i.remove();
    }
}
