/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.framework.UnmodifiableListIteratorFactory.unmodifiableListIterator;

@Fixture(value = "UnmodifiableListIteratorFactory", description = "Performs Unit Tests on org.jtiger.framework.UnmodifiableListIteratorFactory")
@Category("org.jtiger.framework.UnmodifiableListIteratorFactory")
public final class TestUnmodifiableListIteratorFactory
{
    public TestUnmodifiableListIteratorFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(UnmodifiableListIteratorFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        unmodifiableListIterator(null);
    }

    @Test
    public void listIterator1()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final ListIterator<String> i = unmodifiableListIterator(l.listIterator());
        assertTrue(i.hasNext());
        assertSame("a", i.next());
        assertTrue(i.hasNext());
        assertSame("b", i.next());
        assertTrue(i.hasNext());
        assertSame("c", i.next());
        assertFalse(i.hasNext());
        assertTrue(i.hasPrevious());
        assertSame("c", i.previous());
        assertTrue(i.hasPrevious());
        assertSame("b", i.previous());
        assertTrue(i.hasPrevious());
        assertSame("a", i.previous());
        assertFalse(i.hasPrevious());
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void remove()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final ListIterator<String> i = unmodifiableListIterator(l.listIterator());
        i.next();
        i.remove();
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void set()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final ListIterator<String> i = unmodifiableListIterator(l.listIterator());
        i.next();
        i.set("x");
    }

    @Test
    @ExpectException(UnsupportedOperationException.class)
    public void add()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final ListIterator<String> i = unmodifiableListIterator(l.listIterator());
        i.next();
        i.add("x");
    }

    @Test
    public void index()
    {
        final List<String> l = new LinkedList<String>();
        l.add("a");
        l.add("b");
        l.add("c");
        final ListIterator<String> i = unmodifiableListIterator(l.listIterator());
        i.next();
        i.next();
        assertEqual(i.nextIndex(), 2);
        assertEqual(i.previousIndex(), 1);
    }
}
