/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework.junit;

import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.SetUpException;
import org.jtiger.framework.TearDownException;
import org.jtiger.framework.Test;

@Fixture(value = "JUnitSetUpTearDown", description = "Performs Unit Tests on org.jtiger.framework.junit.JUnitSetUpTearDown")
@Category("org.jtiger.framework.junit.JUnitSetUpTearDown")
public final class TestJUnitSetUpTearDown
{
    public TestJUnitSetUpTearDown()
    {

    }

    @Test
    public void setUp1() throws SetUpException
    {
        new JUnitSetUpTearDown().setUp(new A());
        new JUnitSetUpTearDown().setUp(new B());
        new JUnitSetUpTearDown().setUp(new C());
        new JUnitSetUpTearDown().setUp(new D());
    }

    @Test
    @ExpectException(SetUpException.class)
    public void setUp2() throws SetUpException
    {
        new JUnitSetUpTearDown().setUp(new Y());
    }

    @Test
    @ExpectException(SetUpException.class)
    public void setUp3() throws SetUpException
    {
        new JUnitSetUpTearDown().setUp(new Z());
    }

    @Test
    @ExpectException(SetUpException.class)
    public void setUp4() throws SetUpException
    {
        new JUnitSetUpTearDown().setUp(new X());
    }

    @Test
    public void tearDown1() throws TearDownException
    {
        new JUnitSetUpTearDown().tearDown(new A());
        new JUnitSetUpTearDown().tearDown(new B());
        new JUnitSetUpTearDown().tearDown(new C());
        new JUnitSetUpTearDown().tearDown(new D());
    }

    @Test
    @ExpectException(TearDownException.class)
    public void tearDown2() throws TearDownException
    {
        new JUnitSetUpTearDown().tearDown(new Y());
    }

    @Test
    @ExpectException(TearDownException.class)
    public void tearDown3() throws TearDownException
    {
        new JUnitSetUpTearDown().tearDown(new Z());
    }

    @Test
    @ExpectException(TearDownException.class)
    public void tearDown4() throws TearDownException
    {
        new JUnitSetUpTearDown().tearDown(new X());
    }

    private static class A
    {
        protected final void setUp()
        {

        }

        protected final void tearDown()
        {

        }
    }

    private static class B extends A
    {

    }

    private static final class C extends B
    {

    }

    private static final class D
    {
        public void setUp()
        {

        }

        public void tearDown()
        {

        }
    }

    private static final class Z
    {
        public void SetUp()
        {

        }

        public void TearDown()
        {

        }
    }

    private static final class Y
    {
        public void setUp(final int i)
        {

        }

        public void tearDown(final int i)
        {

        }
    }

    private static final class X
    {
        protected void setUp()
        {
            throw new NullPointerException();
        }

        protected void tearDown()
        {
            throw new NullPointerException();
        }
    }
}
