/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.framework.junit;

import java.lang.reflect.Method;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasMethod;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.assertion.Basic.assertFalse;

@Fixture(value = "JUnitTestDefinition", description = "Performs Unit Tests on org.jtiger.framework.junit.JUnitTestDefinition")
@Category("org.jtiger.framework.junit.TestJUnitTestDefinition")
public final class TestJUnitTestDefinition
{
    public TestJUnitTestDefinition()
    {

    }

    @Test
    public void isTest()
    {
        assertFalse(new JUnitTestDefinition().isTest(null));
        final Class<?> c = SampleTestCase.class;
        final Method m1 = assertHasMethod(c, "test", null);
        assertTrue(new JUnitTestDefinition().isTest(m1));
        final Method m2 = assertHasMethod(c, "Test", null);
        assertFalse(new JUnitTestDefinition().isTest(m2));
        final Method m3 = assertHasMethod(c, "testMethod", null);
        assertTrue(new JUnitTestDefinition().isTest(m3));
        final Method m4 = assertHasMethod(c, "tests", null);
        assertTrue(new JUnitTestDefinition().isTest(m4));
        final Method m5 = assertHasMethod(c, "test$", null);
        assertTrue(new JUnitTestDefinition().isTest(m5));
    }

    private static final class SampleTestCase
    {
        private SampleTestCase()
        {

        }

        public void test()
        {

        }

        public void Test()
        {

        }

        public void testMethod()
        {

        }

        public void tests()
        {

        }

        public void test$()
        {

        }
    }
}
