/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.report.html.FixtureResultsFactory.newFixtureResults;
import static org.jtiger.report.html.TestResultFactory.newTestResult;
import static org.jtiger.report.html.FixtureHtmlFileWriterFactory.newFixtureHtmlFileWriter;
import static org.jtiger.report.html.FixturesFilenamePolicyFactory.newFixturesFilenamePolicy;

@Fixture(value = "FixtureHtmlFileWriterFactory", description = "Performs Unit Tests on org.jtiger.report.html.FixtureHtmlFileWriterFactory")
@Category("org.jtiger.report.html.FixtureHtmlFileWriterFactory")
public final class TestFixtureHtmlFileWriterFactory
{
    public TestFixtureHtmlFileWriterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureHtmlFileWriterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void writeFixtureHtml1() throws FixtureResultsHandlerException
    {
        final FixtureResults fr = newFixtureResults("name1", "description1", "className1", newSequence(new TestResult[]
        {
            newTestResult("name11", "exception11", "11", "message11", "methodName11", "description11", "result11"),
            newTestResult("name12", "exception12", "12", "message12", "methodName12", "description12", "result12"),
            newTestResult("name13", "exception13", "13", "message13", "methodName13", "description13", "result13")
        }));

        final File temp = new File(System.getProperty("java.io.tmpdir"), "fixtures" + System.currentTimeMillis());
        final FilenamePolicy policy = newFixturesFilenamePolicy();
        newFixtureHtmlFileWriter().writeFixtureHtml(fr, temp, policy, "build time");
    }

    @Test
    @ExpectException(FixtureResultsHandlerException.class)
    public void writeFixtureHtml2() throws FixtureResultsHandlerException, IOException
    {
        final FixtureResults fr = newFixtureResults("name1", "description1", "className1", newSequence(new TestResult[]
        {
            newTestResult("name11", "exception11", "11", "message11", "methodName11", "description11", "result11"),
            newTestResult("name12", "exception12", "12", "message12", "methodName12", "description12", "result12"),
            newTestResult("name13", "exception13", "13", "message13", "methodName13", "description13", "result13")
        }));

        final File temp = new File(System.getProperty("java.io.tmpdir"), "exist");
        new FileOutputStream(temp).close();
        final FilenamePolicy policy = newFixturesFilenamePolicy();
        newFixtureHtmlFileWriter().writeFixtureHtml(fr, temp, policy, "build time");
    }
}
