/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "FixtureResultBeanImpl", description = "Performs Unit Tests on org.jtiger.report.html.FixtureResultBeanImpl")
@Category("org.jtiger.report.html.FixtureResultBeanImpl")
public final class TestFixtureResultBeanImpl
{
    public TestFixtureResultBeanImpl()
    {

    }

    @Test
    public void constructors()
    {
        new FixtureResultBeanImpl();
        final FixtureResultBean b = new FixtureResultBeanImpl(
                "name", "href");
        assertEqual("name", b.getName());
        assertEqual("href", b.getHref());
    }

    @Test
    public void name()
    {
        final FixtureResultBean b = new FixtureResultBeanImpl();
        b.setName("name");
        assertEqual("name", b.getName());
    }

    @Test
    public void exception()
    {
        final FixtureResultBean b = new FixtureResultBeanImpl();
        b.setHref("href");
        assertEqual("href", b.getHref());
    }

    @Test
    public void serialization()
    {
        final FixtureResultBean b = new FixtureResultBeanImpl("name", "href");

        assertSerializes(b);
        assertSerializesEqual(b);
        assertHasDeclaredField(b.getClass(), "serialVersionUID");
    }

    @Test
    public void testToString()
    {
        final FixtureResultBean b = new FixtureResultBeanImpl("name", "href");

        final String s = "[name][href]";

        assertEqual(s, b.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final ObjectFactory<FixtureResultBeanImpl> factory = new ObjectFactory<FixtureResultBeanImpl>()
        {
            public FixtureResultBeanImpl newInstanceX()
            {
                return new FixtureResultBeanImpl("name", "href");
            }

            public FixtureResultBeanImpl newInstanceY()
            {
                return new FixtureResultBeanImpl("name x", "href");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final ObjectFactory<FixtureResultBeanImpl> factory = new ObjectFactory<FixtureResultBeanImpl>()
        {
            public FixtureResultBeanImpl newInstanceX()
            {
                return new FixtureResultBeanImpl("name", "href");
            }

            public FixtureResultBeanImpl newInstanceY()
            {
                return new FixtureResultBeanImpl("name", "href x");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final ObjectFactory<FixtureResultBeanImpl> factory = new ObjectFactory<FixtureResultBeanImpl>()
        {
            public FixtureResultBeanImpl newInstanceX()
            {
                return new FixtureResultBeanImpl("name", "href");
            }

            public FixtureResultBeanImpl newInstanceY()
            {
                return new FixtureResultBeanImpl(null, "href");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode4()
    {
        final ObjectFactory<FixtureResultBeanImpl> factory = new ObjectFactory<FixtureResultBeanImpl>()
        {
            public FixtureResultBeanImpl newInstanceX()
            {
                return new FixtureResultBeanImpl("name", "href");
            }

            public FixtureResultBeanImpl newInstanceY()
            {
                return new FixtureResultBeanImpl("name", null);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
