/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.report.html.FixtureResultConverterFactory.newFixtureResultConverter;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;

@Fixture(value = "FixtureResultConverterFactory", description = "Performs Unit Tests on org.jtiger.report.html.FixtureResultConverterFactory")
@Category("org.jtiger.report.html.FixtureResultConverterFactory")
public final class TestFixtureResultConverterFactory
{
    public TestFixtureResultConverterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureResultConverterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void convertFixtureResults() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);
        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final ReadOnlyArray<FixtureResults> a = newFixtureResultConverter().convertFixtureResults(results);
        assertEqual(4, a.length());

        assertEqual(DummyFixture1.class.getName(), a.get(0).getClassName());
        assertEqual("fixture description", a.get(0).getDescription());
        assertEqual("fixture name", a.get(0).getName());
        assertEqual(12, a.get(0).getTestResults().length());

        assertEqual(DummyFixture2.class.getName(), a.get(1).getClassName());
        assertEqual("-", a.get(1).getDescription());
        assertEqual(DummyFixture2.class.getName(), a.get(1).getName());
        assertEqual(1, a.get(1).getTestResults().length());

        assertEqual(DummyFixture3.class.getName(), a.get(2).getClassName());
        assertEqual("-", a.get(2).getDescription());
        assertEqual(DummyFixture3.class.getName(), a.get(2).getName());
        assertEqual(1, a.get(2).getTestResults().length());

        assertEqual(DummyFixture4.class.getName(), a.get(3).getClassName());
        assertEqual("-", a.get(3).getDescription());
        assertEqual(DummyFixture4.class.getName(), a.get(3).getName());
        assertEqual(1, a.get(3).getTestResults().length());
    }
}
