/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.report.html.FixtureResultsFactory.newFixtureResults;
import static org.jtiger.report.html.TestResultFactory.newTestResult;
import static org.jtiger.assertion.Basic.assertEqual;

@Fixture(value = "FixtureResultsFactory", description = "Performs Unit Tests on org.jtiger.report.html.FixtureResultsFactory")
@Category("org.jtiger.report.html.FixtureResultsFactory")
public final class TestFixtureResultsFactory
{
    public TestFixtureResultsFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(FixtureResultsFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void testAccessors()
    {
        final TestResult tr = newTestResult("name", "exception", "elapsedTime", "message", "methodName", "description", "result");

        final FixtureResults fr = newFixtureResults("name", "description", "className",
                newSequence(new TestResult[]{tr}));
        assertEqual("name", fr.getName());
        assertEqual("description", fr.getDescription());
        assertEqual("className", fr.getClassName());
        assertEqual(newSequence(new TestResult[]{tr}),
                fr.getTestResults());
    }
}
