/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.report.html.IndexHtmlFileWriterFactory.newIndexHtmlFileWriter;

@Fixture(value = "IndexHtmlFileWriterFactory", description = "Performs Unit Tests on org.jtiger.report.html.IndexHtmlFileWriterFactory")
@Category("org.jtiger.report.html.IndexHtmlFileWriterFactory")
public final class TestIndexHtmlFileWriterFactory
{
    public TestIndexHtmlFileWriterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(IndexHtmlFileWriterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void writeIndexHtmlFile1() throws FixtureResultsHandlerException
    {
        final File temp = new File(System.getProperty("java.io.tmpdir"), "index" + System.currentTimeMillis());
        temp.mkdirs();
        newIndexHtmlFileWriter().writeIndexHtmlFile(temp);
    }

    @Test
    @ExpectException(FixtureResultsHandlerException.class)
    public void writeIndexHtmlFile2() throws FixtureResultsHandlerException, IOException
    {
        final File temp = new File(System.getProperty("java.io.tmpdir"), "exist");
        new FileOutputStream(temp).close();
        temp.mkdirs();
        newIndexHtmlFileWriter().writeIndexHtmlFile(temp);
    }
}
