/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.report.html.OverallResultConverterFactory.newOverallResultConverter;
import static org.jtiger.report.html.FixturesFilenamePolicyFactory.newFixturesFilenamePolicy;
import static org.jtiger.report.html.OverallTotalFactory.newOverallTotal;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.report.html.FixtureResultConverterFactory.newFixtureResultConverter;
import static org.jtiger.report.html.OverallHtmlFileWriterFactory.newOverallHtmlFileWriter;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;

@Fixture(value = "OverallHtmlFileWriterFactory", description = "Performs Unit Tests on org.jtiger.report.html.OverallHtmlFileWriterFactory")
@Category("org.jtiger.report.html.OverallHtmlFileWriterFactory")
public final class TestOverallHtmlFileWriterFactory
{
    public TestOverallHtmlFileWriterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(OverallHtmlFileWriterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void writeOverallHtml1()
            throws RunnerException, FixtureResultsHandlerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);
        final ReadOnlyArray<FixtureResults> frs = newFixtureResultConverter().convertFixtureResults(results);
        final ReadOnlyArray<OverallResult> overallResults = newOverallResultConverter().convertOverallResult(frs);

        final File temp = new File(System.getProperty("java.io.tmpdir"), "overall" + System.currentTimeMillis());
        temp.mkdirs();
        final FilenamePolicy policy = newFixturesFilenamePolicy();
        final OverallTotal total = newOverallTotal(results);
        newOverallHtmlFileWriter().writeOverallHtml(overallResults, temp, policy, total, "build time");
    }

    @Test
    @ExpectException(FixtureResultsHandlerException.class)
    public void writeOverallHtml2()
            throws RunnerException, FixtureResultsHandlerException, IOException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);
        final ReadOnlyArray<FixtureResults> frs = newFixtureResultConverter().convertFixtureResults(results);
        final ReadOnlyArray<OverallResult> overallResults = newOverallResultConverter().convertOverallResult(frs);

        final File temp = new File(System.getProperty("java.io.tmpdir"), "exist");
        new FileOutputStream(temp).close();
        temp.mkdirs();
        final FilenamePolicy policy = newFixturesFilenamePolicy();
        final OverallTotal total = newOverallTotal(results);
        newOverallHtmlFileWriter().writeOverallHtml(overallResults, temp, policy, total, "build time");
    }
}
