/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "OverallResultBeanImpl", description = "Performs Unit Tests on org.jtiger.report.html.OverallResultBeanImpl")
@Category("org.jtiger.report.html.OverallResultBeanImpl")
public final class TestOverallResultBeanImpl
{
    public TestOverallResultBeanImpl()
    {

    }

    @Test
    public void constructors()
    {
        new OverallResultBeanImpl();
        final OverallResultBean b = new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
        assertEqual("name", b.getName());
        assertEqual("href", b.getHref());
        assertEqual("description", b.getDescription());
        assertEqual("elapsedTime", b.getElapsedTime());
        assertEqual("result", b.getResult());
    }

    @Test
    public void name()
    {
        final OverallResultBean b = new OverallResultBeanImpl();
        b.setName("name");
        assertEqual("name", b.getName());
    }

    @Test
    public void href()
    {
        final OverallResultBean b = new OverallResultBeanImpl();
        b.setHref("href");
        assertEqual("href", b.getHref());
    }

    @Test
    public void description()
    {
        final OverallResultBean b = new OverallResultBeanImpl();
        b.setDescription("description");
        assertEqual("description", b.getDescription());
    }

    @Test
    public void elapsedTime()
    {
        final OverallResultBean b = new OverallResultBeanImpl();
        b.setElapsedTime("elapsedTime");
        assertEqual("elapsedTime", b.getElapsedTime());
    }

    @Test
    public void result()
    {
        final OverallResultBean b = new OverallResultBeanImpl();
        b.setResult("result");
        assertEqual("result", b.getResult());
    }

    @Test
    public void serialization()
    {
        final OverallResultBean b = new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");

        assertSerializes(b);
        assertSerializesEqual(b);
        assertHasDeclaredField(b.getClass(), "serialVersionUID");
    }
  
    @Test
    public void testToString()
    {
        final OverallResultBean b = new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");

        final String s = "[name][href][description][elapsedTime][result]";

        assertEqual(s, b.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name x", "href", "description", "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href x", "description", "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description x", "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode4()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime x", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode5()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result x");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode6()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                null, "href", "description", "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode7()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", null, "description", "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode8()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", null, "elapsedTime", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode9()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", null, "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode10()
    {
        final ObjectFactory<OverallResultBeanImpl> factory = new ObjectFactory<OverallResultBeanImpl>()
        {
            public OverallResultBeanImpl newInstanceX()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", "result");
            }

            public OverallResultBeanImpl newInstanceY()
            {
                return new OverallResultBeanImpl(
                "name", "href", "description", "elapsedTime", null);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
