/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.ReadOnlyArray;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.report.html.FixtureResultsFactory.newFixtureResults;
import static org.jtiger.report.html.TestResultFactory.newTestResult;
import static org.jtiger.report.html.OverallResultConverterFactory.newOverallResultConverter;
import static org.jtiger.report.html.ResultMappingFactory.newResultMapping;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;

@Fixture(value = "OverallResultConverterFactory", description = "Performs Unit Tests on org.jtiger.report.html.OverallResultConverterFactory")
@Category("org.jtiger.report.html.OverallResultConverterFactory")
public final class TestOverallResultConverterFactory
{
    public TestOverallResultConverterFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(OverallResultConverterFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void convertOverallResult()
    {
        final FixtureResults fr1 = newFixtureResults("name1", "description1", "className1", newSequence(new TestResult[]
        {
            newTestResult("name11", "exception11", "11", "message11", "methodName11", "description11", "result11"),
            newTestResult("name12", "exception12", "12", "message12", "methodName12", "description12", "result12"),
            newTestResult("name13", "exception13", "13", "message13", "methodName13", "description13", "result13")
        }));

        final FixtureResults fr2 = newFixtureResults("name2", "", "className2", newSequence(new TestResult[]
        {
            newTestResult("name21", "exception21", null, "message21", "methodName21", "description21", "Success"),
            newTestResult("name22", "exception22", "22", "message22", "methodName22", "description22", "Failure"),
            newTestResult("name23", "exception23", "23", "message23", "methodName23", "description23", "result23")
        }));

        final FixtureResults fr3 = newFixtureResults("name3", null, "className3", newSequence(new TestResult[]
        {
            newTestResult("name31", "exception31", "", "message31", "methodName31", "description31", "Failure"),
            newTestResult("name32", "exception32", "32", "message32", "methodName32", "description32", "Ignored (Annotated)"),
            newTestResult("name33", "exception33", "33", "message33", "methodName33", "description33", "Failure (Tear Down)")
        }));

        final FixtureResults fr4 = newFixtureResults("name3", "description3", "className3", newSequence(new TestResult[]{}));

        final ReadOnlyArray<OverallResult> a = newOverallResultConverter().convertOverallResult(
                newSequence(new FixtureResults[]{fr1, fr2, fr3, fr4}));

        final ResultMapping mapping = newResultMapping();

        assertEqual(4, a.length());

        assertEqual("name1", a.get(0).getName());
        assertEqual("description1", a.get(0).getDescription());
        assertEqual("36", a.get(0).getElapsedTime());
        assertEqual(mapping.getResultMapping(SUCCESS), a.get(0).getResult());

        assertEqual("name2", a.get(1).getName());
        assertEqual("-", a.get(1).getDescription());
        assertEqual("45", a.get(1).getElapsedTime());
        assertEqual(mapping.getResultMapping(FAILURE), a.get(1).getResult());

        assertEqual("name3", a.get(2).getName());
        assertEqual("-", a.get(2).getDescription());
        assertEqual("65", a.get(2).getElapsedTime());
        assertEqual(mapping.getResultMapping(FAILURE_TEARDOWN), a.get(2).getResult());
    }
}
