/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.framework.Category;
import org.jtiger.framework.ExpectException;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.report.html.OverallTotalFactory.newOverallTotal;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;

@Fixture(value = "OverallTotalFactory", description = "Performs Unit Tests on org.jtiger.report.html.OverallTotalFactory")
@Category("org.jtiger.report.html.OverallTotalFactory")
public final class TestOverallTotalFactory
{
    public TestOverallTotalFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(OverallTotalFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    @ExpectException(NullPointerException.class)
    public void factoryMethod()
    {
        newOverallTotal(null);
    }

    @Test
    public void testAccessors() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class}), null, null, false);
        final org.jtiger.framework.FixtureResults results = runner.run(config);
        final OverallTotal total = newOverallTotal(results);

        assertEqual(7L, total.getSuccess());
        assertEqual(3L, total.getFailure());
        assertEqual(1L, total.getFailureSetUp());
        assertEqual(1L, total.getFailureTearDown());
        assertEqual(2L, total.getIgnoredAnnotated());
        assertEqual(1L, total.getIgnoredCannotInvoke());
        assertEqual(15L, total.getTotal());
    }
}
