/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.ResourceBundle;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import org.jtiger.framework.TestResultType;
import static org.jtiger.assertion.Reflection.assertHasDeclaredConstructor;
import static org.jtiger.assertion.Modifier.assertPrivate;
import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertNull;
import static org.jtiger.report.html.ResultMappingFactory.newResultMapping;
import static org.jtiger.framework.TestResultType.SUCCESS;
import static org.jtiger.framework.TestResultType.FAILURE;
import static org.jtiger.framework.TestResultType.FAILURE_SETUP;
import static org.jtiger.framework.TestResultType.FAILURE_TEARDOWN;
import static org.jtiger.framework.TestResultType.IGNORED_ANNOTATED;
import static org.jtiger.framework.TestResultType.IGNORED_CANNOT_INVOKE;

@Fixture(value = "ResultMappingFactory", description = "Performs Unit Tests on org.jtiger.report.html.ResultMappingFactory")
@Category("org.jtiger.report.html.ResultMappingFactory")
public final class TestResultMappingFactory
{
    public TestResultMappingFactory()
    {

    }

    @Test
    public void constructor() throws InstantiationException, IllegalAccessException, InvocationTargetException
    {
        final Constructor<?> c = assertHasDeclaredConstructor(ResultMappingFactory.class, null);
        assertPrivate(c);
        assertFalse(c.isAccessible());
        c.setAccessible(true);
        c.newInstance();
    }

    @Test
    public void getResultMapping1()
    {
        final String bundle = "org/jtiger/report/html/ResultMapping";

        final ResultMapping mapping = newResultMapping();

        assertEqual(ResourceBundle.getBundle(bundle).getString("failure"), mapping.getResultMapping(FAILURE));
        assertEqual(ResourceBundle.getBundle(bundle).getString("failure.setup"), mapping.getResultMapping(FAILURE_SETUP));
        assertEqual(ResourceBundle.getBundle(bundle).getString("failure.teardown"), mapping.getResultMapping(FAILURE_TEARDOWN));
        assertEqual(ResourceBundle.getBundle(bundle).getString("ignored.annotated"), mapping.getResultMapping(IGNORED_ANNOTATED));
        assertEqual(ResourceBundle.getBundle(bundle).getString("ignored.cannot.invoke"), mapping.getResultMapping(IGNORED_CANNOT_INVOKE));
        assertEqual(ResourceBundle.getBundle(bundle).getString("success"), mapping.getResultMapping(SUCCESS));
        assertNull(mapping.getResultMapping((TestResultType)null));
    }

    @Test
    public void getResultMapping2()
    {
        final String bundle = "org/jtiger/report/html/ResultMapping";

        final ResultMapping mapping = newResultMapping();

        assertEqual(FAILURE, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("failure")));
        assertEqual(FAILURE_SETUP, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("failure.setup")));
        assertEqual(FAILURE_TEARDOWN, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("failure.teardown")));
        assertEqual(IGNORED_ANNOTATED, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("ignored.annotated")));
        assertEqual(IGNORED_CANNOT_INVOKE, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("ignored.cannot.invoke")));
        assertEqual(SUCCESS, mapping.getResultMapping(ResourceBundle.getBundle(bundle).getString("success")));
        assertNull(mapping.getResultMapping((String)null));
    }
}
