/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.html;

import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "TestResultBeanImpl", description = "Performs Unit Tests on org.jtiger.report.html.TestResultBeanImpl")
@Category("org.jtiger.report.html.TestResultBeanImpl")
public final class TestTestResultBeanImpl
{
    public TestTestResultBeanImpl()
    {

    }

    @Test
    public void constructors()
    {
        new TestResultBeanImpl();
        final TestResultBean b = new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
        assertEqual("name", b.getName());
        assertEqual("exception", b.getException());
        assertEqual("elapsedTime", b.getElapsedTime());
        assertEqual("message", b.getMessage());
        assertEqual("methodName", b.getMethodName());
        assertEqual("description", b.getDescription());
        assertEqual("result", b.getResult());
    }

    @Test
    public void name()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setName("name");
        assertEqual("name", b.getName());
    }

    @Test
    public void exception()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setException("exception");
        assertEqual("exception", b.getException());
    }

    @Test
    public void elapsedTime()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setElapsedTime("elapsedTime");
        assertEqual("elapsedTime", b.getElapsedTime());
    }

    @Test
    public void message()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setMessage("message");
        assertEqual("message", b.getMessage());
    }

    @Test
    public void methodName()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setMethodName("methodName");
        assertEqual("methodName", b.getMethodName());
    }

    @Test
    public void description()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setDescription("description");
        assertEqual("description", b.getDescription());
    }

    @Test
    public void result()
    {
        final TestResultBean b = new TestResultBeanImpl();
        b.setResult("result");
        assertEqual("result", b.getResult());
    }

    @Test
    public void serialization()
    {
        final TestResultBean b = new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");

        assertSerializes(b);
        assertSerializesEqual(b);
        assertHasDeclaredField(b.getClass(), "serialVersionUID");
    }

    @Test
    public void testToString()
    {
        final TestResultBean b = new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");

        final String s = "[name][exception][elapsedTime][message][methodName][description][result]";

        assertEqual(s, b.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name x", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception x", "elapsedTime", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime x", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode4()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message x", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode5()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName x", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode6()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description x", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode7()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result x");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode8()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                null, "exception", "elapsedTime", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode9()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", null, "elapsedTime", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode10()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", null, "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode11()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", null, "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode12()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", null, "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode13()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", null, "result");
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode14()
    {
        final ObjectFactory<TestResultBeanImpl> factory = new ObjectFactory<TestResultBeanImpl>()
        {
            public TestResultBeanImpl newInstanceX()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", "result");
            }

            public TestResultBeanImpl newInstanceY()
            {
                return new TestResultBeanImpl(
                "name", "exception", "elapsedTime", "message", "methodName", "description", null);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
