/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.util.Arrays;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "FixtureResultBeanImpl", description = "Performs Unit Tests on org.jtiger.report.xml.FixtureResultBeanImpl")
@Category("org.jtiger.report.xml.FixtureResultBeanImpl")
public final class TestFixtureResultBeanImpl
{
    public TestFixtureResultBeanImpl()
    {

    }

    @Test
    public void constructors() throws RunnerException
    {
        assertEqual(0, new FixtureResultBeanImpl().getTestResults().length);
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        assertEqual(5, results.size());
        final FixtureResultBean b1 = new FixtureResultBeanImpl(results.get(0));
        final FixtureResultBean b2 = new FixtureResultBeanImpl(results.get(1));
        final FixtureResultBean b3 = new FixtureResultBeanImpl(results.get(2));
        final FixtureResultBean b4 = new FixtureResultBeanImpl(results.get(3));
        final FixtureResultBean b5 = new FixtureResultBeanImpl(results.get(4));
        assertEqual(12, b1.getTestResults().length);
        assertEqual(1, b2.getTestResults().length);
        assertEqual(1, b3.getTestResults().length);
        assertEqual(1, b4.getTestResults().length);
        assertEqual(0, b5.getTestResults().length);
    }

    @Test
    public void accessors()
    {
        final TestResultBean[] beans = new TestResultBean[]
        {
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl()
        };

        final FixtureResultBean b = new FixtureResultBeanImpl();
        b.setTestResults(beans);
        assertSame(beans, b.getTestResults());
    }

    @Test
    public void serialization()
    {
        final TestResultBean[] beans = new TestResultBean[]
        {
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl()
        };

        final FixtureResultBean b = new FixtureResultBeanImpl();
        b.setTestResults(beans);

        assertSerializes(b);
        assertSerializesEqual(b);
        assertHasDeclaredField(b.getClass(), "serialVersionUID");
    }

    @Test
    public void testToString()
    {
        final TestResultBean[] beans = new TestResultBean[]
        {
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl(),
            new TestResultBeanImpl()
        };

        final FixtureResultBean b = new FixtureResultBeanImpl();
        b.setTestResults(beans);

        assertEqual(Arrays.toString(beans), b.toString());
    }

    @Test
    public void equalsHashCode1() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final ObjectFactory<FixtureResultBean> factory = new ObjectFactory<FixtureResultBean>()
        {
            public FixtureResultBean newInstanceX()
            {
                return new FixtureResultBeanImpl(results.get(0));
            }

            public FixtureResultBean newInstanceY()
            {
                return new FixtureResultBeanImpl(results.get(1));
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final ObjectFactory<FixtureResultBean> factory = new ObjectFactory<FixtureResultBean>()
        {
            public FixtureResultBean newInstanceX()
            {
                return new FixtureResultBeanImpl(results.get(1));
            }

            public FixtureResultBean newInstanceY()
            {
                return new FixtureResultBeanImpl(results.get(2));
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final ObjectFactory<FixtureResultBean> factory = new ObjectFactory<FixtureResultBean>()
        {
            public FixtureResultBean newInstanceX()
            {
                return new FixtureResultBeanImpl(results.get(2));
            }

            public FixtureResultBean newInstanceY()
            {
                return new FixtureResultBeanImpl(results.get(3));
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode4() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final ObjectFactory<FixtureResultBean> factory = new ObjectFactory<FixtureResultBean>()
        {
            public FixtureResultBean newInstanceX()
            {
                return new FixtureResultBeanImpl(results.get(3));
            }

            public FixtureResultBean newInstanceY()
            {
                return new FixtureResultBeanImpl(results.get(4));
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
