/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.util.Arrays;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Serialization.assertSerializesEqual;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "FixtureResultsBeanImpl", description = "Performs Unit Tests on org.jtiger.report.xml.FixtureResultsBeanImpl")
@Category("org.jtiger.report.xml.FixtureResultsBeanImpl")
public final class TestFixtureResultsBeanImpl
{
    public TestFixtureResultsBeanImpl()
    {

    }

    @Test
    public void constructors() throws RunnerException
    {
        assertEqual(0, new FixtureResultsBeanImpl().getFixtureResults().length);
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        final FixtureResultsBean b = new FixtureResultsBeanImpl(results);
        assertEqual(5, b.getFixtureResults().length);
        assertEqual(12, b.getFixtureResults()[0].getTestResults().length);
        assertEqual(1, b.getFixtureResults()[1].getTestResults().length);
        assertEqual(1, b.getFixtureResults()[2].getTestResults().length);
        assertEqual(1, b.getFixtureResults()[3].getTestResults().length);
        assertEqual(0, b.getFixtureResults()[4].getTestResults().length);
    }

    @Test
    public void accessors()
    {
        final FixtureResultBean[] beans = new FixtureResultBean[]
        {
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl()
        };

        final FixtureResultsBean b = new FixtureResultsBeanImpl();
        b.setFixtureResults(beans);
        assertSame(beans, b.getFixtureResults());
    }

    @Test
    public void serialization()
    {
        final FixtureResultBean[] beans = new FixtureResultBean[]
        {
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl()
        };

        final FixtureResultsBean b = new FixtureResultsBeanImpl();
        b.setFixtureResults(beans);

        assertSerializes(b);
        assertSerializesEqual(b);
        assertHasDeclaredField(b.getClass(), "serialVersionUID");
    }
  
    @Test
    public void testToString()
    {
        final FixtureResultBean[] beans = new FixtureResultBean[]
        {
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl(),
            new FixtureResultBeanImpl()
        };

        final FixtureResultsBean b = new FixtureResultsBeanImpl();
        b.setFixtureResults(beans);

        assertEqual(Arrays.toString(beans), b.toString());
    }

    @Test
    public void equalsHashCode1() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config1 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results1 = runner.run(config1);

        final FixturesRunnerConfig config2 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results2 = runner.run(config2);

        final ObjectFactory<FixtureResultsBean> factory = new ObjectFactory<FixtureResultsBean>()
        {
            public FixtureResultsBean newInstanceX()
            {
                return new FixtureResultsBeanImpl(results1);
            }

            public FixtureResultsBean newInstanceY()
            {
                return new FixtureResultsBeanImpl(results2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config1 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results1 = runner.run(config1);

        final FixturesRunnerConfig config2 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture4.class, DummyFixture3.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results2 = runner.run(config2);

        final ObjectFactory<FixtureResultsBean> factory = new ObjectFactory<FixtureResultsBean>()
        {
            public FixtureResultsBean newInstanceX()
            {
                return new FixtureResultsBeanImpl(results1);
            }

            public FixtureResultsBean newInstanceY()
            {
                return new FixtureResultsBeanImpl(results2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3() throws RunnerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config1 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture4.class, DummyFixture3.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results1 = runner.run(config1);

        final FixturesRunnerConfig config2 = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results2 = runner.run(config2);

        final ObjectFactory<FixtureResultsBean> factory = new ObjectFactory<FixtureResultsBean>()
        {
            public FixtureResultsBean newInstanceX()
            {
                return new FixtureResultsBeanImpl(results1);
            }

            public FixtureResultsBean newInstanceY()
            {
                return new FixtureResultsBeanImpl(results2);
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
