/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import static org.jtiger.framework.SequenceFactory.newSequence;
import java.util.Arrays;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.assertion.ObjectFactory;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.assertion.Reflection.assertHasDeclaredField;
import static org.jtiger.assertion.Serialization.assertSerializes;
import static org.jtiger.assertion.Basic.assertEqual;
import static org.jtiger.assertion.Basic.assertSame;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.assertion.ObjectFactoryContract.assertObjectFactoryFillsContract;
import static org.jtiger.assertion.HashCodeMethodContract.assertHashCodeMethodFillsContract;
import static org.jtiger.assertion.EqualsMethodContract.assertEqualsMethodFillsContract;

@Fixture(value = "TestResultBeanImpl", description = "Performs Unit Tests on org.jtiger.report.xml.TestResultBeanImpl")
@Category("org.jtiger.report.xml.TestResultBeanImpl")
public final class TestTestResultBeanImpl
{
    public TestTestResultBeanImpl()
    {

    }

    @Test
    public void constructors() throws RunnerException
    {
        assertEqual(0, new FixtureResultsBeanImpl().getFixtureResults().length);
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);

        assertEqual(5, results.size());
        assertEqual(12, results.get(0).size());
    }

    @Test
    public void accessors()
    {
        final TestResultBean bean = new TestResultBeanImpl();
        final String[] categories = new String[]{"x", "y"};
        final Long elapsedTime = 7L;
        final Throwable exception = new IllegalArgumentException();
        final Class<?> fixtureClass = getClass();
        final String fixtureDescription = "fixture description";
        final String fixtureName = "fixture name";
        final String message = "message";
        final String testDescription = "test description";
        final String testMethodName = "testMethodName";
        final String testName = "test name";
        final String testResult = "Success";

        bean.setCategories(categories);
        bean.setElapsedTime(elapsedTime);
        bean.setException(exception);
        bean.setFixtureClass(fixtureClass);
        bean.setFixtureDescription(fixtureDescription);
        bean.setFixtureName(fixtureName);
        bean.setMessage(message);
        bean.setTestDescription(testDescription);
        bean.setTestMethodName(testMethodName);
        bean.setTestName(testName);
        bean.setTestResult(testResult);

        assertEqual(new String[]{"x", "y"}, bean.getCategories());
        assertEqual(7L, bean.getElapsedTime());
        assertEqual(exception, bean.getException());
        assertSame(getClass(), bean.getFixtureClass());
        assertEqual("fixture description", bean.getFixtureDescription());
        assertEqual("fixture name", bean.getFixtureName());
        assertEqual("message", bean.getMessage());
        assertEqual("test description", bean.getTestDescription());
        assertEqual("testMethodName", bean.getTestMethodName());
        assertEqual("test name", bean.getTestName());
        assertEqual("Success", bean.getTestResult());
    }

    @Test
    public void serialization()
    {
        final TestResultBean bean = new TestResultBeanImpl();
        final String[] categories = new String[]{"x", "y"};
        final Long elapsedTime = 7L;
        final Throwable exception = new IllegalArgumentException();
        final Class<?> fixtureClass = getClass();
        final String fixtureDescription = "fixture description";
        final String fixtureName = "fixture name";
        final String message = "message";
        final String testDescription = "test description";
        final String testMethodName = "testMethodName";
        final String testName = "test name";
        final String testResult = "Success";

        bean.setCategories(categories);
        bean.setElapsedTime(elapsedTime);
        bean.setException(exception);
        bean.setFixtureClass(fixtureClass);
        bean.setFixtureDescription(fixtureDescription);
        bean.setFixtureName(fixtureName);
        bean.setMessage(message);
        bean.setTestDescription(testDescription);
        bean.setTestMethodName(testMethodName);
        bean.setTestName(testName);
        bean.setTestResult(testResult);

        assertSerializes(bean);
        assertHasDeclaredField(bean.getClass(), "serialVersionUID");
    }

    @Test
    public void testToString()
    {
        final TestResultBean bean = new TestResultBeanImpl();
        final String[] categories = new String[]{"x", "y"};
        final Long elapsedTime = 7L;
        final Throwable exception = new IllegalArgumentException();
        final Class<?> fixtureClass = getClass();
        final String fixtureDescription = "fixture description";
        final String fixtureName = "fixture name";
        final String message = "message";
        final String testDescription = "test description";
        final String testMethodName = "testMethodName";
        final String testName = "test name";
        final String testResult = "Success";

        bean.setCategories(categories);
        bean.setElapsedTime(elapsedTime);
        bean.setException(exception);
        bean.setFixtureClass(fixtureClass);
        bean.setFixtureDescription(fixtureDescription);
        bean.setFixtureName(fixtureName);
        bean.setMessage(message);
        bean.setTestDescription(testDescription);
        bean.setTestMethodName(testMethodName);
        bean.setTestName(testName);
        bean.setTestResult(testResult);

        final String s = "[" + testResult + "][" + message + "][" + exception + "][" + elapsedTime + "][" +
                Arrays.toString(categories) + "][" + testName + "][" + testDescription + "][" +
                testMethodName + "][" + fixtureName + "][" + fixtureDescription + "][" + fixtureClass + "]";

        assertEqual(s, bean.toString());
    }

    @Test
    public void equalsHashCode1()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"y", "x"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode2()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 8L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode3()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = null;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode4()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = String.class;
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode5()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description x";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode6()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name x";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode7()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message x";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode8()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description x";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode9()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodNameX";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode10()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name x";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode11()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Failure";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode12()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode13()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = null;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode14()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = null;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode15()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = null;
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode16()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = null;
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode17()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = null;
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode18()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = null;
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode19()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = null;
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode20()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = null;
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode21()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = null;
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }

    @Test
    public void equalsHashCode22()
    {
        final ObjectFactory<TestResultBean> factory = new ObjectFactory<TestResultBean>()
        {
            private final Throwable exception = new IllegalArgumentException();

            public TestResultBean newInstanceX()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = new String[]{"x", "y"};
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = "Success";

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }

            public TestResultBean newInstanceY()
            {
                final TestResultBean bean1 = new TestResultBeanImpl();
                final String[] categories = null;
                final Long elapsedTime = 7L;
                final Throwable exception = this.exception;
                final Class<?> fixtureClass = getClass();
                final String fixtureDescription = "fixture description";
                final String fixtureName = "fixture name";
                final String message = "message";
                final String testDescription = "test description";
                final String testMethodName = "testMethodName";
                final String testName = "test name";
                final String testResult = null;

                bean1.setCategories(categories);
                bean1.setElapsedTime(elapsedTime);
                bean1.setException(exception);
                bean1.setFixtureClass(fixtureClass);
                bean1.setFixtureDescription(fixtureDescription);
                bean1.setFixtureName(fixtureName);
                bean1.setMessage(message);
                bean1.setTestDescription(testDescription);
                bean1.setTestMethodName(testMethodName);
                bean1.setTestName(testName);
                bean1.setTestResult(testResult);
                return bean1;
            }
        };

        assertObjectFactoryFillsContract(factory);
        assertHashCodeMethodFillsContract(factory);
        assertEqualsMethodFillsContract(factory);
    }
}
