/*
 * JTiger Unit Testing Framework for J2SE 1.5
 * Copyright (C) 2005 Tony Morris
 *
 * This software is licenced under the
 * Common Public Licence version 1.0
 * http://www.opensource.org/licenses/cpl1.0.php
 *
 * You received a copy of this licence with this software.
 */
package org.jtiger.report.xml;

import static org.jtiger.assertion.Basic.assertFalse;
import static org.jtiger.assertion.Basic.assertTrue;
import static org.jtiger.framework.SequenceFactory.newSequence;
import java.io.File;
import java.io.IOException;
import org.jtiger.DummyFixture1;
import org.jtiger.DummyFixture2;
import org.jtiger.DummyFixture3;
import org.jtiger.DummyFixture4;
import org.jtiger.DummyFixture5;
import org.jtiger.framework.Category;
import org.jtiger.framework.Fixture;
import org.jtiger.framework.FixtureResultsHandlerException;
import org.jtiger.framework.FixturesRunner;
import org.jtiger.framework.FixturesRunnerConfig;
import org.jtiger.framework.RunnerException;
import org.jtiger.framework.Test;
import static org.jtiger.framework.FixturesRunnerConfigFactory.newFixturesRunnerConfig;
import static org.jtiger.framework.FixturesRunnerFactory.newFixturesRunner;

@Fixture(value = "XmlFixtureResultsHandler", description = "Performs Unit Tests on org.jtiger.report.xml.XmlFixtureResultsHandler")
@Category("org.jtiger.report.xml.XmlFixtureResultsHandler")
public final class TestXmlFixtureResultsHandler
{
    public TestXmlFixtureResultsHandler()
    {

    }

    @Test
    public void handleResult1() throws RunnerException, FixtureResultsHandlerException, IOException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);
        final File temp = new File(System.getProperty("java.io.tmpdir"), "xmlresults" + System.currentTimeMillis());
        new XmlFixtureResultsHandler().handleResult(results, newSequence(new String[]{temp.getCanonicalPath()}));

    }

    @Test
    public void handleResult2() throws RunnerException, FixtureResultsHandlerException
    {
        final FixturesRunner runner = newFixturesRunner();
        final FixturesRunnerConfig config = newFixturesRunnerConfig(
                newSequence(new Class<?>[]{DummyFixture1.class, DummyFixture2.class, DummyFixture3.class, DummyFixture4.class, DummyFixture5.class}), null, null, false);

        final org.jtiger.framework.FixtureResults results = runner.run(config);
        assertFalse(new File("result.xml").exists());
        new XmlFixtureResultsHandler().handleResult(results, newSequence(new String[]{}));
        assertTrue(new File("result.xml").exists());
        new File("result.xml").delete();
    }
}
